@@ -187,8 +187,7 @@ void ArticleViewer::generateNormalModeCSS()
     const QColorGroup & cg = QApplication::palette().active();
     
     // from kmail::headerstyle.cpp
-    m_normalModeCSS = QString (
-            "<style type=\"text/css\">\n"
+    m_normalModeCSS = QString(
             "@media screen, print {"
             "body {\n"
             "  font-family: \"%1\" ! important;\n"
@@ -199,7 +198,7 @@ void ArticleViewer::generateNormalModeCSS()
             .arg(QString::number(pointsToPixel(Settings::mediumFontSize()))+"px")
             .arg(cg.text().name())
             .arg(cg.base().name());
-    m_normalModeCSS += (
+    m_normalModeCSS += QString(
     "a {\n"
     + QString("  color: %1 ! important;\n")
     + QString(!Settings::underlineLinks() ? " text-decoration: none ! important;\n" : "")
@@ -223,6 +222,7 @@ void ArticleViewer::generateNormalModeCSS()
             .arg(cg.highlightedText().name())
             .arg(cg.highlightedText().name())
             .arg(cg.highlightedText().name());
+    
     m_normalModeCSS += QString(
     ".headertitle {\n"
     "  background: %1 ! important;\n"
@@ -253,11 +253,12 @@ void ArticleViewer::generateNormalModeCSS()
     ".content > P:first-child {\n margin-top: 1px; }\n"
     ".content > DIV:first-child {\n margin-top: 1px; }\n"
     ".content > BR:first-child {\n display: none;  }\n"
-    //".contentlink {\n display: block; }\n"
-    "}\n\n" // @media screen, print
-    // Why did we need that, bug #108187?
-    //"@media screen { body { overflow: auto; } }\n"
-    "\n\n");
+    "iframe {display: none !important; }\n"
+    "frame {display: none !important; }\n"
+    "frameset {display: none !important; }\n"
+    "object {display: none !important; }\n"
+    "applet {display: none !important; }\n"
+    "}\n\n"); // @media screen, print    
 }
 
 void ArticleViewer::generateCombinedModeCSS()
@@ -266,7 +267,7 @@ void ArticleViewer::generateCombinedModeCSS()
     
     // from kmail::headerstyle.cpp
     m_combinedModeCSS = QString (
-            "<style type=\"text/css\">\n"
+//            "<style type=\"text/css\">\n"
             "@media screen, print {"
             "body {\n"
             "  font-family: \"%1\" ! important;\n"
@@ -331,11 +332,12 @@ void ArticleViewer::generateCombinedModeCSS()
     ".content > P:first-child {\n margin-top: 1px; }\n"
     ".content > DIV:first-child {\n margin-top: 1px; }\n"
     ".content > BR:first-child {\n display: none;  }\n"
-    //".contentlink {\n display: block; }\n"
-    "}\n\n" // @media screen, print
-    // Why did we need that, bug #108187?
-    //"@media screen { body { overflow: auto; } }\n"
-    "\n\n");
+    "iframe {display: none !important; }\n"
+    "frame {display: none !important; }\n"
+    "frameset {display: none !important; }\n"
+    "object {display: none !important; }\n"
+    "applet {display: none !important; }\n"
+    "}\n\n"); // @media screen, print
 }
 
 void ArticleViewer::reload()
@@ -384,7 +386,7 @@ void ArticleViewer::displayAboutPage()
             "<p>Thank you,</p>\n"
             "<p style='margin-bottom: 0px'>&nbsp; &nbsp; The Akregator Team</p>\n")
             .arg(AKREGATOR_VERSION) // Akregator version
-            .arg("http://akregator.sourceforge.net/"); // Akregator homepage URL
+            .arg("http://akregator.kde.org/"); // Akregator homepage URL
 
     QString fontSize = QString::number( pointsToPixel( Settings::mediumFontSize() ));
     QString appTitle = i18n("Akregator");
@@ -428,8 +430,7 @@ QString ArticleViewer::formatArticleNormalMode(Feed* feed, const Article& articl
 
     if (feed && !feed->image().isNull())
     {
-        QString url=feed->xmlUrl();
-        QString file = url.replace("/", "_").replace(":", "_");
+        QString file = Utils::fileNameForUrl(feed->xmlUrl());
         KURL u(m_imageDir);
         u.setFileName(file);
         text += QString("<a href=\"%1\"><img class=\"headimage\" src=\"%2.png\"></a>\n").arg(feed->htmlUrl()).arg(u.url());
@@ -493,13 +494,15 @@ QString ArticleViewer::formatArticleCombinedMode(Feed* feed, const Article& arti
     QString text;
     text = QString("<div class=\"headerbox\" dir=\"%1\">\n").arg(QApplication::reverseLayout() ? "rtl" : "ltr");
 
+    KURL link = article.link();
+    
     if (!article.title().isEmpty())
     {
         text += QString("<div class=\"headertitle\" dir=\"%1\">\n").arg(directionOf(Utils::stripTags(article.title())));
-        if (article.link().isValid())
-            text += "<a href=\""+article.link().url()+"\">";
+        if (link.isValid())
+            text += "<a href=\""+link.url()+"\">";
         text += article.title().replace("<", "&lt;").replace(">", "&gt;"); // TODO: better leave things escaped in the parser
-        if (article.link().isValid())
+        if (link.isValid())
             text += "</a>";
         text += "</div>\n";
     }
@@ -524,8 +527,7 @@ QString ArticleViewer::formatArticleCombinedMode(Feed* feed, const Article& arti
 
     if (feed && !feed->image().isNull())
     {
-        QString url=feed->xmlUrl();
-        QString file = url.replace("/", "_").replace(":", "_");
+        QString file = Utils::fileNameForUrl(feed->xmlUrl());
         KURL u(m_imageDir);
         u.setFileName(file);
         text += QString("<a href=\"%1\"><img class=\"headimage\" src=\"%2.png\"></a>\n").arg(feed->htmlUrl()).arg(u.url());
@@ -554,13 +556,13 @@ QString ArticleViewer::formatArticleCombinedMode(Feed* feed, const Article& arti
         text += "</a>";
     }
 
-    if (article.link().isValid() || (article.guidIsPermaLink() && KURL(article.guid()).isValid()))
+    if (link.isValid() || (article.guidIsPermaLink() && KURL(article.guid()).isValid()))
     {
         text += "<p><a class=\"contentlink\" href=\"";
         // in case link isn't valid, fall back to the guid permaLink.
-        if (article.link().isValid())
+        if (link.isValid())
         {
-            text += article.link().url();
+            text += link.url();
         }
         else
          {
@@ -586,16 +588,10 @@ void ArticleViewer::renderContent(const QString& text)
 
 void ArticleViewer::beginWriting()
 {
-    QString head = QString("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n <html><head><title>.</title>");
-    
-    if (m_viewMode == CombinedView)
-        head += m_combinedModeCSS;
-    else
-        head += m_normalModeCSS; 
-
-    head += "</style></head><body>";
+    QString head = QString("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n <html><head><title>.</title></head>");
     view()->setContentsPos(0,0);
     begin(m_link);
+    setUserStyleSheet(m_viewMode == CombinedView ? m_combinedModeCSS : m_normalModeCSS);
     write(head);
 }
 
