@@ -1,7 +1,7 @@
 /*
  *  alarmevent.h  -  represents calendar alarms and events
  *  Program:  kalarm
- *  Copyright (c) 2001-2005 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001-2006 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -353,6 +353,7 @@ class KAEvent : public KAAlarmEventBase
 		bool               defer(const DateTime&, bool reminder, bool adjustRecurrence = false);
 		void               cancelDefer();
 		void               cancelCancelledDeferral();
+		void               setDeferDefaultMinutes(int minutes)               { mDeferDefaultMinutes = minutes;  mUpdated = true; }
 		bool               setDisplaying(const KAEvent&, KAAlarm::Type, const QDateTime&);
 		void               reinstateFromDisplaying(const KAEvent& dispEvent);
 		void               setArchive()                                      { mArchive = true;  mUpdated = true; }
@@ -389,6 +390,7 @@ class KAEvent : public KAAlarmEventBase
 		int                reminderArchived() const       { return mArchiveReminderMinutes; }
 		DateTime           deferDateTime() const          { return mDeferralTime; }
 		DateTime           deferralLimit(DeferLimitType* = 0) const;
+		int                deferDefaultMinutes() const    { return mDeferDefaultMinutes; }
 		DateTime           nextDateTime(bool includeReminders = true) const;
 		const QString&     messageFileOrCommand() const   { return mText; }
 		QString            logFile() const                { return mLogFile; }
@@ -447,6 +449,8 @@ class KAEvent : public KAAlarmEventBase
 #else
 		void               dumpDebug() const;
 #endif
+		static int         calVersion();
+		static QString     calVersionString();
 		static bool        adjustStartOfDay(const KCal::Event::List&);
 		static void        convertKCalEvents(KCal::Calendar&, int version, bool adjustSummerTime);
 
@@ -484,6 +488,7 @@ class KAEvent : public KAAlarmEventBase
 		int                mDisplayingFlags;  // type of alarm which is currently being displayed
 		int                mReminderMinutes;  // how long in advance reminder is to be, or 0 if none
 		int                mArchiveReminderMinutes;  // original reminder period if now expired, or 0 if none
+		int                mDeferDefaultMinutes; // default number of minutes for deferral dialogue, or 0 to select time control
 		int                mRevision;         // SEQUENCE: revision number of the original alarm, or 0
 		KARecurrence*      mRecurrence;       // RECUR: recurrence specification, or 0 if none
 		int                mRemainingRecurrences; // remaining number of alarm recurrences including initial time, -1 to repeat indefinitely
