@@ -1,7 +1,7 @@
 /*
  *  birthdaydlg.cpp  -  dialog to pick birthdays from address book
  *  Program:  kalarm
- *  Copyright (c) 2002-2006 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2002-2006 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@ const KABC::AddressBook* BirthdayDlg::mAddressBook = 0;
 
 
 BirthdayDlg::BirthdayDlg(QWidget* parent)
-	: KDialogBase(KDialogBase::Plain, i18n("Import Birthdays From KAddressBook"), Ok|Cancel, Ok, parent),
+	: KDialogBase(KDialogBase::Plain, i18n("Import Birthdays From KAddressBook"), Ok|Cancel, Ok, parent, "BirthdayDlg"),
 	  mSpecialActionsButton(0)
 {
 	QWidget* topWidget = plainPage();
@@ -194,7 +194,7 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 	mBgColourChoose->setColour(Preferences::defaultBgColour());     // set colour before setting alarm type buttons
 	mLateCancel->setMinutes(Preferences::defaultLateCancel(), true, TimePeriod::DAYS);
 	mConfirmAck->setChecked(Preferences::defaultConfirmAck());
-	mSoundPicker->set(Preferences::defaultSound(), Preferences::defaultSoundType(), Preferences::defaultSoundFile(),
+	mSoundPicker->set(Preferences::defaultSoundType(), Preferences::defaultSoundFile(),
 	                  Preferences::defaultSoundVolume(), -1, 0, Preferences::defaultSoundRepeat());
 	if (mSpecialActionsButton)
 		mSpecialActionsButton->setActions(Preferences::defaultPreAction(), Preferences::defaultPostAction());
@@ -352,11 +352,11 @@ void BirthdayDlg::slotOk()
 	config->writeEntry(QString::fromLatin1("BirthdaySuffix"), mSuffix->text());
 	config->sync();
 
-	mFlags = (mSoundPicker->beep()             ? KAEvent::BEEP : 0)
-	       | (mSoundPicker->repeat()           ? KAEvent::REPEAT_SOUND : 0)
-	       | (mConfirmAck->isChecked()         ? KAEvent::CONFIRM_ACK : 0)
-	       | (mFontColourButton->defaultFont() ? KAEvent::DEFAULT_FONT : 0)
-	       |                                     KAEvent::ANY_TIME;
+	mFlags = (mSoundPicker->sound() == SoundPicker::BEEP ? KAEvent::BEEP : 0)
+	       | (mSoundPicker->repeat()                     ? KAEvent::REPEAT_SOUND : 0)
+	       | (mConfirmAck->isChecked()                   ? KAEvent::CONFIRM_ACK : 0)
+	       | (mFontColourButton->defaultFont()           ? KAEvent::DEFAULT_FONT : 0)
+	       |                                               KAEvent::ANY_TIME;
 	KDialogBase::slotOk();
 }
 
