@@ -1,7 +1,7 @@
 /*
  *  prefdlg.cpp  -  program preferences dialog
  *  Program:  kalarm
- *  Copyright (c) 2001-2006 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001-2006 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@
 #include <kglobal.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
+#include <kshell.h>
 #include <kmessagebox.h>
 #include <kaboutdata.h>
 #include <kapplication.h>
@@ -48,6 +49,7 @@
 
 #include "alarmcalendar.h"
 #include "alarmtimewidget.h"
+#include "daemon.h"
 #include "editdlg.h"
 #include "fontcolour.h"
 #include "functions.h"
@@ -91,7 +93,7 @@ static QString xtermCommands[] = {
 =============================================================================*/
 
 KAlarmPrefDlg::KAlarmPrefDlg()
-	: KDialogBase(IconList, i18n("Preferences"), Help | Default | Ok | Apply | Cancel, Ok, 0, 0, true, true)
+	: KDialogBase(IconList, i18n("Preferences"), Help | Default | Ok | Apply | Cancel, Ok, 0, "PrefDlg", true, true)
 {
 	setIconListAllVisible(true);
 
@@ -225,26 +227,25 @@ MiscPrefTab::MiscPrefTab(QVBox* frame)
 	// Get alignment to use in QGridLayout (AlignAuto doesn't work correctly there)
 	int alignment = QApplication::reverseLayout() ? Qt::AlignRight : Qt::AlignLeft;
 
-	// Autostart alarm daemon
-	QHBox* itemBox = new QHBox(mPage);   // this is to allow left adjustment
-	mAutostartDaemon = new QCheckBox(i18n("Start alarm monitoring at lo&gin"), itemBox, "startDaemon");
-	mAutostartDaemon->setFixedSize(mAutostartDaemon->sizeHint());
-	connect(mAutostartDaemon, SIGNAL(clicked()), SLOT(slotAutostartDaemonClicked()));
-	QWhatsThis::add(mAutostartDaemon,
-	      i18n("Automatically start alarm monitoring whenever you start KDE, by running the alarm daemon (%1).\n\n"
-	           "This option should always be checked unless you intend to discontinue use of KAlarm.")
-	          .arg(QString::fromLatin1(DAEMON_APP_NAME)));
-	itemBox->setStretchFactor(new QWidget(itemBox), 1);    // left adjust the controls
-
 	QGroupBox* group = new QButtonGroup(i18n("Run Mode"), mPage, "modeGroup");
-	QGridLayout* grid = new QGridLayout(group, 6, 3, KDialog::marginHint(), KDialog::spacingHint());
+	QGridLayout* grid = new QGridLayout(group, 6, 2, KDialog::marginHint(), KDialog::spacingHint());
 	grid->setColStretch(2, 1);
 	grid->addColSpacing(0, indentWidth());
 	grid->addColSpacing(1, indentWidth());
 	grid->addRowSpacing(0, fontMetrics().lineSpacing()/2);
-	int row = 1;
 
-	// Run-in-system-tray radio button has an ID of 0
+	// Run-on-demand radio button
+	mRunOnDemand = new QRadioButton(i18n("&Run only on demand"), group, "runDemand");
+	mRunOnDemand->setFixedSize(mRunOnDemand->sizeHint());
+	connect(mRunOnDemand, SIGNAL(toggled(bool)), SLOT(slotRunModeToggled(bool)));
+	QWhatsThis::add(mRunOnDemand,
+	      i18n("Check to run KAlarm only when required.\n\n"
+	           "Notes:\n"
+	           "1. Alarms are displayed even when KAlarm is not running, since alarm monitoring is done by the alarm daemon.\n"
+	           "2. With this option selected, the system tray icon can be displayed or hidden independently of KAlarm."));
+	grid->addMultiCellWidget(mRunOnDemand, 1, 1, 0, 2, alignment);
+
+	// Run-in-system-tray radio button
 	mRunInSystemTray = new QRadioButton(i18n("Run continuously in system &tray"), group, "runTray");
 	mRunInSystemTray->setFixedSize(mRunInSystemTray->sizeHint());
 	connect(mRunInSystemTray, SIGNAL(toggled(bool)), SLOT(slotRunModeToggled(bool)));
@@ -254,58 +255,42 @@ MiscPrefTab::MiscPrefTab(QVBox* frame)
 	           "1. With this option selected, closing the system tray icon will quit KAlarm.\n"
 	           "2. You do not need to select this option in order for alarms to be displayed, since alarm monitoring is done by the alarm daemon."
 	           " Running in the system tray simply provides easy access and a status indication."));
-	grid->addMultiCellWidget(mRunInSystemTray, row, row, 0, 2, alignment);
-	++row;
-
-	mAutostartTrayIcon1 = new QCheckBox(i18n("Autostart at &login"), group, "autoTray");
-	mAutostartTrayIcon1->setFixedSize(mAutostartTrayIcon1->sizeHint());
-#ifdef AUTOSTART_BY_KALARMD
-	connect(mAutostartTrayIcon1, SIGNAL(toggled(bool)), SLOT(slotAutostartToggled(bool)));
-#endif
-	QWhatsThis::add(mAutostartTrayIcon1,
-	      i18n("Check to run KAlarm whenever you start KDE."));
-	grid->addMultiCellWidget(mAutostartTrayIcon1, row, row, 1, 2, alignment);
-	++row;
+	grid->addMultiCellWidget(mRunInSystemTray, 2, 2, 0, 2, alignment);
 
+	// Run continuously options
 	mDisableAlarmsIfStopped = new QCheckBox(i18n("Disa&ble alarms while not running"), group, "disableAl");
 	mDisableAlarmsIfStopped->setFixedSize(mDisableAlarmsIfStopped->sizeHint());
 	connect(mDisableAlarmsIfStopped, SIGNAL(toggled(bool)), SLOT(slotDisableIfStoppedToggled(bool)));
 	QWhatsThis::add(mDisableAlarmsIfStopped,
 	      i18n("Check to disable alarms whenever KAlarm is not running. Alarms will only appear while the system tray icon is visible."));
-	grid->addMultiCellWidget(mDisableAlarmsIfStopped, row, row, 1, 2, alignment);
-	++row;
+	grid->addMultiCellWidget(mDisableAlarmsIfStopped, 3, 3, 1, 2, alignment);
 
 	mQuitWarn = new QCheckBox(i18n("Warn before &quitting"), group, "disableAl");
 	mQuitWarn->setFixedSize(mQuitWarn->sizeHint());
 	QWhatsThis::add(mQuitWarn,
 	      i18n("Check to display a warning prompt before quitting KAlarm."));
-	grid->addWidget(mQuitWarn, row, 2, alignment);
-	++row;
+	grid->addWidget(mQuitWarn, 4, 2, alignment);
 
-	// Run-on-demand radio button has an ID of 3
-	mRunOnDemand = new QRadioButton(i18n("&Run only on demand"), group, "runDemand");
-	mRunOnDemand->setFixedSize(mRunOnDemand->sizeHint());
-	connect(mRunOnDemand, SIGNAL(toggled(bool)), SLOT(slotRunModeToggled(bool)));
-	QWhatsThis::add(mRunOnDemand,
-	      i18n("Check to run KAlarm only when required.\n\n"
-	           "Notes:\n"
-	           "1. Alarms are displayed even when KAlarm is not running, since alarm monitoring is done by the alarm daemon.\n"
-	           "2. With this option selected, the system tray icon can be displayed or hidden independently of KAlarm."));
-	grid->addMultiCellWidget(mRunOnDemand, row, row, 0, 2, alignment);
-	++row;
-
-	mAutostartTrayIcon2 = new QCheckBox(i18n("Autostart system tray &icon at login"), group, "autoRun");
-	mAutostartTrayIcon2->setFixedSize(mAutostartTrayIcon2->sizeHint());
+	mAutostartTrayIcon = new QCheckBox(i18n("Autostart at &login"), group, "autoTray");
 #ifdef AUTOSTART_BY_KALARMD
-	connect(mAutostartTrayIcon2, SIGNAL(toggled(bool)), SLOT(slotAutostartToggled(bool)));
+	connect(mAutostartTrayIcon, SIGNAL(toggled(bool)), SLOT(slotAutostartToggled(bool)));
 #endif
-	QWhatsThis::add(mAutostartTrayIcon2,
-	      i18n("Check to display the system tray icon whenever you start KDE."));
-	grid->addMultiCellWidget(mAutostartTrayIcon2, row, row, 1, 2, alignment);
+	grid->addMultiCellWidget(mAutostartTrayIcon, 5, 5, 0, 2, alignment);
+
+	// Autostart alarm daemon
+	mAutostartDaemon = new QCheckBox(i18n("Start alarm monitoring at lo&gin"), group, "startDaemon");
+	mAutostartDaemon->setFixedSize(mAutostartDaemon->sizeHint());
+	connect(mAutostartDaemon, SIGNAL(clicked()), SLOT(slotAutostartDaemonClicked()));
+	QWhatsThis::add(mAutostartDaemon,
+	      i18n("Automatically start alarm monitoring whenever you start KDE, by running the alarm daemon (%1).\n\n"
+	           "This option should always be checked unless you intend to discontinue use of KAlarm.")
+	          .arg(QString::fromLatin1(DAEMON_APP_NAME)));
+	grid->addMultiCellWidget(mAutostartDaemon, 6, 6, 0, 2, alignment);
+
 	group->setFixedHeight(group->sizeHint().height());
 
 	// Start-of-day time
-	itemBox = new QHBox(mPage);
+	QHBox* itemBox = new QHBox(mPage);
 	QHBox* box = new QHBox(itemBox);   // this is to control the QWhatsThis text display area
 	box->setSpacing(KDialog::spacingHint());
 	QLabel* label = new QLabel(i18n("&Start of day for date-only alarms:"), box);
@@ -370,7 +355,7 @@ MiscPrefTab::MiscPrefTab(QVBox* frame)
 	      i18n("Choose which application to use when a command alarm is executed in a terminal window"));
 	grid = new QGridLayout(group, 1, 3, KDialog::marginHint(), KDialog::spacingHint());
 	grid->addRowSpacing(0, fontMetrics().lineSpacing()/2);
-	row = 0;
+	int row = 0;
 
 	mXtermType = new QButtonGroup(group);
 	mXtermType->hide();
@@ -379,11 +364,10 @@ MiscPrefTab::MiscPrefTab(QVBox* frame)
 	for (mXtermCount = 0;  !xtermCommands[mXtermCount].isNull();  ++mXtermCount)
 	{
 		QString cmd = xtermCommands[mXtermCount];
-		int i = cmd.find(' ');    // find the end of the terminal window name
-		QString term = cmd.left(i > 0 ? i : 1000);
-		if (KStandardDirs::findExe(term).isEmpty())
+		QStringList args = KShell::splitArgs(cmd);
+		if (args.isEmpty()  ||  KStandardDirs::findExe(args[0]).isEmpty())
 			continue;
-		QRadioButton* radio = new QRadioButton(term, group);
+		QRadioButton* radio = new QRadioButton(args[0], group);
 		radio->setMinimumSize(radio->sizeHint());
 		mXtermType->insert(radio, mXtermCount);
 		cmd.replace("%t", kapp->aboutData()->programName());
@@ -413,14 +397,13 @@ MiscPrefTab::MiscPrefTab(QVBox* frame)
 
 void MiscPrefTab::restore()
 {
-	mAutostartDaemon->setChecked(Preferences::mAutostartDaemon);
+	mAutostartDaemon->setChecked(Daemon::autoStart());
 	bool systray = Preferences::mRunInSystemTray;
 	mRunInSystemTray->setChecked(systray);
 	mRunOnDemand->setChecked(!systray);
 	mDisableAlarmsIfStopped->setChecked(Preferences::mDisableAlarmsIfStopped);
 	mQuitWarn->setChecked(Preferences::quitWarn());
-	mAutostartTrayIcon1->setChecked(Preferences::mAutostartTrayIcon);
-	mAutostartTrayIcon2->setChecked(Preferences::mAutostartTrayIcon);
+	mAutostartTrayIcon->setChecked(Preferences::mAutostartTrayIcon);
 	mConfirmAlarmDeletion->setChecked(Preferences::confirmAlarmDeletion());
 	mStartOfDay->setValue(Preferences::mStartOfDay);
 	setExpiredControls(Preferences::mExpiredKeepDays);
@@ -451,9 +434,8 @@ void MiscPrefTab::apply(bool syncToDisc)
 			xtermID = 0;       // 'Other' is only acceptable if it's non-blank
 		else
 		{
-			int i = cmd.find(' ');    // find the end of the terminal window name
-			if (i > 0)
-				cmd = cmd.left(i);
+			QStringList args = KShell::splitArgs(cmd);
+			cmd = args.isEmpty() ? QString::null : args[0];
 			if (KStandardDirs::findExe(cmd).isEmpty())
 			{
 				mXtermCommand->setFocus();
@@ -468,12 +450,14 @@ void MiscPrefTab::apply(bool syncToDisc)
 	Preferences::mDisableAlarmsIfStopped = mDisableAlarmsIfStopped->isChecked();
 	if (mQuitWarn->isEnabled())
 		Preferences::setQuitWarn(mQuitWarn->isChecked());
-	Preferences::mAutostartTrayIcon = systray ? mAutostartTrayIcon1->isChecked() : mAutostartTrayIcon2->isChecked();
+	Preferences::mAutostartTrayIcon = mAutostartTrayIcon->isChecked();
 #ifdef AUTOSTART_BY_KALARMD
-	Preferences::mAutostartDaemon = mAutostartDaemon->isChecked() || Preferences::mAutostartTrayIcon;
+	bool newAutostartDaemon = mAutostartDaemon->isChecked() || Preferences::mAutostartTrayIcon;
 #else
-	Preferences::mAutostartDaemon = mAutostartDaemon->isChecked();
+	bool newAutostartDaemon = mAutostartDaemon->isChecked();
 #endif
+	if (newAutostartDaemon != Daemon::autoStart())
+		Daemon::enableAutoStart(newAutostartDaemon);
 	Preferences::setConfirmAlarmDeletion(mConfirmAlarmDeletion->isChecked());
 	int sod = mStartOfDay->value();
 	Preferences::mStartOfDay.setHMS(sod/60, sod%60, 0);
@@ -485,14 +469,13 @@ void MiscPrefTab::apply(bool syncToDisc)
 
 void MiscPrefTab::setDefaults()
 {
-	mAutostartDaemon->setChecked(Preferences::default_autostartDaemon);
+	mAutostartDaemon->setChecked(true);
 	bool systray = Preferences::default_runInSystemTray;
 	mRunInSystemTray->setChecked(systray);
 	mRunOnDemand->setChecked(!systray);
 	mDisableAlarmsIfStopped->setChecked(Preferences::default_disableAlarmsIfStopped);
 	mQuitWarn->setChecked(Preferences::default_quitWarn);
-	mAutostartTrayIcon1->setChecked(Preferences::default_autostartTrayIcon);
-	mAutostartTrayIcon2->setChecked(Preferences::default_autostartTrayIcon);
+	mAutostartTrayIcon->setChecked(Preferences::default_autostartTrayIcon);
 	mConfirmAlarmDeletion->setChecked(Preferences::default_confirmAlarmDeletion);
 	mStartOfDay->setValue(Preferences::default_startOfDay);
 	setExpiredControls(Preferences::default_expiredKeepDays);
@@ -513,9 +496,10 @@ void MiscPrefTab::slotAutostartDaemonClicked()
 
 void MiscPrefTab::slotRunModeToggled(bool)
 {
-	bool systray = (mRunInSystemTray->isOn());
-	mAutostartTrayIcon2->setEnabled(!systray);
-	mAutostartTrayIcon1->setEnabled(systray);
+	bool systray = mRunInSystemTray->isOn();
+	mAutostartTrayIcon->setText(systray ? i18n("Autostart at &login") : i18n("Autostart system tray &icon at login"));
+	QWhatsThis::add(mAutostartTrayIcon, (systray ? i18n("Check to run KAlarm whenever you start KDE.")
+	                                             : i18n("Check to display the system tray icon whenever you start KDE.")));
 	mDisableAlarmsIfStopped->setEnabled(systray);
 	slotDisableIfStoppedToggled(true);
 }
@@ -527,8 +511,7 @@ void MiscPrefTab::slotRunModeToggled(bool)
 void MiscPrefTab::slotAutostartToggled(bool)
 {
 #ifdef AUTOSTART_BY_KALARMD
-	bool autostart = mRunInSystemTray->isChecked() ? mAutostartTrayIcon1->isChecked() : mAutostartTrayIcon2->isChecked();
-	mAutostartDaemon->setEnabled(!autostart);
+	mAutostartDaemon->setEnabled(!mAutostartTrayIcon->isChecked());
 #endif
 }
 
@@ -926,36 +909,24 @@ EditPrefTab::EditPrefTab(QVBox* frame)
 	layout = new QVBoxLayout(bgroup, KDialog::marginHint(), KDialog::spacingHint());
 	layout->addSpacing(groupTopMargin);
 
-	mSound = new QCheckBox(SoundPicker::i18n_s_Sound(), bgroup, "defSound");
+	QBoxLayout* hlayout = new QHBoxLayout(layout, KDialog::spacingHint());
+	mSound = new QComboBox(false, bgroup, "defSound");
+	mSound->insertItem(SoundPicker::i18n_None());         // index 0
+	mSound->insertItem(SoundPicker::i18n_Beep());         // index 1
+	mSound->insertItem(SoundPicker::i18n_File());         // index 2
+	if (theApp()->speechEnabled())
+		mSound->insertItem(SoundPicker::i18n_Speak());  // index 3
 	mSound->setMinimumSize(mSound->sizeHint());
 	QWhatsThis::add(mSound, defsetting.arg(SoundPicker::i18n_Sound()));
-	layout->addWidget(mSound, 0, Qt::AlignAuto);
+	hlayout->addWidget(mSound);
+	hlayout->addStretch(1);
 
-	box = new QHBox(bgroup);
-	box->setSpacing(KDialog::spacingHint());
-	layout->addWidget(box, 0, Qt::AlignAuto);
-
-	mBeep = new QRadioButton(SoundPicker::i18n_b_Beep(), box, "defBeep");
-	bgroup->insert(mBeep);
-	mBeep->setMinimumSize(mBeep->sizeHint());
-	QWhatsThis::add(mBeep,
-	      soundSetting.arg(SoundPicker::i18n_Beep()).arg(SoundPicker::i18n_Sound()));
-	mFile = new QRadioButton(SoundPicker::i18n_File(), box, "defFile");
-	bgroup->insert(mFile);
-	mFile->setMinimumSize(mFile->sizeHint());
-	QWhatsThis::add(mFile,
-	      soundSetting.arg(SoundPicker::i18n_File()).arg(SoundPicker::i18n_Sound()));
-	if (theApp()->speechEnabled())
-	{
-		mSpeak = new QRadioButton(SoundPicker::i18n_Speak(), box, "defSpeak");
-		mSpeak->setMinimumSize(mSpeak->sizeHint());
-		QWhatsThis::add(mSpeak,
-		      soundSetting.arg(SoundPicker::i18n_Speak()).arg(SoundPicker::i18n_Sound()));
-		bgroup->insert(mSpeak);
-	}
-	else
-		mSpeak = 0;
-	box->setStretchFactor(new QWidget(box), 1);    // left adjust the controls
+#ifndef WITHOUT_ARTS
+	mSoundRepeat = new QCheckBox(i18n("Repea&t sound file"), bgroup, "defRepeatSound");
+	mSoundRepeat->setMinimumSize(mSoundRepeat->sizeHint());
+	QWhatsThis::add(mSoundRepeat, i18n("sound file \"Repeat\" checkbox", "The default setting for sound file \"%1\" in the alarm edit dialog.").arg(SoundDlg::i18n_Repeat()));
+	hlayout->addWidget(mSoundRepeat);
+#endif
 
 	box = new QHBox(bgroup);   // this is to control the QWhatsThis text display area
 	box->setSpacing(KDialog::spacingHint());
@@ -972,13 +943,6 @@ EditPrefTab::EditPrefTab(QVBox* frame)
 	      i18n("Enter the default sound file to use in the alarm edit dialog."));
 	box->setFixedHeight(box->sizeHint().height());
 	layout->addWidget(box);
-
-#ifndef WITHOUT_ARTS
-	mSoundRepeat = new QCheckBox(i18n("Repea&t sound file"), bgroup, "defRepeatSound");
-	mSoundRepeat->setMinimumSize(mSoundRepeat->sizeHint());
-	QWhatsThis::add(mSoundRepeat, i18n("sound file \"Repeat\" checkbox", "The default setting for sound file \"%1\" in the alarm edit dialog.").arg(SoundDlg::i18n_Repeat()));
-	layout->addWidget(mSoundRepeat, 0, Qt::AlignAuto);
-#endif
 	bgroup->setFixedHeight(bgroup->sizeHint().height());
 
 	// COMMAND ALARMS
@@ -1076,8 +1040,7 @@ void EditPrefTab::restore()
 	mConfirmAck->setChecked(Preferences::mDefaultConfirmAck);
 	mReminderUnits->setCurrentItem(Preferences::mDefaultReminderUnits);
 	mSpecialActionsButton->setActions(Preferences::mDefaultPreAction, Preferences::mDefaultPostAction);
-	mSound->setChecked(Preferences::mDefaultSound);
-	setSoundType(Preferences::mDefaultSoundType);
+	mSound->setCurrentItem(soundIndex(Preferences::mDefaultSoundType));
 	mSoundFile->setText(Preferences::mDefaultSoundFile);
 #ifndef WITHOUT_ARTS
 	mSoundRepeat->setChecked(Preferences::mDefaultSoundRepeat);
@@ -1098,11 +1061,15 @@ void EditPrefTab::apply(bool syncToDisc)
 	Preferences::mDefaultReminderUnits    = static_cast<TimePeriod::Units>(mReminderUnits->currentItem());
 	Preferences::mDefaultPreAction        = mSpecialActionsButton->preAction();
 	Preferences::mDefaultPostAction       = mSpecialActionsButton->postAction();
-	Preferences::mDefaultSound            = mSound->isChecked();
+	switch (mSound->currentItem())
+	{
+		case 3:  Preferences::mDefaultSoundType = SoundPicker::SPEAK;      break;
+		case 2:  Preferences::mDefaultSoundType = SoundPicker::PLAY_FILE;  break;
+		case 1:  Preferences::mDefaultSoundType = SoundPicker::BEEP;       break;
+		case 0:
+		default: Preferences::mDefaultSoundType = SoundPicker::NONE;       break;
+	}
 	Preferences::mDefaultSoundFile        = mSoundFile->text();
-	Preferences::mDefaultSoundType        = mSpeak && mSpeak->isOn() ? SoundPicker::SPEAK
-	                                      : mFile->isOn()            ? SoundPicker::PLAY_FILE
-	                                      :                            SoundPicker::BEEP;
 #ifndef WITHOUT_ARTS
 	Preferences::mDefaultSoundRepeat      = mSoundRepeat->isChecked();
 #endif
@@ -1133,8 +1100,7 @@ void EditPrefTab::setDefaults()
 	mConfirmAck->setChecked(Preferences::default_defaultConfirmAck);
 	mReminderUnits->setCurrentItem(Preferences::default_defaultReminderUnits);
 	mSpecialActionsButton->setActions(Preferences::default_defaultPreAction, Preferences::default_defaultPostAction);
-	mSound->setChecked(Preferences::default_defaultSound);
-	setSoundType(Preferences::default_defaultSoundType);
+	mSound->setCurrentItem(soundIndex(Preferences::default_defaultSoundType));
 	mSoundFile->setText(Preferences::default_defaultSoundFile);
 #ifndef WITHOUT_ARTS
 	mSoundRepeat->setChecked(Preferences::default_defaultSoundRepeat);
@@ -1156,6 +1122,18 @@ void EditPrefTab::slotBrowseSoundFile()
 		mSoundFile->setText(url);
 }
 
+int EditPrefTab::soundIndex(SoundPicker::Type type)
+{
+	switch (type)
+	{
+		case SoundPicker::SPEAK:      return 3;
+		case SoundPicker::PLAY_FILE:  return 2;
+		case SoundPicker::BEEP:       return 1;
+		case SoundPicker::NONE:
+		default:                      return 0;
+	}
+}
+
 int EditPrefTab::recurIndex(RecurrenceEdit::RepeatType type)
 {
 	switch (type)
@@ -1171,30 +1149,9 @@ int EditPrefTab::recurIndex(RecurrenceEdit::RepeatType type)
 	}
 }
 
-void EditPrefTab::setSoundType(SoundPicker::Type type)
-{
-	switch (type)
-	{
-		case SoundPicker::PLAY_FILE:
-			mFile->setChecked(true);
-			break;
-		case SoundPicker::SPEAK:
-			if (mSpeak)
-			{
-				mSpeak->setChecked(true);
-				break;
-			}
-			// fall through to BEEP
-		case SoundPicker::BEEP:
-		default:
-			mBeep->setChecked(true);
-			break;
-	}
-}
-
 QString EditPrefTab::validate()
 {
-	if (mFile->isOn()  &&  mSoundFile->text().isEmpty())
+	if (mSound->currentItem() == SoundPicker::PLAY_FILE  &&  mSoundFile->text().isEmpty())
 	{
 		mSoundFile->setFocus();
 		return i18n("You must enter a sound file when %1 is selected as the default sound type").arg(SoundPicker::i18n_File());;
