@@ -1,7 +1,7 @@
 /*
  *  preferences.cpp  -  program preference settings
  *  Program:  kalarm
- *  (C) 2001 - 2005 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2001-2006 by David Jarvie <software@astrojar.org.uk>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,9 +13,9 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include "kalarm.h"
@@ -31,80 +31,126 @@
 #include <libkpimidentities/identitymanager.h>
 
 #include "daemon.h"
+#include "functions.h"
 #include "kamail.h"
 #include "messagebox.h"
 #include "preferences.moc"
 
 
+static QString translateXTermPath(KConfig*, const QString& cmdline, bool write);
+
 Preferences* Preferences::mInstance = 0;
 
 // Default config file settings
 QColor defaultMessageColours[] = { Qt::red, Qt::green, Qt::blue, Qt::cyan, Qt::magenta, Qt::yellow, Qt::white, Qt::lightGray, Qt::black, QColor() };
-const ColourList Preferences::default_messageColours(defaultMessageColours);
-const QColor     Preferences::default_defaultBgColour(Qt::red);
-const QColor     Preferences::default_defaultFgColour(Qt::black);
-QFont            Preferences::default_messageFont;    // initialised in constructor
-const QTime      Preferences::default_startOfDay(0, 0);
-const bool       Preferences::default_autostartDaemon          = true;
-const bool       Preferences::default_runInSystemTray          = true;
-const bool       Preferences::default_disableAlarmsIfStopped   = true;
-const bool       Preferences::default_quitWarn                 = true;
-const bool       Preferences::default_autostartTrayIcon        = true;
-const bool       Preferences::default_confirmAlarmDeletion     = true;
-const bool       Preferences::default_modalMessages            = true;
-const int        Preferences::default_messageButtonDelay       = 0;     // (seconds)
-const bool       Preferences::default_showExpiredAlarms        = false;
-const bool       Preferences::default_showAlarmTime            = true;
-const bool       Preferences::default_showTimeToAlarm          = false;
-const int        Preferences::default_tooltipAlarmCount        = 5;
-const bool       Preferences::default_showTooltipAlarmTime     = true;
-const bool       Preferences::default_showTooltipTimeToAlarm   = true;
-const QString    Preferences::default_tooltipTimeToPrefix      = QString::fromLatin1("+");
-const int        Preferences::default_daemonTrayCheckInterval  = 10;     // (seconds)
-const bool       Preferences::default_emailCopyToKMail         = false;
-const bool       Preferences::default_emailQueuedNotify        = false;
-const QColor     Preferences::default_disabledColour(Qt::lightGray);
-const QColor     Preferences::default_expiredColour(Qt::darkRed);
-const int        Preferences::default_expiredKeepDays          = 7;
-const QString    Preferences::default_defaultSoundFile         = QString::null;
-const float      Preferences::default_defaultSoundVolume       = -1;
-const int        Preferences::default_defaultLateCancel        = 0;
-const bool       Preferences::default_defaultAutoClose         = false;
-const bool       Preferences::default_defaultSound             = false;
-const bool       Preferences::default_defaultSoundRepeat       = false;
-const bool       Preferences::default_defaultBeep              = false;
-const bool       Preferences::default_defaultConfirmAck        = false;
-const bool       Preferences::default_defaultCmdScript         = false;
-const bool       Preferences::default_defaultCmdXterm          = false;
-const bool       Preferences::default_defaultEmailBcc          = false;
-const QString    Preferences::default_emailAddress             = QString::null;
-const QString    Preferences::default_emailBccAddress          = QString::null;
-const Preferences::MailClient    Preferences::default_emailClient          = KMAIL;
-#if KDE_VERSION >= 210
-const Preferences::MailFrom      Preferences::default_emailBccFrom         = MAIL_FROM_CONTROL_CENTRE;
-#else
-const Preferences::MailFrom      Preferences::default_emailBccFrom         = MAIL_FROM_ADDR;
-#endif
-const Preferences::Feb29Type     Preferences::default_feb29RecurType       = FEB29_MAR1;
-const RecurrenceEdit::RepeatType Preferences::default_defaultRecurPeriod   = RecurrenceEdit::NO_RECUR;
-const TimePeriod::Units          Preferences::default_defaultReminderUnits = TimePeriod::HOURS_MINUTES;
-const QString    Preferences::default_defaultPreAction;
-const QString    Preferences::default_defaultPostAction;
+const ColourList                 Preferences::default_messageColours(defaultMessageColours);
+const QColor                     Preferences::default_defaultBgColour(Qt::red);
+const QColor                     Preferences::default_defaultFgColour(Qt::black);
+QFont                            Preferences::mDefault_messageFont;    // initialised in constructor
+const QTime                      Preferences::default_startOfDay(0, 0);
+const bool                       Preferences::default_runInSystemTray         = true;
+const bool                       Preferences::default_disableAlarmsIfStopped  = true;
+const bool                       Preferences::default_quitWarn                = true;
+const bool                       Preferences::default_autostartTrayIcon       = true;
+const bool                       Preferences::default_confirmAlarmDeletion    = true;
+const bool                       Preferences::default_modalMessages           = true;
+const int                        Preferences::default_messageButtonDelay      = 0;     // (seconds)
+const bool                       Preferences::default_showExpiredAlarms       = false;
+const bool                       Preferences::default_showAlarmTime           = true;
+const bool                       Preferences::default_showTimeToAlarm         = false;
+const int                        Preferences::default_tooltipAlarmCount       = 5;
+const bool                       Preferences::default_showTooltipAlarmTime    = true;
+const bool                       Preferences::default_showTooltipTimeToAlarm  = true;
+const QString                    Preferences::default_tooltipTimeToPrefix     = QString::fromLatin1("+");
+const int                        Preferences::default_daemonTrayCheckInterval = 10;     // (seconds)
+const bool                       Preferences::default_emailCopyToKMail        = false;
+const bool                       Preferences::default_emailQueuedNotify       = false;
+const QColor                     Preferences::default_disabledColour(Qt::lightGray);
+const QColor                     Preferences::default_expiredColour(Qt::darkRed);
+const int                        Preferences::default_expiredKeepDays         = 7;
+const QString                    Preferences::default_defaultSoundFile        = QString::null;
+const float                      Preferences::default_defaultSoundVolume      = -1;
+const int                        Preferences::default_defaultLateCancel       = 0;
+const bool                       Preferences::default_defaultAutoClose        = false;
+const bool                       Preferences::default_defaultCopyToKOrganizer = false;
+const bool                       Preferences::default_defaultSoundRepeat      = false;
+const SoundPicker::Type          Preferences::default_defaultSoundType        = SoundPicker::BEEP;
+const bool                       Preferences::default_defaultConfirmAck       = false;
+const bool                       Preferences::default_defaultCmdScript        = false;
+const EditAlarmDlg::CmdLogType   Preferences::default_defaultCmdLogType       = EditAlarmDlg::DISCARD_OUTPUT;
+const bool                       Preferences::default_defaultEmailBcc         = false;
+const QString                    Preferences::default_emailAddress            = QString::null;
+const QString                    Preferences::default_emailBccAddress         = QString::null;
+const Preferences::MailClient    Preferences::default_emailClient             = KMAIL;
+const Preferences::MailFrom      Preferences::default_emailBccFrom            = MAIL_FROM_CONTROL_CENTRE;
+const RecurrenceEdit::RepeatType Preferences::default_defaultRecurPeriod      = RecurrenceEdit::NO_RECUR;
+const KARecurrence::Feb29Type    Preferences::default_defaultFeb29Type        = KARecurrence::FEB29_MAR1;
+const TimePeriod::Units          Preferences::default_defaultReminderUnits    = TimePeriod::HOURS_MINUTES;
+const QString                    Preferences::default_defaultPreAction;
+const QString                    Preferences::default_defaultPostAction;
 
 Preferences::MailFrom Preferences::default_emailFrom()
 {
-#if KDE_VERSION >= 210
 	return KAMail::identitiesExist() ? MAIL_FROM_KMAIL : MAIL_FROM_CONTROL_CENTRE;
-#else
-	return KAMail::identitiesExist() ? MAIL_FROM_KMAIL : MAIL_FROM_ADDR;
-#endif
 }
 
+// Active config file settings
+ColourList                 Preferences::mMessageColours;
+QColor                     Preferences::mDefaultBgColour;
+QFont                      Preferences::mMessageFont;
+QTime                      Preferences::mStartOfDay;
+bool                       Preferences::mRunInSystemTray;
+bool                       Preferences::mDisableAlarmsIfStopped;
+bool                       Preferences::mAutostartTrayIcon;
+KARecurrence::Feb29Type    Preferences::mDefaultFeb29Type;
+bool                       Preferences::mModalMessages;
+int                        Preferences::mMessageButtonDelay;
+bool                       Preferences::mShowExpiredAlarms;
+bool                       Preferences::mShowAlarmTime;
+bool                       Preferences::mShowTimeToAlarm;
+int                        Preferences::mTooltipAlarmCount;
+bool                       Preferences::mShowTooltipAlarmTime;
+bool                       Preferences::mShowTooltipTimeToAlarm;
+QString                    Preferences::mTooltipTimeToPrefix;
+int                        Preferences::mDaemonTrayCheckInterval;
+QString                    Preferences::mEmailAddress;
+QString                    Preferences::mEmailBccAddress;
+Preferences::MailClient    Preferences::mEmailClient;
+Preferences::MailFrom      Preferences::mEmailFrom;
+Preferences::MailFrom      Preferences::mEmailBccFrom;
+bool                       Preferences::mEmailCopyToKMail;
+QString                    Preferences::mCmdXTermCommand;
+QColor                     Preferences::mDisabledColour;
+QColor                     Preferences::mExpiredColour;
+int                        Preferences::mExpiredKeepDays;
+// Default settings for Edit Alarm dialog
+QString                    Preferences::mDefaultSoundFile;
+float                      Preferences::mDefaultSoundVolume;
+int                        Preferences::mDefaultLateCancel;
+bool                       Preferences::mDefaultAutoClose;
+bool                       Preferences::mDefaultCopyToKOrganizer;
+SoundPicker::Type          Preferences::mDefaultSoundType;
+bool                       Preferences::mDefaultSoundRepeat;
+bool                       Preferences::mDefaultConfirmAck;
+bool                       Preferences::mDefaultEmailBcc;
+bool                       Preferences::mDefaultCmdScript;
+EditAlarmDlg::CmdLogType   Preferences::mDefaultCmdLogType;
+QString                    Preferences::mDefaultCmdLogFile;
+RecurrenceEdit::RepeatType Preferences::mDefaultRecurPeriod;
+TimePeriod::Units          Preferences::mDefaultReminderUnits;
+QString                    Preferences::mDefaultPreAction;
+QString                    Preferences::mDefaultPostAction;
+// Change tracking
+QTime                      Preferences::mOldStartOfDay;
+bool                       Preferences::mStartOfDayChanged;
+
+
 static const QString defaultFeb29RecurType    = QString::fromLatin1("Mar1");
 static const QString defaultEmailClient       = QString::fromLatin1("kmail");
 
 // Config file entry names
 static const QString GENERAL_SECTION          = QString::fromLatin1("General");
+static const QString VERSION_NUM              = QString::fromLatin1("Version");
 static const QString MESSAGE_COLOURS          = QString::fromLatin1("MessageColours");
 static const QString MESSAGE_BG_COLOUR        = QString::fromLatin1("MessageBackgroundColour");
 static const QString MESSAGE_FONT             = QString::fromLatin1("MessageFont");
@@ -136,22 +182,22 @@ static const QString DEFAULTS_SECTION         = QString::fromLatin1("Defaults");
 static const QString DEF_LATE_CANCEL          = QString::fromLatin1("DefLateCancel");
 static const QString DEF_AUTO_CLOSE           = QString::fromLatin1("DefAutoClose");
 static const QString DEF_CONFIRM_ACK          = QString::fromLatin1("DefConfirmAck");
-static const QString DEF_SOUND                = QString::fromLatin1("DefSound");
+static const QString DEF_COPY_TO_KORG         = QString::fromLatin1("DefCopyKOrg");
+static const QString DEF_SOUND_TYPE           = QString::fromLatin1("DefSoundType");
 static const QString DEF_SOUND_FILE           = QString::fromLatin1("DefSoundFile");
 static const QString DEF_SOUND_VOLUME         = QString::fromLatin1("DefSoundVolume");
 static const QString DEF_SOUND_REPEAT         = QString::fromLatin1("DefSoundRepeat");
-static const QString DEF_BEEP                 = QString::fromLatin1("DefBeep");
 static const QString DEF_CMD_SCRIPT           = QString::fromLatin1("DefCmdScript");
-static const QString DEF_CMD_XTERM            = QString::fromLatin1("DefCmdXterm");
+static const QString DEF_CMD_LOG_TYPE         = QString::fromLatin1("DefCmdLogType");
+static const QString DEF_LOG_FILE             = QString::fromLatin1("DefLogFile");
 static const QString DEF_EMAIL_BCC            = QString::fromLatin1("DefEmailBcc");
 static const QString DEF_RECUR_PERIOD         = QString::fromLatin1("DefRecurPeriod");
 static const QString DEF_REMIND_UNITS         = QString::fromLatin1("DefRemindUnits");
 static const QString DEF_PRE_ACTION           = QString::fromLatin1("DefPreAction");
 static const QString DEF_POST_ACTION          = QString::fromLatin1("DefPostAction");
-// Obsolete - compatibility with pre-1.2.1
-static const QString EMAIL_ADDRESS            = QString::fromLatin1("EmailAddress");
-static const QString EMAIL_USE_CONTROL_CENTRE = QString::fromLatin1("EmailUseControlCenter");
-static const QString EMAIL_BCC_USE_CONTROL_CENTRE = QString::fromLatin1("EmailBccUseControlCenter");
+
+// Config file entry name for temporary use
+static const QString TEMP                     = QString::fromLatin1("Temp");
 
 // Values for EmailFrom entry
 static const QString FROM_CONTROL_CENTRE      = QString::fromLatin1("@ControlCenter");
@@ -163,7 +209,7 @@ const QString Preferences::CONFIRM_ALARM_DELETION = QString::fromLatin1("Confirm
 const QString Preferences::EMAIL_QUEUED_NOTIFY    = QString::fromLatin1("EmailQueuedNotify");
 
 static const int SODxor = 0x82451630;
-inline int Preferences::startOfDayCheck() const
+inline int Preferences::startOfDayCheck()
 {
 	// Combine with a 'random' constant to prevent 'clever' people fiddling the
 	// value, and thereby screwing things up.
@@ -171,31 +217,50 @@ inline int Preferences::startOfDayCheck() const
 }
 
 
-Preferences* Preferences::instance()
+void Preferences::initialise()
 {
 	if (!mInstance)
 	{
-		convertOldPrefs();    // convert preferences written by previous KAlarm versions
+		// Initialise static variables here to avoid static initialisation
+		// sequencing errors.
+		mDefault_messageFont = QFont(KGlobalSettings::generalFont().family(), 16, QFont::Bold);
 
 		mInstance = new Preferences;
 
+		convertOldPrefs();    // convert preferences written by previous KAlarm versions
+		read();
+
 		// Set the default button for the Quit warning message box to Cancel
 		MessageBox::setContinueDefault(QUIT_WARN, KMessageBox::Cancel);
 		MessageBox::setDefaultShouldBeShownContinue(QUIT_WARN, default_quitWarn);
 		MessageBox::setDefaultShouldBeShownContinue(EMAIL_QUEUED_NOTIFY, default_emailQueuedNotify);
 		MessageBox::setDefaultShouldBeShownContinue(CONFIRM_ALARM_DELETION, default_confirmAlarmDeletion);
 	}
-	return mInstance;
 }
 
-Preferences::Preferences()
-	: QObject(0)
+void Preferences::connect(const char* signal, const QObject* receiver, const char* member)
 {
-	// Initialise static variables here to avoid static initialisation
-	// sequencing errors.
-	default_messageFont = QFont(KGlobalSettings::generalFont().family(), 16, QFont::Bold);
+	initialise();
+	QObject::connect(mInstance, signal, receiver, member);
+}
+
+void Preferences::emitStartOfDayChanged()
+{
+	emit startOfDayChanged(mOldStartOfDay);
+}
+
+void Preferences::emitPreferencesChanged()
+{
+	emit preferencesChanged();
+}
+
+/******************************************************************************
+* Read preference values from the config file.
+*/
+void Preferences::read()
+{
+	initialise();
 
-	// Read preference values from the config file
 	KConfig* config = KGlobal::config();
 	config->setGroup(GENERAL_SECTION);
 	QStringList cols = config->readListEntry(MESSAGE_COLOURS);
@@ -212,12 +277,10 @@ Preferences::Preferences()
 		}
 	}
 	mDefaultBgColour          = config->readColorEntry(MESSAGE_BG_COLOUR, &default_defaultBgColour);
-	mMessageFont              = config->readFontEntry(MESSAGE_FONT, &default_messageFont);
+	mMessageFont              = config->readFontEntry(MESSAGE_FONT, &mDefault_messageFont);
 	mRunInSystemTray          = config->readBoolEntry(RUN_IN_SYSTEM_TRAY, default_runInSystemTray);
 	mDisableAlarmsIfStopped   = config->readBoolEntry(DISABLE_IF_STOPPED, default_disableAlarmsIfStopped);
 	mAutostartTrayIcon        = config->readBoolEntry(AUTOSTART_TRAY, default_autostartTrayIcon);
-	QCString feb29            = config->readEntry(FEB29_RECUR_TYPE, defaultFeb29RecurType).local8Bit();
-	mFeb29RecurType           = (feb29 == "Mar1") ? FEB29_MAR1 : (feb29 == "Feb28") ? FEB29_FEB28 : FEB29_NONE;
 	mModalMessages            = config->readBoolEntry(MODAL_MESSAGES, default_modalMessages);
 	mMessageButtonDelay       = config->readNumEntry(MESSAGE_BUTTON_DELAY, default_messageButtonDelay);
 	mShowExpiredAlarms        = config->readBoolEntry(SHOW_EXPIRED_ALARMS, default_showExpiredAlarms);
@@ -245,7 +308,7 @@ Preferences::Preferences()
 		mEmailAddress     = from;
 	if (mEmailBccFrom == MAIL_FROM_ADDR)
 		mEmailBccAddress  = bccFrom;
-	mCmdXTermCommand          = config->readPathEntry(CMD_XTERM_COMMAND);
+	mCmdXTermCommand          = translateXTermPath(config, config->readEntry(CMD_XTERM_COMMAND), false);
 	QDateTime defStartOfDay(QDate(1900,1,1), default_startOfDay);
 	mStartOfDay               = config->readDateTimeEntry(START_OF_DAY, &defStartOfDay).time();
 	mOldStartOfDay.setHMS(0,0,0);
@@ -255,12 +318,15 @@ Preferences::Preferences()
 	mDisabledColour           = config->readColorEntry(DISABLED_COLOUR, &default_disabledColour);
 	mExpiredColour            = config->readColorEntry(EXPIRED_COLOUR, &default_expiredColour);
 	mExpiredKeepDays          = config->readNumEntry(EXPIRED_KEEP_DAYS, default_expiredKeepDays);
+
 	config->setGroup(DEFAULTS_SECTION);
 	mDefaultLateCancel        = static_cast<int>(config->readUnsignedNumEntry(DEF_LATE_CANCEL, default_defaultLateCancel));
 	mDefaultAutoClose         = config->readBoolEntry(DEF_AUTO_CLOSE, default_defaultAutoClose);
 	mDefaultConfirmAck        = config->readBoolEntry(DEF_CONFIRM_ACK, default_defaultConfirmAck);
-	mDefaultSound             = config->readBoolEntry(DEF_SOUND, default_defaultSound);
-	mDefaultBeep              = config->readBoolEntry(DEF_BEEP, default_defaultBeep);
+	mDefaultCopyToKOrganizer  = config->readBoolEntry(DEF_COPY_TO_KORG, default_defaultCopyToKOrganizer);
+	int soundType             = config->readNumEntry(DEF_SOUND_TYPE, default_defaultSoundType);
+	mDefaultSoundType         = (soundType < 0 || soundType > SoundPicker::SPEAK)
+	                          ? default_defaultSoundType : (SoundPicker::Type)soundType;
 	mDefaultSoundVolume       = static_cast<float>(config->readDoubleNumEntry(DEF_SOUND_VOLUME, default_defaultSoundVolume));
 #ifdef WITHOUT_ARTS
 	mDefaultSoundRepeat       = false;
@@ -269,31 +335,38 @@ Preferences::Preferences()
 #endif
 	mDefaultSoundFile         = config->readPathEntry(DEF_SOUND_FILE);
 	mDefaultCmdScript         = config->readBoolEntry(DEF_CMD_SCRIPT, default_defaultCmdScript);
-	mDefaultCmdXterm          = config->readBoolEntry(DEF_CMD_XTERM, default_defaultCmdXterm);
+	int logType               = config->readNumEntry(DEF_CMD_LOG_TYPE, default_defaultCmdLogType);
+	mDefaultCmdLogType        = (logType < EditAlarmDlg::DISCARD_OUTPUT || logType > EditAlarmDlg::EXEC_IN_TERMINAL)
+	                          ? default_defaultCmdLogType : (EditAlarmDlg::CmdLogType)logType;
+	mDefaultCmdLogFile        = config->readPathEntry(DEF_LOG_FILE);
 	mDefaultEmailBcc          = config->readBoolEntry(DEF_EMAIL_BCC, default_defaultEmailBcc);
 	int recurPeriod           = config->readNumEntry(DEF_RECUR_PERIOD, default_defaultRecurPeriod);
 	mDefaultRecurPeriod       = (recurPeriod < RecurrenceEdit::SUBDAILY || recurPeriod > RecurrenceEdit::ANNUAL)
 	                          ? default_defaultRecurPeriod : (RecurrenceEdit::RepeatType)recurPeriod;
+	QCString feb29            = config->readEntry(FEB29_RECUR_TYPE, defaultFeb29RecurType).local8Bit();
+	mDefaultFeb29Type         = (feb29 == "Mar1") ? KARecurrence::FEB29_MAR1 : (feb29 == "Feb28") ? KARecurrence::FEB29_FEB28 : KARecurrence::FEB29_FEB29;
 	int reminderUnits         = config->readNumEntry(DEF_REMIND_UNITS, default_defaultReminderUnits);
 	mDefaultReminderUnits     = (reminderUnits < TimePeriod::HOURS_MINUTES || reminderUnits > TimePeriod::WEEKS)
 	                          ? default_defaultReminderUnits : (TimePeriod::Units)reminderUnits;
 	mDefaultPreAction         = config->readEntry(DEF_PRE_ACTION, default_defaultPreAction);
 	mDefaultPostAction        = config->readEntry(DEF_POST_ACTION, default_defaultPostAction);
-	mAutostartDaemon          = Daemon::autoStart(default_autostartDaemon);
-	mOldAutostartDaemon       = mAutostartDaemon;
-	emit preferencesChanged();
+	mInstance->emitPreferencesChanged();
 	mStartOfDayChanged = (mStartOfDay != mOldStartOfDay);
 	if (mStartOfDayChanged)
 	{
-		emit startOfDayChanged(mOldStartOfDay);
+		mInstance->emitStartOfDayChanged();
 		mOldStartOfDay = mStartOfDay;
 	}
 }
 
+/******************************************************************************
+* Save preference values to the config file.
+*/
 void Preferences::save(bool syncToDisc)
 {
 	KConfig* config = KGlobal::config();
 	config->setGroup(GENERAL_SECTION);
+	config->writeEntry(VERSION_NUM, KALARM_VERSION);
 	QStringList colours;
 	for (ColourList::const_iterator it = mMessageColours.begin();  it != mMessageColours.end();  ++it)
 		colours.append(QColor(*it).name());
@@ -303,7 +376,6 @@ void Preferences::save(bool syncToDisc)
 	config->writeEntry(RUN_IN_SYSTEM_TRAY, mRunInSystemTray);
 	config->writeEntry(DISABLE_IF_STOPPED, mDisableAlarmsIfStopped);
 	config->writeEntry(AUTOSTART_TRAY, mAutostartTrayIcon);
-	config->writeEntry(FEB29_RECUR_TYPE, (mFeb29RecurType == FEB29_MAR1 ? "Mar1" : mFeb29RecurType == FEB29_FEB28 ? "Feb28" : "None"));
 	config->writeEntry(MODAL_MESSAGES, mModalMessages);
 	config->writeEntry(MESSAGE_BUTTON_DELAY, mMessageButtonDelay);
 	config->writeEntry(SHOW_EXPIRED_ALARMS, mShowExpiredAlarms);
@@ -318,40 +390,38 @@ void Preferences::save(bool syncToDisc)
 	config->writeEntry(EMAIL_COPY_TO_KMAIL, mEmailCopyToKMail);
 	config->writeEntry(EMAIL_FROM, emailFrom(mEmailFrom, true, false));
 	config->writeEntry(EMAIL_BCC_ADDRESS, emailFrom(mEmailBccFrom, true, true));
+	config->writeEntry(CMD_XTERM_COMMAND, translateXTermPath(config, mCmdXTermCommand, true));
 	config->writeEntry(START_OF_DAY, QDateTime(QDate(1900,1,1), mStartOfDay));
-	config->writePathEntry(CMD_XTERM_COMMAND, mCmdXTermCommand);
 	// Start-of-day check value is only written once the start-of-day time has been processed.
 	config->writeEntry(DISABLED_COLOUR, mDisabledColour);
 	config->writeEntry(EXPIRED_COLOUR, mExpiredColour);
 	config->writeEntry(EXPIRED_KEEP_DAYS, mExpiredKeepDays);
+
 	config->setGroup(DEFAULTS_SECTION);
 	config->writeEntry(DEF_LATE_CANCEL, mDefaultLateCancel);
 	config->writeEntry(DEF_AUTO_CLOSE, mDefaultAutoClose);
 	config->writeEntry(DEF_CONFIRM_ACK, mDefaultConfirmAck);
-	config->writeEntry(DEF_BEEP, mDefaultBeep);
-	config->writeEntry(DEF_SOUND, mDefaultSound);
+	config->writeEntry(DEF_COPY_TO_KORG, mDefaultCopyToKOrganizer);
+	config->writeEntry(DEF_SOUND_TYPE, mDefaultSoundType);
 	config->writePathEntry(DEF_SOUND_FILE, mDefaultSoundFile);
 	config->writeEntry(DEF_SOUND_VOLUME, static_cast<double>(mDefaultSoundVolume));
 	config->writeEntry(DEF_SOUND_REPEAT, mDefaultSoundRepeat);
 	config->writeEntry(DEF_CMD_SCRIPT, mDefaultCmdScript);
-	config->writeEntry(DEF_CMD_XTERM, mDefaultCmdXterm);
+	config->writeEntry(DEF_CMD_LOG_TYPE, mDefaultCmdLogType);
+	config->writePathEntry(DEF_LOG_FILE, mDefaultCmdLogFile);
 	config->writeEntry(DEF_EMAIL_BCC, mDefaultEmailBcc);
 	config->writeEntry(DEF_RECUR_PERIOD, mDefaultRecurPeriod);
+	config->writeEntry(FEB29_RECUR_TYPE, (mDefaultFeb29Type == KARecurrence::FEB29_MAR1 ? "Mar1" : mDefaultFeb29Type == KARecurrence::FEB29_FEB28 ? "Feb28" : "None"));
 	config->writeEntry(DEF_REMIND_UNITS, mDefaultReminderUnits);
 	config->writeEntry(DEF_PRE_ACTION, mDefaultPreAction);
 	config->writeEntry(DEF_POST_ACTION, mDefaultPostAction);
+
 	if (syncToDisc)
 		config->sync();
-	if (mAutostartDaemon != mOldAutostartDaemon)
-	{
-		// The alarm daemon autostart setting has changed.
-		Daemon::enableAutoStart(mAutostartDaemon);
-		mOldAutostartDaemon = mAutostartDaemon;
-	}
-	emit preferencesChanged();
+	mInstance->emitPreferencesChanged();
 	if (mStartOfDay != mOldStartOfDay)
 	{
-		emit startOfDayChanged(mOldStartOfDay);
+		mInstance->emitStartOfDayChanged();
 		mOldStartOfDay = mStartOfDay;
 	}
 }
@@ -370,16 +440,14 @@ void Preferences::updateStartOfDayCheck()
 	mStartOfDayChanged = false;
 }
 
-QString Preferences::emailFrom(Preferences::MailFrom from, bool useAddress, bool bcc) const
+QString Preferences::emailFrom(Preferences::MailFrom from, bool useAddress, bool bcc)
 {
 	switch (from)
 	{
 		case MAIL_FROM_KMAIL:
 			return FROM_KMAIL;
-#if KDE_VERSION >= 210
 		case MAIL_FROM_CONTROL_CENTRE:
 			return FROM_CONTROL_CENTRE;
-#endif
 		case MAIL_FROM_ADDR:
 			return useAddress ? (bcc ? mEmailBccAddress : mEmailAddress) : QString::null;
 		default:
@@ -391,17 +459,15 @@ Preferences::MailFrom Preferences::emailFrom(const QString& str)
 {
 	if (str == FROM_KMAIL)
 		return MAIL_FROM_KMAIL;
-#if KDE_VERSION >= 210
 	if (str == FROM_CONTROL_CENTRE)
 		return MAIL_FROM_CONTROL_CENTRE;
-#endif
 	return MAIL_FROM_ADDR;
 }
 
 /******************************************************************************
 * Get user's default 'From' email address.
 */
-QString Preferences::emailAddress() const
+QString Preferences::emailAddress()
 {
 	switch (mEmailFrom)
 	{
@@ -416,7 +482,7 @@ QString Preferences::emailAddress() const
 	}
 }
 
-QString Preferences::emailBccAddress() const
+QString Preferences::emailBccAddress()
 {
 	switch (mEmailBccFrom)
 	{
@@ -435,11 +501,9 @@ void Preferences::setEmailAddress(Preferences::MailFrom from, const QString& add
 	{
 		case MAIL_FROM_KMAIL:
 			break;
-#if KDE_VERSION >= 210
 		case MAIL_FROM_CONTROL_CENTRE:
 			mEmailAddress = KAMail::controlCentreAddress();
 			break;
-#endif
 		case MAIL_FROM_ADDR:
 			mEmailAddress = address;
 			break;
@@ -451,10 +515,6 @@ void Preferences::setEmailAddress(Preferences::MailFrom from, const QString& add
 
 void Preferences::setEmailBccAddress(bool useControlCentre, const QString& address)
 {
-#if KDE_VERSION < 210
-	if (useControlCentre)
-		return;
-#endif
 	if (useControlCentre)
 		mEmailBccAddress = KAMail::controlCentreAddress();
 	else
@@ -490,28 +550,119 @@ bool Preferences::notifying(const QString& messageID)
 void Preferences::convertOldPrefs()
 {
 	KConfig* config = KGlobal::config();
-	QMap<QString, QString> entries = config->entryMap(GENERAL_SECTION);
-	if (entries.find(EMAIL_FROM) == entries.end()
-	&&  entries.find(EMAIL_USE_CONTROL_CENTRE) != entries.end())
+	config->setGroup(GENERAL_SECTION);
+	int version = KAlarm::getVersionNumber(config->readEntry(VERSION_NUM));
+	if (version >= KAlarm::Version(1,4,6))
+		return;     // config format is up to date
+
+	// Convert KAlarm 1.4.5 preferences
+	static const QString DEF_SOUND = QString::fromLatin1("DefSound");
+	config->setGroup(DEFAULTS_SECTION);
+	bool sound = config->readBoolEntry(DEF_SOUND, false);
+	if (!sound)
+		config->writeEntry(DEF_SOUND_TYPE, SoundPicker::NONE);
+	config->deleteEntry(DEF_SOUND);
+
+	if (version < KAlarm::Version(1,3,0))
 	{
-		// Preferences were written by KAlarm pre-1.2.1
-		config->setGroup(GENERAL_SECTION);
-		bool useCC = false;
-		bool bccUseCC = false;
-#if KDE_VERSION >= 210
-		const bool default_emailUseControlCentre    = true;
-		const bool default_emailBccUseControlCentre = true;
-		useCC = config->readBoolEntry(EMAIL_USE_CONTROL_CENTRE, default_emailUseControlCentre);
-		// EmailBccUseControlCenter was missing in preferences written by KAlarm pre-0.9.5
-		bccUseCC = config->hasKey(EMAIL_BCC_USE_CONTROL_CENTRE)
-		         ? config->readBoolEntry(EMAIL_BCC_USE_CONTROL_CENTRE, default_emailBccUseControlCentre)
-			 : useCC;
-#endif
-		config->writeEntry(EMAIL_FROM, (useCC ? FROM_CONTROL_CENTRE : config->readEntry(EMAIL_ADDRESS)));
-		config->writeEntry(EMAIL_BCC_ADDRESS, (bccUseCC ? FROM_CONTROL_CENTRE : config->readEntry(EMAIL_BCC_ADDRESS)));
-		config->deleteEntry(EMAIL_ADDRESS);
-		config->deleteEntry(EMAIL_BCC_USE_CONTROL_CENTRE);
-		config->deleteEntry(EMAIL_USE_CONTROL_CENTRE);
-		config->sync();
+		// Convert KAlarm pre-1.3 preferences
+		static const QString EMAIL_ADDRESS             = QString::fromLatin1("EmailAddress");
+		static const QString EMAIL_USE_CTRL_CENTRE     = QString::fromLatin1("EmailUseControlCenter");
+		static const QString EMAIL_BCC_USE_CTRL_CENTRE = QString::fromLatin1("EmailBccUseControlCenter");
+		QMap<QString, QString> entries = config->entryMap(GENERAL_SECTION);
+		if (entries.find(EMAIL_FROM) == entries.end()
+		&&  entries.find(EMAIL_USE_CTRL_CENTRE) != entries.end())
+		{
+			// Preferences were written by KAlarm pre-1.2.1
+			config->setGroup(GENERAL_SECTION);
+			bool useCC = false;
+			bool bccUseCC = false;
+			const bool default_emailUseControlCentre    = true;
+			const bool default_emailBccUseControlCentre = true;
+			useCC = config->readBoolEntry(EMAIL_USE_CTRL_CENTRE, default_emailUseControlCentre);
+			// EmailBccUseControlCenter was missing in preferences written by KAlarm pre-0.9.5
+			bccUseCC = config->hasKey(EMAIL_BCC_USE_CTRL_CENTRE)
+			         ? config->readBoolEntry(EMAIL_BCC_USE_CTRL_CENTRE, default_emailBccUseControlCentre)
+				 : useCC;
+			config->writeEntry(EMAIL_FROM, (useCC ? FROM_CONTROL_CENTRE : config->readEntry(EMAIL_ADDRESS)));
+			config->writeEntry(EMAIL_BCC_ADDRESS, (bccUseCC ? FROM_CONTROL_CENTRE : config->readEntry(EMAIL_BCC_ADDRESS)));
+			config->deleteEntry(EMAIL_ADDRESS);
+			config->deleteEntry(EMAIL_BCC_USE_CTRL_CENTRE);
+			config->deleteEntry(EMAIL_USE_CTRL_CENTRE);
+		}
+		// Convert KAlarm 1.2 preferences
+		static const QString DEF_CMD_XTERM = QString::fromLatin1("DefCmdXterm");
+		config->setGroup(DEFAULTS_SECTION);
+		if (config->hasKey(DEF_CMD_XTERM))
+		{
+			config->writeEntry(DEF_CMD_LOG_TYPE,
+				(config->readBoolEntry(DEF_CMD_XTERM, false) ? EditAlarmDlg::EXEC_IN_TERMINAL : EditAlarmDlg::DISCARD_OUTPUT));
+			config->deleteEntry(DEF_CMD_XTERM);
+		}
 	}
+	config->setGroup(GENERAL_SECTION);
+	config->writeEntry(VERSION_NUM, KALARM_VERSION);
+	config->sync();
+}
+
+/******************************************************************************
+* Translate an X terminal command path to/from config file format.
+* Note that only a home directory specification at the start of the path is
+* translated, so there's no need to worry about missing out some of the
+* executable's path due to quotes etc.
+* N.B. Calling KConfig::read/writePathEntry() on the entire command line
+*      causes a crash on some systems, so it's necessary to extract the
+*      executable path first before processing.
+*/
+QString translateXTermPath(KConfig* config, const QString& cmdline, bool write)
+{
+	QString params;
+	QString cmd = cmdline;
+	if (cmdline.isEmpty())
+		return cmdline;
+	// Strip any leading quote
+	QChar quote = cmdline[0];
+	char q = static_cast<char>(quote);
+	bool quoted = (q == '"' || q == '\'');
+	if (quoted)
+		cmd = cmdline.mid(1);
+	// Split the command at the first non-escaped space
+	for (int i = 0, count = cmd.length();  i < count;  ++i)
+	{
+		switch (cmd[i].latin1())
+		{
+			case '\\':
+				++i;
+				continue;
+			case '"':
+			case '\'':
+				if (cmd[i] != quote)
+					continue;
+				// fall through to ' '
+			case ' ':
+				params = cmd.mid(i);
+				cmd = cmd.left(i);
+				break;
+			default:
+				continue;
+		}
+		break;
+	}
+	// Translate any home directory specification at the start of the
+	// executable's path.
+	if (write)
+	{
+		config->writePathEntry(TEMP, cmd);
+		cmd = config->readEntry(TEMP);
+	}
+	else
+	{
+		config->writeEntry(TEMP, cmd);
+		cmd = config->readPathEntry(TEMP);
+	}
+	config->deleteEntry(TEMP);
+	if (quoted)
+		return quote + cmd + params;
+	else
+		return cmd + params;
 }
