@@ -213,6 +213,12 @@ QString KarmStorage::load (TaskView* view, const Preferences* preferences, QStri
   return err;
 }
 
+QString KarmStorage::icalfile()
+{
+  kdDebug(5970) << "Entering KarmStorage::icalfile" << endl;
+  return _icalfile;
+}
+
 QString KarmStorage::buildTaskView(KCal::ResourceCalendar *rc, TaskView *view)
 // makes *view contain the tasks out of *rc.
 {
@@ -273,7 +279,7 @@ QString KarmStorage::buildTaskView(KCal::ResourceCalendar *rc, TaskView *view)
   // restart tasks that have been running with their start times
   for ( int i=0; i<view->count(); i++)
   {
-    for ( int n=0; n<runningTasks.size(); n++)
+    for ( unsigned int n=0; n<runningTasks.size(); n++)
     {
       if ( runningTasks[n] == view->item_at_index(i)->uid() )
       {
@@ -1043,9 +1049,10 @@ QString KarmStorage::exportcsvHistory ( TaskView      *taskview,
   return err;
 }
 
-void KarmStorage::stopTimer(const Task* task)
+void KarmStorage::stopTimer(const Task* task, QDateTime when)
 {
-  long delta = task->startTime().secsTo(QDateTime::currentDateTime());
+  kdDebug(5970) << "Entering KarmStorage::stopTimer" << endl;
+  long delta = task->startTime().secsTo(when);
   changeTime(task, delta);
 }
 
@@ -1071,6 +1078,7 @@ bool KarmStorage::bookTime(const Task* task,
 
 void KarmStorage::changeTime(const Task* task, const long deltaSeconds)
 {
+  kdDebug(5970) << "Entering KarmStorage::changeTime ( " << task->name() << "," << deltaSeconds <<  " )" << endl;
   KCal::Event* e;
   QDateTime end;
 
@@ -1211,6 +1219,12 @@ bool KarmStorage::saveCalendar()
 {
   kdDebug(5970) << "KarmStorage::saveCalendar" << endl;
 
+  Event::List evl=_calendar->rawEvents();
+  kdDebug(5970) << "summary - dtStart - dtEnd" << endl;
+  for (unsigned int i=0; i<evl.count(); i++) 
+  {
+    kdDebug() << evl[i]->summary() << evl[i]->dtStart() << evl[i]->dtEnd() << endl;
+  }
   KABC::Lock *lock = _calendar->lock();
   if ( !lock || !lock->lock() )
     return false;
