@@ -10,6 +10,7 @@
 #include "desktoplist.h"
 #include "resourcecalendar.h"
 #include "karmstorage.h"
+#include "mainwindow.h"
 #include "reportcriteria.h"
 #include <qtimer.h>
 //#include "desktoptracker.h"
@@ -96,6 +97,9 @@ class TaskView : public KListView
     /** Stop all running timers.  */
     void stopAllTimers();
 
+    /** Stop all running timers as if it was qdt */
+    void stopAllTimersAt(QDateTime qdt);
+
     /** Calls newTask dialog with caption "New Task".  */
     void newTask();
 
@@ -173,12 +177,17 @@ class TaskView : public KListView
 	 IF YOU DO NOT KNOW WHAT YOU ARE DOING, CALL stopAllTimers INSTEAD */
     void clearActiveTasks();
 
-    /** User has picked a new iCalendar file on preferences screen. */
+    /** User might have picked a new iCalendar file on preferences screen. 
+        Verify the file is not the same as before and load the new one. 
+        This is not iCalFileModified. */
     void iCalFileChanged(QString file);
 
     /** Copy totals for current and all sub tasks to clipboard. */
     void clipTotals();
 
+    /** Copy session times for current and all sub tasks to clipboard */
+    void clipSession();
+
     /** Copy history for current and all sub tasks to clipboard. */
     void clipHistory();
 
@@ -188,6 +197,7 @@ class TaskView : public KListView
     void timersActive();
     void timersInactive();
     void tasksChanged( QPtrList<Task> activeTasks );
+    void setStatusBar( QString );
 
   private: // member variables
     IdleTimeDetector *_idleTimeDetector;
@@ -218,6 +228,7 @@ class TaskView : public KListView
     void minuteUpdate();
     /** item state stores if a task is expanded so you can see the subtasks */
     void itemStateChanged( QListViewItem *item );
+    /** React on another process having modified the iCal file we rely on. */
     void iCalFileModified(ResourceCalendar *);
 };
 
