@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 
     author  : jh, jochen@ifb.bv.tu-berlin.de
 
@@ -139,6 +139,7 @@ public:
    *
    */
   void removeHoliday(int y, int m, int d) {
+    Q_UNUSED(y); Q_UNUSED(m); Q_UNUSED(d);
   }
 
 
