@@ -152,7 +152,7 @@ kdemain (int argc, char **argv)
 #ifdef HAVE_LIBSASL2
   sasl_done();
 #endif
-  
+
   return 0;
 }
 
@@ -747,7 +747,7 @@ bool IMAP4Protocol::parseReadLine (QByteArray & buffer, ulong relay)
       }
 
       readBufferLen -= copyLen;
-      if (readBufferLen) 
+      if (readBufferLen)
         memmove(readBuffer, &readBuffer[copyLen], readBufferLen);
       if (buffer[buffer.size() - 1] == '\n') return TRUE;
     }
@@ -945,10 +945,10 @@ IMAP4Protocol::mkdir (const KURL & _url, int)
   if (type == ITYPE_BOX)
   {
     bool ask = ( aInfo.find( "ASKUSER" ) != -1 );
-    if ( ask && 
+    if ( ask &&
         messageBox(QuestionYesNo,
           i18n("The following folder will be created on the server: %1 "
-               "What do you want to store in this folder?").arg( aBox ), 
+               "What do you want to store in this folder?").arg( aBox ),
           i18n("Create Folder"),
           i18n("&Messages"), i18n("&Subfolders")) == KMessageBox::No )
     {
@@ -1212,7 +1212,7 @@ IMAP4Protocol::del (const KURL & _url, bool isFile)
  * No-op: data = 'N'
  * Namespace: data = 'n'. Result shipped in infoMessage() signal
  *                        The format is: section=namespace=delimiter
- *                        Note that the namespace can be empty               
+ *                        Note that the namespace can be empty
  * Unsubscribe: data = 'U' + URL (KURL)
  * Subscribe: data = 'u' + URL (KURL)
  * Change the status: data = 'S' + URL (KURL) + Flags (QCString)
@@ -1264,7 +1264,7 @@ IMAP4Protocol::special (const QByteArray & aData)
     break;
   }
   case 'n':
-  { 
+  {
     // namespace in the form "section=namespace=delimiter"
     // entries are separated by ,
     infoMessage( imapNamespaces.join(",") );
@@ -1313,7 +1313,7 @@ IMAP4Protocol::special (const QByteArray & aData)
     finished();
     break;
   }
-  case 'A': 
+  case 'A':
   {
     // acl
     int cmd;
@@ -1325,7 +1325,7 @@ IMAP4Protocol::special (const QByteArray & aData)
     }
     break;
   }
-  case 'M': 
+  case 'M':
   {
     // annotatemore
     int cmd;
@@ -1337,7 +1337,7 @@ IMAP4Protocol::special (const QByteArray & aData)
     }
     break;
   }
-  case 'S': 
+  case 'S':
   {
     // status
     KURL _url;
@@ -1374,7 +1374,7 @@ IMAP4Protocol::special (const QByteArray & aData)
     finished();
     break;
   }
-  case 'E': 
+  case 'E':
   {
     // search
     specialSearchCommand( stream );
@@ -1665,7 +1665,7 @@ IMAP4Protocol::stat (const KURL & _url)
   QString aBox, aSequence, aLType, aSection, aValidity, aDelimiter, aInfo;
   // parseURL with caching
   enum IMAP_TYPE aType =
-    parseURL (_url, aBox, aSection, aLType, aSequence, aValidity, aDelimiter, 
+    parseURL (_url, aBox, aSection, aLType, aSequence, aValidity, aDelimiter,
         aInfo, true);
 
   UDSEntry entry;
@@ -1924,16 +1924,23 @@ bool IMAP4Protocol::makeLogin ()
       } else completeQueue.removeRef(cmd);
     }
 
-    if (!myAuth.isEmpty () && myAuth != "*"
-        && !hasCapability (QString ("AUTH=") + myAuth))
-    {
-      error (ERR_COULD_NOT_LOGIN, i18n("The authentication method %1 is not "
-        "supported by the server.").arg(myAuth));
-      closeConnection();
-      return false;
+    if (myAuth.isEmpty () || myAuth == "*") {
+      if (hasCapability (QString ("LOGINDISABLED"))) {
+        error (ERR_COULD_NOT_LOGIN, i18n("LOGIN is disabled by the server."));
+        closeConnection();
+        return false;
+      }
+    }
+    else {
+      if (!hasCapability (QString ("AUTH=") + myAuth)) {
+        error (ERR_COULD_NOT_LOGIN, i18n("The authentication method %1 is not "
+          "supported by the server.").arg(myAuth));
+        closeConnection();
+        return false;
+      }
     }
 
-    if (  greeting.contains(  QRegExp(  "Cyrus IMAP4 v2.1" ) ) ) {
+    if ( greeting.contains(  QRegExp(  "Cyrus IMAP4 v2.1" ) ) ) {
       removeCapability( "ANNOTATEMORE" );
     }
 
@@ -1961,7 +1968,7 @@ bool IMAP4Protocol::makeLogin ()
     }
     else
     {
-#ifdef HAVE_LIBSASL2      
+#ifdef HAVE_LIBSASL2
       if (!clientAuthenticate (this, authInfo, myHost, myAuth, mySSL, resultInfo))
         error(KIO::ERR_COULD_NOT_LOGIN, i18n("Unable to authenticate via %1.\n"
 	"The server %2 replied:\n%3").arg(myAuth).arg(myHost).arg(resultInfo));
@@ -2002,12 +2009,12 @@ bool IMAP4Protocol::makeLogin ()
       if ( it != listResponses.end() )
       {
         namespaceToDelimiter[QString::null] = (*it).hierarchyDelimiter();
-        kdDebug(7116) << "makeLogin - delimiter for empty ns='" << 
+        kdDebug(7116) << "makeLogin - delimiter for empty ns='" <<
           (*it).hierarchyDelimiter() << "'" << endl;
         if ( !hasCapability("NAMESPACE") )
         {
           // server does not support namespaces
-          QString nsentry = QString::number( 0 ) + "==" 
+          QString nsentry = QString::number( 0 ) + "=="
             + (*it).hierarchyDelimiter();
           imapNamespaces.append( nsentry );
         }
@@ -2336,7 +2343,7 @@ IMAP4Protocol::parseURL (const KURL & _url, QString & _box,
               }
             }
             // if we got no list response for the box see if it's a prefix
-            if ( retVal == ITYPE_UNKNOWN && 
+            if ( retVal == ITYPE_UNKNOWN &&
                  namespaceToDelimiter.contains(_box) ) {
               retVal = ITYPE_DIR;
             }
@@ -2354,7 +2361,7 @@ IMAP4Protocol::parseURL (const KURL & _url, QString & _box,
     else
       kdDebug(7116) << "IMAP4::parseURL: no login!" << endl;
 
-  } 
+  }
   else // empty box
   {
     // the root is just a dir
@@ -2383,7 +2390,7 @@ IMAP4Protocol::parseURL (const KURL & _url, QString & _box,
   if ( _hierarchyDelimiter.isEmpty() &&
        (_type == "LIST" || _type == "LSUB" || _type == "LSUBNOCHECK") )
   {
-    // this shouldn't happen but when the delimiter is really empty 
+    // this shouldn't happen but when the delimiter is really empty
     // we try to reconstruct it from the URL
     if (!_box.isEmpty())
     {
