@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
@@ -42,11 +42,12 @@
 using KMail::FolderRequester;
 #include "kmfoldermgr.h"
 #include "transportmanager.h"
-#include "kmkernel.h"
 #include "dictionarycombobox.h"
 #include "kleo_util.h"
 #include "kmmainwidget.h"
 #include "kmfolder.h"
+#include "templatesconfiguration.h"
+#include "templatesconfiguration_kfg.h"
 
 // other kdepim headers:
 // libkdepim
@@ -65,6 +66,7 @@ using KMail::FolderRequester;
 #include <kfileitem.h>
 #include <kurl.h>
 #include <kdebug.h>
+#include <kpushbutton.h>
 
 // Qt headers:
 #include <qtabwidget.h>
@@ -286,9 +288,9 @@ namespace KMail {
     row = -1;
     tab = new QWidget( tabWidget );
     tabWidget->addTab( tab, i18n("&Advanced") );
-    glay = new QGridLayout( tab, 7, 2, marginHint(), spacingHint() );
+    glay = new QGridLayout( tab, 8, 2, marginHint(), spacingHint() );
     // the last (empty) row takes all the remaining space
-    glay->setRowStretch( 7-1, 1 );
+    glay->setRowStretch( 8-1, 1 );
     glay->setColStretch( 1, 1 );
 
     // "Reply-To Address" line edit and label:
@@ -353,6 +355,15 @@ namespace KMail {
     glay->addWidget( new QLabel( mDraftsCombo, i18n("&Drafts folder:"), tab ),
                      row, 0 );
 
+    // "Templates Folder" combo box and label:
+    ++row;
+    mTemplatesCombo = new FolderRequester( tab,
+        kmkernel->getKMMainWidget()->folderTree() );
+    mTemplatesCombo->setShowOutbox( false );
+    glay->addWidget( mTemplatesCombo, row, 1 );
+    glay->addWidget( new QLabel( mTemplatesCombo, i18n("&Templates folder:"), tab ),
+                     row, 0 );
+
     // "Special transport" combobox and label:
     ++row;
     mTransportCheck = new QCheckBox( i18n("Special &transport:"), tab );
@@ -365,7 +376,29 @@ namespace KMail {
              mTransportCombo, SLOT(setEnabled(bool)) );
 
     // the last row is a spacer
-
+    
+    // 
+    // Tab Widget: Templates
+    // 
+		tab = new QWidget( tabWidget );
+    tabWidget->addTab( tab, i18n("&Templates") );
+    vlay = new QVBoxLayout( tab, marginHint(), spacingHint() );
+		mCustom = new QCheckBox( i18n("&Use custom message templates"), tab );
+		vlay->addWidget( mCustom );
+		mWidget = new TemplatesConfiguration( tab , "identity-templates" );
+		mWidget->setEnabled( false );
+		vlay->addWidget( mWidget );
+		QHBoxLayout *btns = new QHBoxLayout( vlay, spacingHint() );
+		mCopyGlobal = new KPushButton( i18n("&Copy global templates"), tab );
+		mCopyGlobal->setEnabled( false );
+		btns->addWidget( mCopyGlobal );
+		connect( mCustom, SIGNAL( toggled( bool ) ),
+					mWidget, SLOT( setEnabled( bool ) ) );
+		connect( mCustom, SIGNAL( toggled( bool ) ),
+					mCopyGlobal, SLOT( setEnabled( bool ) ) );
+		connect( mCopyGlobal, SIGNAL(clicked()),
+					this, SLOT(slotCopyGlobal()) );
+		
     //
     // Tab Widget: Signature
     //
@@ -402,6 +435,10 @@ namespace KMail {
       mSMIMESigningKeyRequester->setInitialQuery( email );
     }
   }
+  
+  void IdentityDialog::slotCopyGlobal() {
+    mWidget->loadFromGlobal();
+  }
 
   namespace {
     struct DoesntMatchEMailAddress {
@@ -585,7 +622,25 @@ void IdentityDialog::slotOk() {
       mDraftsCombo->setFolder( kmkernel->draftsFolder() );
     else
       mDraftsCombo->setFolder( ident.drafts() );
-
+    
+    if ( ident.templates().isEmpty() ||
+         !checkFolderExists( ident.templates(),
+                             i18n("The custom templates folder for identity "
+                                  "\"%1\" does not exist (anymore); "
+                                  "therefore, the default templates folder "
+                                  "will be used.")
+                             .arg( ident.identityName() ) ) )
+      mTemplatesCombo->setFolder( kmkernel->templatesFolder() );
+    else
+      mTemplatesCombo->setFolder( ident.templates() );
+    
+    // "Templates" tab:
+    uint identity = ident.uoid();
+		QString iid = QString("IDENTITY_%1").arg( identity );
+		Templates t( iid );
+		mCustom->setChecked(t.useCustomTemplates());
+		mWidget->loadFromIdentity( identity );
+    
     // "Signature" tab:
     mSignatureConfigurator->setSignature( ident.signature() );
     mXFaceConfigurator->setXFace( ident.xface() );
@@ -614,6 +669,16 @@ void IdentityDialog::slotOk() {
                   mFccCombo->folder()->idString() : QString::null );
     ident.setDrafts( mDraftsCombo->folder() ?
                      mDraftsCombo->folder()->idString() : QString::null );
+    ident.setTemplates( mTemplatesCombo->folder() ?
+                     mTemplatesCombo->folder()->idString() : QString::null );
+    // "Templates" tab:
+    uint identity = ident.uoid();
+    QString iid = QString("IDENTITY_%1").arg( identity );
+    Templates t( iid );
+		kdDebug() << "use custom templates for identity " << identity << ": " << mCustom->isChecked() << endl;
+		t.setUseCustomTemplates(mCustom->isChecked());
+		t.writeConfig();
+		mWidget->saveToIdentity( identity );
     // "Signature" tab:
     ident.setSignature( mSignatureConfigurator->signature() );
     ident.setXFace( mXFaceConfigurator->xface() );
