@@ -19,6 +19,8 @@ using KPIM::ProgressManager;
 #include <kdebug.h>
 #include <kconfig.h>
 
+#include <qstylesheet.h>
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <errno.h>
@@ -31,7 +33,7 @@ using KPIM::ProgressManager;
 #undef None
 
 //-----------------------------------------------------------------------------
-KMAcctMaildir::KMAcctMaildir(KMAcctMgr* aOwner, const QString& aAccountName, uint id):
+KMAcctMaildir::KMAcctMaildir(AccountManager* aOwner, const QString& aAccountName, uint id):
   KMAccount(aOwner, aAccountName, id)
 {
 }
@@ -89,7 +91,8 @@ void KMAcctMaildir::processNewMail(bool)
     }
   }
 
-  KMFolder mailFolder(0, location(), KMFolderTypeMaildir);
+  KMFolder mailFolder(0, location(), KMFolderTypeMaildir,
+                              false /* no index */, false /* don't export sernums */);
 
   long num = 0;
   long i;
@@ -107,10 +110,11 @@ void KMAcctMaildir::processNewMail(bool)
 	i18n("Preparing transmission from \"%1\"...").arg(mName));
 
   Q_ASSERT( !mMailCheckProgressItem );
+  QString escapedName = QStyleSheet::escape( mName );
   mMailCheckProgressItem = KPIM::ProgressManager::createProgressItem(
     "MailCheck" + mName,
-    mName,
-    i18n("Preparing transmission from \"%1\"...").arg(mName),
+    escapedName,
+    i18n("Preparing transmission from \"%1\"...").arg( escapedName ),
     false, // cannot be canceled
     false ); // no tls/ssl
 
@@ -119,10 +123,10 @@ void KMAcctMaildir::processNewMail(bool)
   {
     kdDebug(5006) << "cannot run precommand " << precommand() << endl;
     checkDone( hasNewMail, CheckError );
+    BroadcastStatus::instance()->setStatusMsg( i18n( "Transmission failed." ));
+    return;
   }
 
-  mailFolder.setAutoCreateIndex(FALSE);
-
   rc = mailFolder.open();
   if (rc)
   {
