@@ -109,6 +109,7 @@ using KMail::SecondaryWindow;
 #include "redirectdialog.h"
 using KMail::RedirectDialog;
 #include "util.h"
+#include "templateparser.h"
 
 #include "broadcaststatus.h"
 #include "globalsettings.h"
@@ -555,8 +556,7 @@ KMMailtoOpenAddrBookCommand::KMMailtoOpenAddrBookCommand( const KURL &url,
 
 KMCommand::Result KMMailtoOpenAddrBookCommand::execute()
 {
-  QString addr = KMMessage::decodeMailtoUrl( mUrl.path() );
-  KAddrBookExternal::openEmail( KPIM::getEmailAddress(addr), addr ,
+  KAddrBookExternal::openEmail( KMMessage::decodeMailtoUrl( mUrl.path() ),
                                 parentWidget() );
 
   return OK;
@@ -656,12 +656,13 @@ KMEditMsgCommand::KMEditMsgCommand( QWidget *parent, KMMessage *msg )
 KMCommand::Result KMEditMsgCommand::execute()
 {
   KMMessage *msg = retrievedMessage();
-  if (!msg || !msg->parent() ||
-      !kmkernel->folderIsDraftOrOutbox( msg->parent() ))
+  if ( !msg || !msg->parent() ||
+       ( !kmkernel->folderIsDraftOrOutbox( msg->parent() ) &&
+         !kmkernel->folderIsTemplates( msg->parent() ) ) )
     return Failed;
 
   // Remember the old parent, we need it a bit further down to be able
-  // to put the unchanged messsage back in the drafts folder if the nth
+  // to put the unchanged messsage back in the original folder if the nth
   // edit is discarded, for n > 1.
   KMFolder *parent = msg->parent();
   if ( parent )
@@ -676,6 +677,30 @@ KMCommand::Result KMEditMsgCommand::execute()
   return OK;
 }
 
+KMUseTemplateCommand::KMUseTemplateCommand( QWidget *parent, KMMessage *msg )
+  :KMCommand( parent, msg )
+{
+}
+
+KMCommand::Result KMUseTemplateCommand::execute()
+{
+  KMMessage *msg = retrievedMessage();
+  if ( !msg || !msg->parent() ||
+       !kmkernel->folderIsTemplates( msg->parent() ) )
+    return Failed;
+
+  // Take a copy of the original message, which remains unchanged.
+  KMMessage *newMsg = new KMMessage;
+  newMsg->setComplete( msg->isComplete() );
+  newMsg->fromString( msg->asString() );
+
+  KMail::Composer *win = KMail::makeComposer();
+  newMsg->setTransferInProgress( false ); // From here on on, the composer owns the message.
+  win->setMsg( newMsg, FALSE, TRUE );
+  win->show();
+
+  return OK;
+}
 
 KMShowMsgSrcCommand::KMShowMsgSrcCommand( QWidget *parent,
   KMMessage *msg, bool fixedFont )
@@ -812,22 +837,28 @@ void KMSaveMsgCommand::slotSaveDataReq()
     assert( idx >= 0 );
     msg = p->getMsg(idx);
 
-    if (msg->transferInProgress()) {
-      QByteArray data = QByteArray();
-      mJob->sendAsyncData( data );
-    }
-    msg->setTransferInProgress( true );
-    if (msg->isComplete() ) {
-      slotMessageRetrievedForSaving(msg);
-    } else {
-      // retrieve Message first
-      if (msg->parent()  && !msg->isComplete() ) {
-        FolderJob *job = msg->parent()->createJob(msg);
-        job->setCancellable( false );
-        connect(job, SIGNAL(messageRetrieved(KMMessage*)),
-            this, SLOT(slotMessageRetrievedForSaving(KMMessage*)));
-        job->start();
+    if ( msg ) {
+      if ( msg->transferInProgress() ) {
+        QByteArray data = QByteArray();
+        mJob->sendAsyncData( data );
       }
+      msg->setTransferInProgress( true );
+      if (msg->isComplete() ) {
+      slotMessageRetrievedForSaving( msg );
+      } else {
+        // retrieve Message first
+        if ( msg->parent()  && !msg->isComplete() ) {
+          FolderJob *job = msg->parent()->createJob( msg );
+          job->setCancellable( false );
+          connect(job, SIGNAL( messageRetrieved( KMMessage* ) ),
+                  this, SLOT( slotMessageRetrievedForSaving( KMMessage* ) ) );
+          job->start();
+        }
+      }
+    } else {
+      mJob->slotError( KIO::ERR_ABORTED,
+                       i18n("The message was removed while saving it. "
+                            "It has not been saved.") );
     }
   } else {
     if ( mStandAloneMessage ) {
@@ -847,7 +878,7 @@ void KMSaveMsgCommand::slotMessageRetrievedForSaving(KMMessage *msg)
   if ( msg ) {
     QCString str( msg->mboxMessageSeparator() );
     str += KMFolderMbox::escapeFrom( msg->asString() );
-    str += "\n";
+    str += '\n';
     msg->setTransferInProgress(false);
 
     mData = str;
@@ -1124,143 +1155,77 @@ KMCommand::Result KMReplyAuthorCommand::execute()
 }
 
 
-KMForwardCommand::KMForwardCommand( QWidget *parent,
+KMForwardInlineCommand::KMForwardInlineCommand( QWidget *parent,
   const QPtrList<KMMsgBase> &msgList, uint identity )
   : KMCommand( parent, msgList ),
     mIdentity( identity )
 {
 }
 
-KMForwardCommand::KMForwardCommand( QWidget *parent, KMMessage *msg,
-                                    uint identity )
+KMForwardInlineCommand::KMForwardInlineCommand( QWidget *parent,
+  KMMessage *msg, uint identity )
   : KMCommand( parent, msg ),
     mIdentity( identity )
 {
 }
 
-KMCommand::Result KMForwardCommand::execute()
+KMCommand::Result KMForwardInlineCommand::execute()
 {
   QPtrList<KMMessage> msgList = retrievedMsgs();
 
-  if (msgList.count() >= 2) {
-    // ask if they want a mime digest forward
+  if (msgList.count() >= 2) { // Multiple forward
 
-    if (KMessageBox::questionYesNo( parentWidget(),
-                                    i18n("Forward selected messages as "
-                                         "a MIME digest?"), QString::null, i18n("Send Digest"), i18n("Send") )
-        == KMessageBox::Yes) {
-      uint id = 0;
-      KMMessage *fwdMsg = new KMMessage;
-      KMMessagePart *msgPart = new KMMessagePart;
-      QString msgPartText;
-      int msgCnt = 0; // incase there are some we can't forward for some reason
+    uint id = 0;
+    // QCString msgText = "";
+    QPtrList<KMMessage> linklist;
+    for ( KMMessage *msg = msgList.first(); msg; msg = msgList.next() ) {
+      // set the identity
+      if (id == 0)
+        id = msg->headerField( "X-KMail-Identity" ).stripWhiteSpace().toUInt();
 
-      // dummy header initialization; initialization with the correct identity
-      // is done below
-      fwdMsg->initHeader(id);
-      fwdMsg->setAutomaticFields(true);
-      fwdMsg->mMsg->Headers().ContentType().CreateBoundary(1);
-      QCString boundary( fwdMsg->mMsg->Headers().ContentType().Boundary().c_str() );
-      msgPartText = i18n("\nThis is a MIME digest forward. The content of the"
-                         " message is contained in the attachment(s).\n\n\n");
-      // iterate through all the messages to be forwarded
-      for (KMMessage *msg = msgList.first(); msg; msg = msgList.next()) {
-        // set the identity
-        if (id == 0)
-          id = msg->headerField("X-KMail-Identity").stripWhiteSpace().toUInt();
-        // set the part header
-        msgPartText += "--";
-        msgPartText += QString::fromLatin1( boundary );
-        msgPartText += "\nContent-Type: MESSAGE/RFC822";
-        msgPartText += QString("; CHARSET=%1").arg(msg->charset());
-        msgPartText += "\n";
-        DwHeaders dwh;
-        dwh.MessageId().CreateDefault();
-        msgPartText += QString("Content-ID: %1\n").arg(dwh.MessageId().AsString().c_str());
-        msgPartText += QString("Content-Description: %1").arg(msg->subject());
-        if (!msg->subject().contains("(fwd)"))
-          msgPartText += " (fwd)";
-        msgPartText += "\n\n";
-        // remove headers that shouldn't be forwarded
-        msg->removePrivateHeaderFields();
-        msg->removeHeaderField("BCC");
-        // set the part
-        msgPartText += msg->headerAsString();
-        msgPartText += "\n";
-        msgPartText += msg->body();
-        msgPartText += "\n";     // eot
-        msgCnt++;
-        fwdMsg->link(msg, KMMsgStatusForwarded);
-      }
-      if ( id == 0 )
-        id = mIdentity; // use folder identity if no message had an id set
-      fwdMsg->initHeader(id);
-      msgPartText += "--";
-      msgPartText += QString::fromLatin1( boundary );
-      msgPartText += "--\n";
-      QCString tmp;
-      msgPart->setTypeStr("MULTIPART");
-      tmp.sprintf( "Digest; boundary=\"%s\"", boundary.data() );
-      msgPart->setSubtypeStr( tmp );
-      msgPart->setName("unnamed");
-      msgPart->setCte(DwMime::kCte7bit);   // does it have to be 7bit?
-      msgPart->setContentDescription(QString("Digest of %1 messages.").arg(msgCnt));
-      // THIS HAS TO BE AFTER setCte()!!!!
-      msgPart->setBodyEncoded(QCString(msgPartText.ascii()));
-      KCursorSaver busy(KBusyPtr::busy());
+      // msgText += msg->createForwardBody();
+      linklist.append( msg );
+    }
+    if ( id == 0 )
+      id = mIdentity; // use folder identity if no message had an id set
+    KMMessage *fwdMsg = new KMMessage;
+    fwdMsg->initHeader( id );
+    fwdMsg->setAutomaticFields( true );
+    fwdMsg->setCharset( "utf-8" );
+    // fwdMsg->setBody( msgText );
+
+    for ( KMMessage *msg = linklist.first(); msg; msg = linklist.next() ) {
+      TemplateParser parser( fwdMsg, TemplateParser::Forward,
+        msg->body(), false, false, false, false);
+        parser.process( msg, 0, true );
+
+      fwdMsg->link( msg, KMMsgStatusForwarded );
+    }
+
+    KCursorSaver busy( KBusyPtr::busy() );
+    KMail::Composer * win = KMail::makeComposer( fwdMsg, id );
+    win->setCharset("");
+    win->show();
+
+  } else { // forward a single message at most
+
+    KMMessage *msg = msgList.getFirst();
+    if ( !msg || !msg->codec() )
+      return Failed;
+
+    KCursorSaver busy( KBusyPtr::busy() );
+    KMMessage *fwdMsg = msg->createForward();
+
+    uint id = msg->headerField( "X-KMail-Identity" ).stripWhiteSpace().toUInt();
+    if ( id == 0 )
+      id = mIdentity;
+    {
       KMail::Composer * win = KMail::makeComposer( fwdMsg, id );
-      win->addAttach(msgPart);
+      win->setCharset( fwdMsg->codec()->mimeName(), true );
+      // win->setBody( QString::fromUtf8( msg->createForwardBody() ) );
       win->show();
-      return OK;
-    } else {            // NO MIME DIGEST, Multiple forward
-      uint id = 0;
-      QCString msgText = "";
-      QPtrList<KMMessage> linklist;
-      for (KMMessage *msg = msgList.first(); msg; msg = msgList.next()) {
-        // set the identity
-        if (id == 0)
-          id = msg->headerField("X-KMail-Identity").stripWhiteSpace().toUInt();
-
-        msgText += msg->createForwardBody();
-        linklist.append(msg);
-      }
-      if ( id == 0 )
-        id = mIdentity; // use folder identity if no message had an id set
-      KMMessage *fwdMsg = new KMMessage;
-      fwdMsg->initHeader(id);
-      fwdMsg->setAutomaticFields(true);
-      fwdMsg->setCharset("utf-8");
-      fwdMsg->setBody(msgText);
-
-      for (KMMessage *msg = linklist.first(); msg; msg = linklist.next())
-        fwdMsg->link(msg, KMMsgStatusForwarded);
-
-      KCursorSaver busy(KBusyPtr::busy());
-      KMail::Composer * win = KMail::makeComposer( fwdMsg, id );
-      win->setCharset("");
-      win->show();
-      return OK;
     }
   }
-
-  // forward a single message at most.
-  KMMessage *msg = msgList.getFirst();
-  if ( !msg || !msg->codec() )
-    return Failed;
-
-  KCursorSaver busy(KBusyPtr::busy());
-  KMMessage *fwdMsg = msg->createForward();
-
-  uint id = msg->headerField("X-KMail-Identity").stripWhiteSpace().toUInt();
-  if ( id == 0 )
-    id = mIdentity;
-  {
-    KMail::Composer * win = KMail::makeComposer( fwdMsg, id );
-    win->setCharset( fwdMsg->codec()->mimeName(), true );
-    win->setBody( QString::fromUtf8( msg->createForwardBody() ) );
-    win->show();
-  }
-
   return OK;
 }
 
@@ -1329,8 +1294,95 @@ KMCommand::Result KMForwardAttachedCommand::execute()
 }
 
 
+KMForwardDigestCommand::KMForwardDigestCommand( QWidget *parent,
+           const QPtrList<KMMsgBase> &msgList, uint identity, KMail::Composer *win )
+  : KMCommand( parent, msgList ), mIdentity( identity ),
+    mWin( QGuardedPtr<KMail::Composer>( win ))
+{
+}
+
+KMForwardDigestCommand::KMForwardDigestCommand( QWidget *parent,
+           KMMessage * msg, uint identity, KMail::Composer *win )
+  : KMCommand( parent, msg ), mIdentity( identity ),
+    mWin( QGuardedPtr< KMail::Composer >( win ))
+{
+}
+
+KMCommand::Result KMForwardDigestCommand::execute()
+{
+  QPtrList<KMMessage> msgList = retrievedMsgs();
+
+  if ( msgList.count() < 2 )
+    return Undefined; // must have more than 1 for a digest
+
+  uint id = 0;
+  KMMessage *fwdMsg = new KMMessage;
+  KMMessagePart *msgPart = new KMMessagePart;
+  QString msgPartText;
+  int msgCnt = 0; // incase there are some we can't forward for some reason
+
+  // dummy header initialization; initialization with the correct identity
+  // is done below
+  fwdMsg->initHeader( id );
+  fwdMsg->setAutomaticFields( true );
+  fwdMsg->mMsg->Headers().ContentType().CreateBoundary( 1 );
+  QCString boundary( fwdMsg->mMsg->Headers().ContentType().Boundary().c_str() );
+  msgPartText = i18n("\nThis is a MIME digest forward. The content of the"
+                     " message is contained in the attachment(s).\n\n\n");
+  // iterate through all the messages to be forwarded
+  for ( KMMessage *msg = msgList.first(); msg; msg = msgList.next() ) {
+    // set the identity
+    if ( id == 0 )
+      id = msg->headerField( "X-KMail-Identity" ).stripWhiteSpace().toUInt();
+    // set the part header
+    msgPartText += "--";
+    msgPartText += QString::fromLatin1( boundary );
+    msgPartText += "\nContent-Type: MESSAGE/RFC822";
+    msgPartText += QString( "; CHARSET=%1" ).arg( msg->charset() );
+    msgPartText += '\n';
+    DwHeaders dwh;
+    dwh.MessageId().CreateDefault();
+    msgPartText += QString( "Content-ID: %1\n" ).arg( dwh.MessageId().AsString().c_str() );
+    msgPartText += QString( "Content-Description: %1" ).arg( msg->subject() );
+    if ( !msg->subject().contains( "(fwd)" ) )
+      msgPartText += " (fwd)";
+    msgPartText += "\n\n";
+    // remove headers that shouldn't be forwarded
+    msg->removePrivateHeaderFields();
+    msg->removeHeaderField( "BCC" );
+    // set the part
+    msgPartText += msg->headerAsString();
+    msgPartText += '\n';
+    msgPartText += msg->body();
+    msgPartText += '\n';     // eot
+    msgCnt++;
+    fwdMsg->link( msg, KMMsgStatusForwarded );
+  }
+
+  if ( id == 0 )
+    id = mIdentity; // use folder identity if no message had an id set
+  fwdMsg->initHeader( id );
+  msgPartText += "--";
+  msgPartText += QString::fromLatin1( boundary );
+  msgPartText += "--\n";
+  QCString tmp;
+  msgPart->setTypeStr( "MULTIPART" );
+  tmp.sprintf( "Digest; boundary=\"%s\"", boundary.data() );
+  msgPart->setSubtypeStr( tmp );
+  msgPart->setName( "unnamed" );
+  msgPart->setCte( DwMime::kCte7bit );   // does it have to be 7bit?
+  msgPart->setContentDescription( QString( "Digest of %1 messages." ).arg( msgCnt ) );
+  // THIS HAS TO BE AFTER setCte()!!!!
+  msgPart->setBodyEncoded( QCString( msgPartText.ascii() ) );
+  KCursorSaver busy( KBusyPtr::busy() );
+  KMail::Composer * win = KMail::makeComposer( fwdMsg, id );
+  win->addAttach( msgPart );
+  win->show();
+  return OK;
+}
+
 KMRedirectCommand::KMRedirectCommand( QWidget *parent,
-  KMMessage *msg )
+                                      KMMessage *msg )
   : KMCommand( parent, msg )
 {
 }
@@ -1359,6 +1411,124 @@ KMCommand::Result KMRedirectCommand::execute()
 }
 
 
+KMCustomReplyToCommand::KMCustomReplyToCommand( QWidget *parent, KMMessage *msg,
+                                                const QString &selection,
+                                                const QString &tmpl )
+  : KMCommand( parent, msg ), mSelection( selection ), mTemplate( tmpl )
+{
+}
+
+KMCommand::Result KMCustomReplyToCommand::execute()
+{
+  KCursorSaver busy(KBusyPtr::busy());
+  KMMessage *msg = retrievedMessage();
+  KMMessage *reply = msg->createReply( KMail::ReplySmart, mSelection,
+                                       false, true, false, mTemplate );
+  KMail::Composer * win = KMail::makeComposer( reply );
+  win->setCharset( msg->codec()->mimeName(), TRUE );
+  win->setReplyFocus();
+  win->show();
+
+  return OK;
+}
+
+
+KMCustomReplyAllToCommand::KMCustomReplyAllToCommand( QWidget *parent, KMMessage *msg,
+                                                      const QString &selection,
+                                                      const QString &tmpl )
+  : KMCommand( parent, msg ), mSelection( selection ), mTemplate( tmpl )
+{
+}
+
+KMCommand::Result KMCustomReplyAllToCommand::execute()
+{
+  KCursorSaver busy(KBusyPtr::busy());
+  KMMessage *msg = retrievedMessage();
+  KMMessage *reply = msg->createReply( KMail::ReplyAll, mSelection,
+                                       false, true, false, mTemplate );
+  KMail::Composer * win = KMail::makeComposer( reply );
+  win->setCharset( msg->codec()->mimeName(), TRUE );
+  win->setReplyFocus();
+  win->show();
+
+  return OK;
+}
+
+
+KMCustomForwardCommand::KMCustomForwardCommand( QWidget *parent,
+  const QPtrList<KMMsgBase> &msgList, uint identity, const QString &tmpl )
+  : KMCommand( parent, msgList ),
+    mIdentity( identity ), mTemplate( tmpl )
+{
+}
+
+KMCustomForwardCommand::KMCustomForwardCommand( QWidget *parent,
+  KMMessage *msg, uint identity, const QString &tmpl )
+  : KMCommand( parent, msg ),
+    mIdentity( identity ), mTemplate( tmpl )
+{
+}
+
+KMCommand::Result KMCustomForwardCommand::execute()
+{
+  QPtrList<KMMessage> msgList = retrievedMsgs();
+
+  if (msgList.count() >= 2) { // Multiple forward
+
+    uint id = 0;
+    // QCString msgText = "";
+    QPtrList<KMMessage> linklist;
+    for ( KMMessage *msg = msgList.first(); msg; msg = msgList.next() ) {
+      // set the identity
+      if (id == 0)
+        id = msg->headerField( "X-KMail-Identity" ).stripWhiteSpace().toUInt();
+
+      // msgText += msg->createForwardBody();
+      linklist.append( msg );
+    }
+    if ( id == 0 )
+      id = mIdentity; // use folder identity if no message had an id set
+    KMMessage *fwdMsg = new KMMessage;
+    fwdMsg->initHeader( id );
+    fwdMsg->setAutomaticFields( true );
+    fwdMsg->setCharset( "utf-8" );
+    // fwdMsg->setBody( msgText );
+
+    for ( KMMessage *msg = linklist.first(); msg; msg = linklist.next() ) {
+      TemplateParser parser( fwdMsg, TemplateParser::Forward,
+        msg->body(), false, false, false, false);
+        parser.process( msg, 0, true );
+
+      fwdMsg->link( msg, KMMsgStatusForwarded );
+    }
+
+    KCursorSaver busy( KBusyPtr::busy() );
+    KMail::Composer * win = KMail::makeComposer( fwdMsg, id );
+    win->setCharset("");
+    win->show();
+
+  } else { // forward a single message at most
+
+    KMMessage *msg = msgList.getFirst();
+    if ( !msg || !msg->codec() )
+      return Failed;
+
+    KCursorSaver busy( KBusyPtr::busy() );
+    KMMessage *fwdMsg = msg->createForward( mTemplate );
+
+    uint id = msg->headerField( "X-KMail-Identity" ).stripWhiteSpace().toUInt();
+    if ( id == 0 )
+      id = mIdentity;
+    {
+      KMail::Composer * win = KMail::makeComposer( fwdMsg, id );
+      win->setCharset( fwdMsg->codec()->mimeName(), true );
+      win->show();
+    }
+  }
+  return OK;
+}
+
+
 KMPrintCommand::KMPrintCommand( QWidget *parent,
   KMMessage *msg, bool htmlOverride, bool htmlLoadExtOverride,
   bool useFixedFont, const QString & encoding )
@@ -1462,37 +1632,46 @@ KMFilterActionCommand::KMFilterActionCommand( QWidget *parent,
                                               KMFilter *filter )
   : KMCommand( parent, msgList ), mFilter( filter  )
 {
+  QPtrListIterator<KMMsgBase> it(msgList);
+  while ( it.current() ) {
+    serNumList.append( (*it)->getMsgSerNum() );
+    ++it;
+  }
 }
 
 KMCommand::Result KMFilterActionCommand::execute()
 {
   KCursorSaver busy( KBusyPtr::busy() );
-  QPtrList<KMMessage> msgList = retrievedMsgs();
-
-  for (KMMessage *msg = msgList.first(); msg; msg = msgList.next())
-    if( msg->parent() )
-      kmkernel->filterMgr()->tempOpenFolder(msg->parent());
 
   int msgCount = 0;
-  int msgCountToFilter = msgList.count();
-  for (KMMessage *msg = msgList.first(); msg; msg = msgList.next()) {
+  int msgCountToFilter = serNumList.count();
+  ProgressItem* progressItem =
+    ProgressManager::createProgressItem ( "filter"+ProgressManager::getUniqueID(),
+                                          i18n( "Filtering messages" ) );
+  progressItem->setTotalItems( msgCountToFilter );
+  QValueList<Q_UINT32>::const_iterator it;
+  for ( it = serNumList.begin(); it != serNumList.end(); it++ ) {
+    Q_UINT32 serNum = *it;
     int diff = msgCountToFilter - ++msgCount;
-    if ( diff < 10 || !( msgCount % 20 ) ) {
+    if ( diff < 10 || !( msgCount % 20 ) || msgCount <= 10 ) {
+      progressItem->updateProgress();
       QString statusMsg = i18n("Filtering message %1 of %2");
       statusMsg = statusMsg.arg( msgCount ).arg( msgCountToFilter );
       KPIM::BroadcastStatus::instance()->setStatusMsg( statusMsg );
       KApplication::kApplication()->eventLoop()->processEvents( QEventLoop::ExcludeUserInput, 50 );
     }
-    msg->setTransferInProgress(false);
-    int filterResult = kmkernel->filterMgr()->process(msg, mFilter);
+
+    int filterResult = kmkernel->filterMgr()->process( serNum, mFilter );
     if (filterResult == 2) {
       // something went horribly wrong (out of space?)
       perror("Critical error");
       kmkernel->emergencyExit( i18n("Not enough free disk space?" ));
     }
-    msg->setTransferInProgress(true);
+    progressItem->incCompletedItems();
   }
 
+  progressItem->setComplete();
+  progressItem = 0;
   return OK;
 }
 
@@ -1524,8 +1703,9 @@ void KMMetaFilterActionCommand::start()
     for (KMMsgBase *msg = msgList.first(); msg; msg = msgList.next())
       scheduler->execFilters( msg );
   } else {
-    KMCommand *filterCommand = new KMFilterActionCommand( mMainWidget,
-    *mHeaders->selectedMsgs(), mFilter);
+    KMCommand *filterCommand =
+      new KMFilterActionCommand( mMainWidget,
+                                 *mHeaders->selectedMsgs(), mFilter );
     filterCommand->start();
     int contentX, contentY;
     HeaderItem *item = mHeaders->prepareMove( &contentX, &contentY );
@@ -1911,7 +2091,7 @@ KMCommand::Result KMMoveCommand::execute()
       msg = srcFolder->getMsg(idx);
     }
 
-    if ( msg->transferInProgress() &&
+    if ( msg && msg->transferInProgress() &&
          srcFolder->folderType() == KMFolderTypeImap )
     {
       // cancel the download
@@ -2890,7 +3070,7 @@ void KMHandleAttachmentCommand::atmSave()
 
 void KMHandleAttachmentCommand::atmProperties()
 {
-  KMMsgPartDialogCompat dlg( 0, true );
+  KMMsgPartDialogCompat dlg( parentWidget() , 0, true );
   KMMessagePart& msgPart = mNode->msgPart();
   dlg.setMsgPart( &msgPart );
   dlg.exec();
