@@ -266,6 +266,7 @@ private slots:
    * Returns true when saving was successful.
    */
   void slotSaveDraft();
+  void slotSaveTemplate();
   void slotNewComposer();
   void slotNewMailReader();
   void slotClose();
@@ -398,7 +399,7 @@ private slots:
   void slotAttachRemove();
   void slotAttachSave();
   void slotAttachProperties();
-
+  void slotAttachOpenWith();
 
   /**
    * Select an email from the addressbook and add it to the line
@@ -546,9 +547,9 @@ private:
   virtual bool queryExit ();
 
   /**
-   * Open the attachment with the given index.
+   * Open the attachment with the given index and with ("Open with")
    */
-  void openAttach( int index );
+  void openAttach( int index, bool with );
 
   /**
    * View the attachment with the given index.
@@ -614,12 +615,19 @@ private:
    * This function is for example used to restore the unencrypted/unsigned
    * message text for editting.
    */
-   static void decryptOrStripOffCleartextSignature( QCString& );
+  static void decryptOrStripOffCleartextSignature( QCString& );
+
+  /**
+   * Save the message into the Drafts or Templates folder.
+   */
+  bool saveDraftOrTemplate( const QString &folderName, KMMessage *msg );
 
   /**
    * Send the message. Returns true if the message was sent successfully.
    */
-  void doSend( KMail::MessageSender::SendMethod method=KMail::MessageSender::SendDefault, bool saveInDrafts = false);
+  enum SaveIn { None, Drafts, Templates };
+  void doSend( KMail::MessageSender::SendMethod method=KMail::MessageSender::SendDefault,
+               KMComposeWin::SaveIn saveIn = KMComposeWin::None );
 
   /**
    * Returns the autosave interval in milliseconds (as needed for QTimer).
@@ -649,6 +657,14 @@ private:
    */
   static bool validateAddresses( QWidget * parent, const QString & addresses );
 
+  /**
+   * Sets the transport combobox to @p transport. If @p transport is empty
+   * then the combobox remains unchanged. If @p transport is neither a known transport
+   * nor a custom transport then the combobox is set to the default transport.
+   * @param transport the transport the combobox should be set to
+   */
+  void setTransport( const QString & transport );
+
 private slots:
    /**
     * Compress an attachemnt with the given index
@@ -688,7 +704,7 @@ private:
   QPtrList<QListViewItem> mAtmItemList;
   QPtrList<KMMessagePart> mAtmList;
   QPopupMenu *mAttachMenu;
-  int mOpenId, mViewId, mRemoveId, mSaveAsId, mPropertiesId;
+  int mOpenId, mOpenWithId, mViewId, mRemoveId, mSaveAsId, mPropertiesId;
   bool mAutoDeleteMsg;
   bool mSigningAndEncryptionExplicitlyDisabled;
   bool mLastSignActionState, mLastEncryptActionState;
@@ -793,7 +809,7 @@ private:
 
   // These are for passing on methods over the applyChanges calls
   KMail::MessageSender::SendMethod mSendMethod;
-  bool mSaveInDrafts;
+  KMComposeWin::SaveIn mSaveIn;
 
   KToggleAction *mEncryptChiasmusAction;
   bool mEncryptWithChiasmus;
