@@ -732,4 +732,14 @@ void KMEdit::slotSpellDone()
   }
 }
 
+void KMEdit::setCursorPositionFromStart( unsigned int pos ) {
+  unsigned int l = 0;
+  unsigned int c = 0;
+  posToRowCol( pos, l, c );
+  // kdDebug() << "Num lines: " << numLines() << endl;
+  // kdDebug() << "Position " << pos << " converted to " << l << ":" << c << endl;
+  setCursorPosition( l, c );
+  ensureCursorVisible();
+}
+
 #include "kmedit.moc"
