@@ -14,7 +14,7 @@
 #include "kmfiltermgr.h"
 #include "kmfolderindex.h"
 #include "kmfoldermgr.h"
-#include "kmsender.h"
+#include "messagesender.h"
 #include "kmmainwidget.h"
 #include <libkpimidentities/identity.h>
 #include <libkpimidentities/identitymanager.h>
@@ -26,10 +26,13 @@ using KPIM::CollectingProcess;
 #include "folderrequester.h"
 using KMail::FolderRequester;
 #include "kmmsgbase.h"
+#include "templateparser.h"
 #include "messageproperty.h"
 #include "actionscheduler.h"
 using KMail::MessageProperty;
 using KMail::ActionScheduler;
+#include "regexplineedit.h"
+using KMail::RegExpLineEdit;
 #include <kregexp3.h>
 #include <ktempfile.h>
 #include <kdebug.h>
@@ -112,7 +115,7 @@ void KMFilterAction::sendMDN( KMMessage * msg, KMime::MDN::DispositionType d,
                               const QValueList<KMime::MDN::DispositionModifier> & m ) {
   if ( !msg ) return;
   KMMessage * mdn = msg->createMDN( KMime::MDN::AutomaticAction, d, false, m );
-  if ( mdn && !kmkernel->msgSender()->send( mdn, FALSE ) ) {
+  if ( mdn && !kmkernel->msgSender()->send( mdn, KMail::MessageSender::SendLater ) ) {
     kdDebug(5006) << "KMFilterAction::sendMDN(): sending failed." << endl;
     //delete mdn;
   }
@@ -277,7 +280,6 @@ QWidget* KMFilterActionWithFolder::createParamWidget( QWidget* parent ) const
 {
   FolderRequester *req = new FolderRequester( parent,
       kmkernel->getKMMainWidget()->folderTree() );
-  req->setShowImapFolders( false );
   setParamWidgetValue( req );
   return req;
 }
@@ -285,14 +287,7 @@ QWidget* KMFilterActionWithFolder::createParamWidget( QWidget* parent ) const
 void KMFilterActionWithFolder::applyParamWidgetValue( QWidget* paramWidget )
 {
   mFolder = ((FolderRequester *)paramWidget)->folder();
-  if (mFolder)
-  {
-     mFolderName = QString::null;
-  }
-  else
-  {
-     mFolderName = ((FolderRequester *)paramWidget)->text();
-  }
+  mFolderName = ((FolderRequester *)paramWidget)->folderId();
 }
 
 void KMFilterActionWithFolder::setParamWidgetValue( QWidget* paramWidget ) const
@@ -313,8 +308,10 @@ void KMFilterActionWithFolder::argsFromString( const QString argsStr )
   mFolder = kmkernel->folderMgr()->findIdString( argsStr );
   if (!mFolder)
      mFolder = kmkernel->dimapFolderMgr()->findIdString( argsStr );
+  if (!mFolder)
+     mFolder = kmkernel->imapFolderMgr()->findIdString( argsStr );
   if (mFolder)
-     mFolderName = QString::null;
+     mFolderName = mFolder->idString();
   else
      mFolderName = argsStr;
 }
@@ -344,9 +341,7 @@ bool KMFilterActionWithFolder::folderRemoved( KMFolder* aFolder, KMFolder* aNewF
   if ( aFolder == mFolder ) {
     mFolder = aNewFolder;
     if ( aNewFolder )
-      mFolderName = QString::null;
-    else
-      mFolderName = i18n( "<select a folder>" );
+      mFolderName = mFolder->idString();
     return TRUE;
   } else
     return FALSE;
@@ -592,7 +587,7 @@ KMFilterAction::ReturnCode KMFilterActionSendReceipt::process(KMMessage* msg) co
 
   // Queue message. This is a) so that the user can check
   // the receipt before sending and b) for speed reasons.
-  kmkernel->msgSender()->send( receipt, FALSE );
+  kmkernel->msgSender()->send( receipt, KMail::MessageSender::SendLater );
 
   return GoOn;
 }
@@ -1200,14 +1195,14 @@ QWidget* KMFilterActionRewriteHeader::createParamWidget( QWidget* parent ) const
   l->setFixedWidth( l->sizeHint().width() );
   hbl->addWidget( l, 0 );
 
-  QLineEdit *le = new KLineEdit( w, "search" );
-  hbl->addWidget( le, 1 );
+  RegExpLineEdit *rele = new RegExpLineEdit( w, "search" );
+  hbl->addWidget( rele, 1 );
 
   l = new QLabel( i18n("With:"), w );
   l->setFixedWidth( l->sizeHint().width() );
   hbl->addWidget( l, 0 );
 
-  le = new KLineEdit( w, "replace" );
+  QLineEdit *le = new KLineEdit( w, "replace" );
   hbl->addWidget( le, 1 );
 
   setParamWidgetValue( w );
@@ -1229,11 +1224,11 @@ void KMFilterActionRewriteHeader::setParamWidgetValue( QWidget* paramWidget ) co
     cb->setCurrentItem( idx );
   }
 
-  QLineEdit *le = (QLineEdit*)paramWidget->child("search");
-  Q_ASSERT( le );
-  le->setText( mRegExp.pattern() );
+  RegExpLineEdit *rele = (RegExpLineEdit*)paramWidget->child("search");
+  Q_ASSERT( rele );
+  rele->setText( mRegExp.pattern() );
 
-  le = (QLineEdit*)paramWidget->child("replace");
+  QLineEdit *le = (QLineEdit*)paramWidget->child("replace");
   Q_ASSERT( le );
   le->setText( mReplacementString );
 }
@@ -1244,11 +1239,11 @@ void KMFilterActionRewriteHeader::applyParamWidgetValue( QWidget* paramWidget )
   Q_ASSERT( cb );
   mParameter = cb->currentText();
 
-  QLineEdit *le = (QLineEdit*)paramWidget->child("search");
-  Q_ASSERT( le );
-  mRegExp.setPattern( le->text() );
+  RegExpLineEdit *rele = (RegExpLineEdit*)paramWidget->child("search");
+  Q_ASSERT( rele );
+  mRegExp.setPattern( rele->text() );
 
-  le = (QLineEdit*)paramWidget->child("replace");
+  QLineEdit *le = (QLineEdit*)paramWidget->child("replace");
   Q_ASSERT( le );
   mReplacementString = le->text();
 }
@@ -1259,11 +1254,11 @@ void KMFilterActionRewriteHeader::clearParamWidget( QWidget* paramWidget ) const
   Q_ASSERT( cb );
   cb->setCurrentItem(0);
 
-  QLineEdit *le = (QLineEdit*)paramWidget->child("search");
-  Q_ASSERT( le );
-  le->clear();
+  RegExpLineEdit *rele = (RegExpLineEdit*)paramWidget->child("search");
+  Q_ASSERT( rele );
+  rele->clear();
 
-  le = (QLineEdit*)paramWidget->child("replace");
+  QLineEdit *le = (QLineEdit*)paramWidget->child("replace");
   Q_ASSERT( le );
   le->clear();
 }
@@ -1332,7 +1327,18 @@ KMFilterAction::ReturnCode KMFilterActionMove::process(KMMessage* msg) const
   if ( !mFolder )
     return ErrorButGoOn;
 
-  MessageProperty::setFilterFolder( msg, mFolder );
+  ActionScheduler *handler = MessageProperty::filterHandler( msg );
+  if (handler) {
+    MessageProperty::setFilterFolder( msg, mFolder );
+  } else {
+    // The old filtering system does not support online imap targets.
+    // Skip online imap targets when using the old system.
+    KMFolder *check;
+    check = kmkernel->imapFolderMgr()->findIdString( argsAsString() );
+    if (mFolder && (check != mFolder)) {
+      MessageProperty::setFilterFolder( msg, mFolder );
+    }
+  }
   return GoOn;
 }
 
@@ -1351,6 +1357,7 @@ class KMFilterActionCopy: public KMFilterActionWithFolder
 public:
   KMFilterActionCopy();
   virtual ReturnCode process(KMMessage* msg) const;
+  virtual void processAsync(KMMessage* msg) const;
   virtual bool requiresBody(KMMsgBase*) const;
   static KMFilterAction* newAction(void);
 };
@@ -1367,26 +1374,37 @@ KMFilterActionCopy::KMFilterActionCopy()
 
 KMFilterAction::ReturnCode KMFilterActionCopy::process(KMMessage* msg) const
 {
-  if ( !mFolder )
+  // TODO opening and closing the folder is a trade off.
+  // Perhaps Copy is a seldomly used action for now,
+  // but I gonna look at improvements ASAP.
+  if ( !mFolder && mFolder->open() != 0 )
     return ErrorButGoOn;
 
   // copy the message 1:1
   KMMessage* msgCopy = new KMMessage;
   msgCopy->fromDwString(msg->asDwString());
 
-  // TODO opening and closing the folder is a trade off.
-  // Perhaps Copy is a seldomly used action for now,
-  // but I gonna look at improvements ASAP.
-  mFolder->open();
   int index;
   int rc = mFolder->addMsg(msgCopy, &index);
   if (rc == 0 && index != -1)
-    mFolder->unGetMsg( mFolder->count() - 1 );
+    mFolder->unGetMsg( index );
   mFolder->close();
 
   return GoOn;
 }
 
+void KMFilterActionCopy::processAsync(KMMessage* msg) const
+{
+  // FIXME remove the debug output
+  kdDebug(5006) << "##### KMFilterActionCopy::processAsync(KMMessage* msg)" << endl;
+  ActionScheduler *handler = MessageProperty::filterHandler( msg );
+
+  KMCommand *cmd = new KMCopyCommand( mFolder, msg );
+  QObject::connect( cmd, SIGNAL( completed( KMCommand * ) ),
+                    handler, SLOT( copyMessageFinished( KMCommand * ) ) );
+  cmd->start();
+}
+
 bool KMFilterActionCopy::requiresBody(KMMsgBase*) const
 {
     return true;
@@ -1435,14 +1453,19 @@ KMFilterAction::ReturnCode KMFilterActionForward::process(KMMessage* aMsg) const
 
   msg->initFromMessage( aMsg );
 
-  QString st = QString::fromUtf8( aMsg->createForwardBody() );
+  // QString st = QString::fromUtf8( aMsg->createForwardBody() );
+  
+  TemplateParser parser( msg, TemplateParser::Forward, 
+    aMsg->body(), false, false, false, false);
+  parser.process( aMsg );
+  
   QCString
     encoding = KMMsgBase::autoDetectCharset( aMsg->charset(),
                                              KMMessage::preferredCharsets(),
-                                             st );
+                                             msg->body() );
   if( encoding.isEmpty() )
     encoding = "utf-8";
-  QCString str = KMMsgBase::codecForName( encoding )->fromUnicode( st );
+  QCString str = KMMsgBase::codecForName( encoding )->fromUnicode( msg->body() );
 
   msg->setCharset( encoding );
   msg->setTo( mParameter );
@@ -1493,7 +1516,7 @@ KMFilterAction::ReturnCode KMFilterActionForward::process(KMMessage* aMsg) const
 
   sendMDN( aMsg, KMime::MDN::Dispatched );
 
-  if ( !kmkernel->msgSender()->send( msg, FALSE ) ) {
+  if ( !kmkernel->msgSender()->send( msg, KMail::MessageSender::SendLater ) ) {
     kdDebug(5006) << "KMFilterAction: could not forward message (sending failed)" << endl;
     return ErrorButGoOn; // error: couldn't send
   }
@@ -1533,7 +1556,7 @@ KMFilterAction::ReturnCode KMFilterActionRedirect::process(KMMessage* aMsg) cons
 
   sendMDN( aMsg, KMime::MDN::Dispatched );
 
-  if ( !kmkernel->msgSender()->send( msg, FALSE ) ) {
+  if ( !kmkernel->msgSender()->send( msg, KMail::MessageSender::SendLater ) ) {
     kdDebug(5006) << "KMFilterAction: could not redirect message (sending failed)" << endl;
     return ErrorButGoOn; // error: couldn't send
   }
@@ -1600,6 +1623,9 @@ class PipeJob : public KPIM::ThreadWeaver::Job
       FILE *p;
       QByteArray ba;
 
+      // backup the serial number in case the header gets lost
+      QString origSerNum = mMsg->headerField( "X-KMail-Filtered" );
+
       p = popen(QFile::encodeName(mCmd), "r");
       int len =100;
       char buffer[100];
@@ -1613,7 +1639,20 @@ class PipeJob : public KPIM::ThreadWeaver::Job
       pclose(p);
       if ( !ba.isEmpty() ) {
         KPIM::ThreadWeaver::debug (1, "PipeJob::run: %s", QString(ba).latin1() );
+        KMFolder *filterFolder =  mMsg->parent();
+        ActionScheduler *handler = MessageProperty::filterHandler( mMsg->getMsgSerNum() );
+
         mMsg->fromByteArray( ba );
+        if ( !origSerNum.isEmpty() )
+          mMsg->setHeaderField( "X-KMail-Filtered", origSerNum );
+        if ( filterFolder && handler ) {
+          bool oldStatus = handler->ignoreChanges( true );
+          filterFolder->take( filterFolder->find( mMsg ) );
+          filterFolder->addMsg( mMsg );
+          handler->ignoreChanges( oldStatus );
+        } else {
+          kdDebug(5006) << "Warning: Cannot refresh the message from the external filter." << endl;
+        }
       }
 
       KPIM::ThreadWeaver::debug (1, "PipeJob::run: done.\n" );
