@@ -72,7 +72,7 @@ class KMFolder: public KMFolderNode
 public:
 
   /**
-   * Constructs a new Folder object. 
+   * Constructs a new Folder object.
    * @param parent The directory in the folder storage hierarchy under which
    * the folder's storage will be found or created.
    * @param name If name of the folder. In case there is no parent directory, because
@@ -99,21 +99,26 @@ public:
   bool isOutbox() {
     return this == KMKernel::self()->outboxFolder();
   }
-  /** Retuns true if this folder is the sent-mail box of the local account,
+  /** Returns true if this folder is the sent-mail box of the local account,
     or is configured to be the sent mail box of any of the users identities */
   bool isSent() {
     return KMKernel::self()->folderIsSentMailFolder( this );
   }
-  /** Retuns true if this folder is configured as a trash folder, localy or
+  /** Returns true if this folder is configured as a trash folder, locally or
     for one of the accounts. */
   bool isTrash() {
     return KMKernel::self()->folderIsTrash( this );
   }
-  /** Retuns true if this folder is the drafts box of the local account,
+  /** Returns true if this folder is the drafts box of the local account,
     or is configured to be the drafts box of any of the users identities */
   bool isDrafts() {
     return KMKernel::self()->folderIsDrafts( this );
   }
+  /** Returns true if this folder is the templates folder of the local account,
+    or is configured to be the templates folder of any of the users identities */
+  bool isTemplates() {
+    return KMKernel::self()->folderIsTemplates( this );
+  }
 
   void setAcctList( AccountList* list ) { mAcctList = list; }
   AccountList* acctList() { return mAcctList; }
@@ -353,9 +358,9 @@ public:
   bool isReadOnly() const;
 
   /** Returns true if the folder is a kmail system folder. These are
-    the folders 'inbox', 'outbox', 'sent', 'trash'. The name of these
-    folders is nationalized in the folder display and they cannot have
-    accounts associated. Deletion is also forbidden. Etc. */
+    the folders 'inbox', 'outbox', 'sent', 'trash', 'drafts', 'templates'.
+    The name of these folders is nationalized in the folder display and
+    they cannot have accounts associated. Deletion is also forbidden. Etc. */
   bool isSystemFolder() const { return mIsSystemFolder; }
   void setSystemFolder(bool itIs) { mIsSystemFolder=itIs; }
 
@@ -617,9 +622,9 @@ private:
   /** Mailing list attributes */
   bool                mMailingListEnabled;
   MailingList         mMailingList;
-  
+
   AccountList* mAcctList;
-  
+
   uint mIdentity;
 
   /** name of the field that is used for "From" in listbox */
