@@ -52,6 +52,7 @@ using KMail::MailServiceImpl;
 #include "folderIface.h"
 using KMail::FolderIface;
 #include "jobscheduler.h"
+#include "templateparser.h"
 
 #include <kapplication.h>
 #include <kmessagebox.h>
@@ -111,6 +112,7 @@ KMKernel::KMKernel (QObject *parent, const char *name) :
   the_sentFolder = 0;
   the_trashFolder = 0;
   the_draftsFolder = 0;
+  the_templatesFolder = 0;
 
   the_folderMgr = 0;
   the_imapFolderMgr = 0;
@@ -192,6 +194,7 @@ KMKernel::~KMKernel ()
 bool KMKernel::handleCommandLine( bool noArgsOpensReader )
 {
   QString to, cc, bcc, subj, body;
+  QCStringList customHeaders;
   KURL messageFile;
   KURL::List attachURLs;
   bool mailto = false;
@@ -252,6 +255,8 @@ bool KMKernel::handleCommandLine( bool noArgsOpensReader )
          attachURLs += KURL( QString::fromLocal8Bit( *it ) );
   }
 
+  customHeaders = args->getOptionList("header");
+
   if (args->isSet("composer"))
     mailto = true;
 
@@ -302,7 +307,7 @@ bool KMKernel::handleCommandLine( bool noArgsOpensReader )
     viewMessage( messageFile );
   else
     action( mailto, checkMail, to, cc, bcc, subj, body, messageFile,
-            attachURLs );
+            attachURLs, customHeaders );
   return true;
 }
 
@@ -330,7 +335,7 @@ void KMKernel::checkAccount (const QString &account) //might create a new reader
 
 void KMKernel::openReader( bool onlyCheck )
 {
-  KMMainWin *mWin = 0;
+  mWin = 0;
   KMainWindow *ktmw = 0;
   kdDebug(5006) << "KMKernel::openReader called" << endl;
 
@@ -346,8 +351,7 @@ void KMKernel::openReader( bool onlyCheck )
     activate = !onlyCheck; // existing window: only activate if not --check
     if ( activate )
        mWin->show();
-  }
-  else {
+  } else {
     mWin = new KMMainWin;
     mWin->show();
     activate = false; // new window: no explicit activation (#73591)
@@ -366,7 +370,8 @@ int KMKernel::openComposer (const QString &to, const QString &cc,
                             const QString &bcc, const QString &subject,
                             const QString &body, int hidden,
                             const KURL &messageFile,
-                            const KURL::List &attachURLs)
+                            const KURL::List &attachURLs,
+                            const QCStringList &customHeaders)
 {
   kdDebug(5006) << "KMKernel::openComposer called" << endl;
   KMMessage *msg = new KMMessage;
@@ -383,11 +388,41 @@ int KMKernel::openComposer (const QString &to, const QString &cc,
   if (!subject.isEmpty()) msg->setSubject(subject);
   if (!messageFile.isEmpty() && messageFile.isLocalFile()) {
     QCString str = KPIM::kFileToString( messageFile.path(), true, false );
-    if( !str.isEmpty() )
+    if( !str.isEmpty() ) {
       msg->setBody( QString::fromLocal8Bit( str ).utf8() );
+    } else {
+      TemplateParser parser( msg, TemplateParser::NewMessage,
+	"", false, false, false, false );
+      parser.process( NULL, NULL );
+    }
   }
   else if (!body.isEmpty())
+  {
     msg->setBody(body.utf8());
+  }
+  else
+  {
+    TemplateParser parser( msg, TemplateParser::NewMessage,
+      "", false, false, false, false );
+    parser.process( NULL, NULL );
+  }
+
+  if (!customHeaders.isEmpty())
+  {
+    for ( QCStringList::ConstIterator it = customHeaders.begin() ; it != customHeaders.end() ; ++it )
+      if ( !(*it).isEmpty() )
+      {
+        const int pos = (*it).find( ':' );
+        if ( pos > 0 )
+        {
+          QCString header, value;
+          header = (*it).left( pos ).stripWhiteSpace();
+          value = (*it).mid( pos+1 ).stripWhiteSpace();
+          if ( !header.isEmpty() && !value.isEmpty() )
+            msg->setHeaderField( header, value );
+        }
+      }
+  }
 
   KMail::Composer * cWin = KMail::makeComposer( msg );
   cWin->setCharset("", TRUE);
@@ -448,7 +483,13 @@ int KMKernel::openComposer (const QString &to, const QString &cc,
   if ( !bcc.isEmpty() ) msg->setBcc(bcc);
   if ( !subject.isEmpty() ) msg->setSubject(subject);
   if ( !to.isEmpty() ) msg->setTo(to);
-  if ( !body.isEmpty() ) msg->setBody(body.utf8());
+  if ( !body.isEmpty() ) {
+    msg->setBody(body.utf8());
+  } else {
+    TemplateParser parser( msg, TemplateParser::NewMessage,
+      "", false, false, false, false );
+    parser.process( NULL, NULL );
+  }
 
   bool iCalAutoSend = false;
   bool noWordWrap = false;
@@ -543,7 +584,13 @@ DCOPRef KMKernel::openComposer(const QString &to, const QString &cc,
   if (!bcc.isEmpty()) msg->setBcc(bcc);
   if (!subject.isEmpty()) msg->setSubject(subject);
   if (!to.isEmpty()) msg->setTo(to);
-  if (!body.isEmpty()) msg->setBody(body.utf8());
+  if (!body.isEmpty()) {
+    msg->setBody(body.utf8());
+  } else {
+    TemplateParser parser( msg, TemplateParser::NewMessage,
+      "", false, false, false, false );
+    parser.process( NULL, NULL );
+  }
 
   KMail::Composer * cWin = KMail::makeComposer( msg );
   cWin->setCharset("", TRUE);
@@ -569,16 +616,16 @@ DCOPRef KMKernel::newMessage(const QString &to,
 {
   KMail::Composer * win = 0;
   KMMessage *msg = new KMMessage;
+  KMFolder *folder = NULL;
+  uint id;
 
   if ( useFolderId ) {
     //create message with required folder identity
-    KMFolder *folder = currentFolder();
-    uint id = folder ? folder->identity() : 0;
+    folder = currentFolder();
+    id = folder ? folder->identity() : 0;
     msg->initHeader( id );
-    win = makeComposer( msg, id );
   } else {
     msg->initHeader();
-    win = makeComposer( msg );
   }
   msg->setCharset("utf-8");
   //set basic headers
@@ -586,10 +633,23 @@ DCOPRef KMKernel::newMessage(const QString &to,
   if (!cc.isEmpty()) msg->setCc(cc);
   if (!bcc.isEmpty()) msg->setBcc(bcc);
 
+  if ( useFolderId ) {
+    TemplateParser parser( msg, TemplateParser::NewMessage,
+      "", false, false, false, false );
+    parser.process( NULL, folder );
+    win = makeComposer( msg, id );
+  } else {
+    TemplateParser parser( msg, TemplateParser::NewMessage,
+      "", false, false, false, false );
+    parser.process( NULL, folder );
+    win = makeComposer( msg );
+  }
+
   //Add the attachment if we have one
   if(!attachURL.isEmpty() && attachURL.isValid()) {
     win->addAttach(attachURL);
   }
+
   //only show window when required
   if(!hidden) {
     win->show();
@@ -761,8 +821,7 @@ int KMKernel::dcopAddMessage( const QString & foldername,const KURL & msgUrl,
               tmp_fname = "/" + *it;
             }
             else return -1;
-          }
-          else {
+          } else {
             subfolder = folder->createChildFolder();
             tmp_fname += "/" + *it;
             if(!the_folderMgr->getFolderByURL( tmp_fname )) {
@@ -776,8 +835,7 @@ int KMKernel::dcopAddMessage( const QString & foldername,const KURL & msgUrl,
         mAddMsgCurrentFolder = the_folderMgr->getFolderByURL( tmp_fname );
         if(!folder) return -1;
 
-      }
-      else {
+      } else {
         mAddMsgCurrentFolder = the_folderMgr->findOrCreate(_foldername, false);
       }
     }
@@ -941,8 +999,7 @@ int KMKernel::dcopAddMessage_fastImport( const QString & foldername,
               tmp_fname = "/" + *it;
             }
             else return -1;
-          }
-          else {
+          } else {
             subfolder = folder->createChildFolder();
             tmp_fname += "/" + *it;
             if(!the_folderMgr->getFolderByURL( tmp_fname )) {
@@ -955,8 +1012,7 @@ int KMKernel::dcopAddMessage_fastImport( const QString & foldername,
       mAddMsgCurrentFolder = the_folderMgr->getFolderByURL( tmp_fname );
       if(!folder) return -1;
 
-      }
-      else {
+      } else {
         mAddMsgCurrentFolder = the_folderMgr->findOrCreate(_foldername, false);
       }
     }
@@ -1354,7 +1410,7 @@ void KMKernel::initFolders(KConfig* cfg)
   if (the_trashFolder->canAccess() != 0) {
     emergencyExit( i18n("You do not have read/write permission to your trash folder.") );
   }
-  the_trashFolder->setSystemFolder(TRUE);
+  the_trashFolder->setSystemFolder( TRUE );
   if ( the_trashFolder->userWhoField().isEmpty() )
     the_trashFolder->setUserWhoField( QString::null );
   // the_trashFolder->open();
@@ -1363,10 +1419,21 @@ void KMKernel::initFolders(KConfig* cfg)
   if (the_draftsFolder->canAccess() != 0) {
     emergencyExit( i18n("You do not have read/write permission to your drafts folder.") );
   }
-  the_draftsFolder->setSystemFolder(TRUE);
+  the_draftsFolder->setSystemFolder( TRUE );
   if ( the_draftsFolder->userWhoField().isEmpty() )
     the_draftsFolder->setUserWhoField( QString::null );
   the_draftsFolder->open();
+
+  the_templatesFolder =
+    the_folderMgr->findOrCreate( cfg->readEntry( "templatesFolder",
+                                                 I18N_NOOP("templates") ) );
+  if ( the_templatesFolder->canAccess() != 0 ) {
+    emergencyExit( i18n("You do not have read/write permission to your templates folder.") );
+  }
+  the_templatesFolder->setSystemFolder( TRUE );
+  if ( the_templatesFolder->userWhoField().isEmpty() )
+    the_templatesFolder->setUserWhoField( QString::null );
+  the_templatesFolder->open();
 }
 
 
@@ -1652,7 +1719,8 @@ void KMKernel::cleanup(void)
   the_searchFolderMgr = 0;
   delete mConfigureDialog;
   mConfigureDialog = 0;
-  delete mWin;
+  // do not delete, because mWin may point to an existing window
+  // delete mWin;
   mWin = 0;
 
   if ( RecentAddresses::exists() )
@@ -1709,8 +1777,7 @@ bool KMKernel::transferMail( QString & destinationDir )
                 "files now?</strong></qt>" )
           .arg( kmailName, kmailName, kmailName )
           .arg( dir, destinationDir, dir, destinationDir );
-  }
-  else {
+  } else {
     msg = i18n( "%1-%3 is the application name, %4-%6 are folder path",
                 "<qt>The <i>%4</i> folder exists. "
                 "%1 now uses the <i>%5</i> folder for "
@@ -1802,14 +1869,15 @@ void KMKernel::action(bool mailto, bool check, const QString &to,
                       const QString &cc, const QString &bcc,
                       const QString &subj, const QString &body,
                       const KURL &messageFile,
-                      const KURL::List &attachURLs)
+                      const KURL::List &attachURLs,
+                      const QCStringList &customHeaders)
 {
-  if (mailto)
-    openComposer (to, cc, bcc, subj, body, 0, messageFile, attachURLs);
+  if ( mailto )
+    openComposer( to, cc, bcc, subj, body, 0, messageFile, attachURLs, customHeaders );
   else
     openReader( check );
 
-  if (check)
+  if ( check )
     checkMail();
   //Anything else?
 }
@@ -1937,8 +2005,7 @@ void KMKernel::emergencyExit( const QString& reason )
   QString mesg;
   if ( reason.length() == 0 ) {
     mesg = i18n("KMail encountered a fatal error and will terminate now");
-  }
-  else {
+  } else {
     mesg = i18n("KMail encountered a fatal error and will "
                       "terminate now.\nThe error was:\n%1").arg( reason );
   }
@@ -1967,12 +2034,32 @@ bool KMKernel::folderIsDrafts(const KMFolder * folder)
     return true;
 
   QString idString = folder->idString();
-  if ( idString.isEmpty() ) return false;
+  if ( idString.isEmpty() )
+    return false;
 
   // search the identities if the folder matches the drafts-folder
-  const KPIM::IdentityManager * im = identityManager();
-  for( KPIM::IdentityManager::ConstIterator it = im->begin(); it != im->end(); ++it )
-    if ( (*it).drafts() == idString ) return true;
+  const KPIM::IdentityManager *im = identityManager();
+  for ( KPIM::IdentityManager::ConstIterator it=im->begin(); it != im->end(); ++it )
+    if ( (*it).drafts() == idString )
+      return true;
+  return false;
+}
+
+bool KMKernel::folderIsTemplates( const KMFolder *folder )
+{
+  assert( folder );
+  if ( folder == the_templatesFolder )
+    return true;
+
+  QString idString = folder->idString();
+  if ( idString.isEmpty() )
+    return false;
+
+  // search the identities if the folder matches the templates-folder
+  const KPIM::IdentityManager *im = identityManager();
+  for ( KPIM::IdentityManager::ConstIterator it=im->begin(); it != im->end(); ++it )
+    if ( (*it).templates() == idString )
+      return true;
   return false;
 }
 
@@ -2247,9 +2334,15 @@ Wallet *KMKernel::wallet() {
   if ( !Wallet::isEnabled() || walletOpenFailed )
     return 0;
 
+  // find an appropriate parent window for the wallet dialog
+  WId window = 0;
+  if ( qApp->activeWindow() )
+    window = qApp->activeWindow()->winId();
+  else if ( getKMMainWidget() )
+    window = getKMMainWidget()->topLevelWidget()->winId();
+
   delete mWallet;
-  mWallet = Wallet::openWallet( Wallet::NetworkWallet(),
-        getKMMainWidget() ? getKMMainWidget()->topLevelWidget()->winId() : 0 );
+  mWallet = Wallet::openWallet( Wallet::NetworkWallet(), window );
 
   if ( !mWallet ) {
     walletOpenFailed = true;
