@@ -25,6 +25,7 @@
 #include <kxmlguiclient.h>
 #include <qlistview.h>
 #include <qvbox.h>
+#include <qvaluevector.h>
 
 #include "kmreaderwin.h" //for inline actions
 #include "kmkernel.h" // for access to config
@@ -32,6 +33,7 @@
 
 class QVBoxLayout;
 class QSplitter;
+class QSignalMapper;
 
 class KActionMenu;
 class KActionCollection;
@@ -110,12 +112,15 @@ public:
   KAction *replyAuthorAction() const { return mReplyAuthorAction; }
   KAction *replyAllAction() const { return mReplyAllAction; }
   KAction *replyListAction() const { return mReplyListAction; }
+  KActionMenu *customReplyAction() const { return mCustomReplyActionMenu; }
+  KActionMenu *customReplyAllAction() const { return mCustomReplyAllActionMenu; }
   KActionMenu * replyMenu() const { return mReplyActionMenu; }
   KActionMenu *forwardMenu() const { return mForwardActionMenu; }
   KAction *forwardInlineAction() const { return mForwardInlineAction; }
   KAction *forwardAttachedAction() const { return mForwardAttachedAction; }
   KAction *forwardDigestAction() const { return mForwardDigestAction; }
   KAction *redirectAction() const { return mRedirectAction; }
+  KActionMenu *customForwardAction() const { return mCustomForwardActionMenu; }
   KAction *noQuoteReplyAction() const { return mNoQuoteReplyAction; }
   KActionMenu *filterMenu() const { return mFilterMenu; }
   KAction *printAction() const { return mPrintAction; }
@@ -125,6 +130,7 @@ public:
   KAction *deleteThreadAction() const { return mDeleteThreadAction; }
   KAction *saveAsAction() const { return mSaveAsAction; }
   KAction *editAction() const { return mEditAction; }
+  KAction *useAction() const { return mUseAction; }
   KAction *sendAgainAction() const { return mSendAgainAction; }
   KAction *applyAllFiltersAction() const { return mApplyAllFiltersAction; }
   KAction *findInMessageAction() const { return mFindInMessageAction; }
@@ -221,6 +227,8 @@ public slots:
   /** Add, remove or adjust the folder's shortcut. */
   void slotShortcutChanged( KMFolder *folder );
 
+  void updateCustomTemplateMenus();
+
 signals:
   void messagesTransfered( bool );
   void captionChangeRequest( const QString & caption );
@@ -229,8 +237,9 @@ protected:
   void setupActions();
   void createWidgets();
   void activatePanners();
-  void showMsg(KMReaderWin *win, KMMessage *msg);
+  void showMsg( KMReaderWin *win, KMMessage *msg );
   void updateFileMenu();
+  void newFromTemplate( KMMessage *msg );
 
   KActionCollection * actionCollection() const { return mActionCollection; }
 
@@ -273,6 +282,7 @@ protected slots:
   void slotToggleSubjectThreading();
   void slotMessageQueuedOrDrafted();
   void slotEditMsg();
+  void slotUseTemplate();
   //void slotTrashMsg();   // move to trash
   void slotDeleteMsg( bool confirmDelete = true );  // completely delete message
   void slotTrashThread();
@@ -343,7 +353,10 @@ protected slots:
 
   /** etc. */
   void slotDisplayCurrentMessage();
-  void slotMsgActivated(KMMessage*);
+  void slotMsgActivated( KMMessage* );
+
+  void slotShowNewFromTemplate();
+  void slotNewFromTemplate( int );
 
   /** Update the undo action */
   void slotUpdateUndo();
@@ -374,10 +387,13 @@ protected slots:
   void slotReplyAuthorToMsg();
   void slotReplyListToMsg();
   void slotReplyAllToMsg();
+  void slotCustomReplyToMsg( int tid );
+  void slotCustomReplyAllToMsg( int tid );
   void slotForwardInlineMsg();
   void slotForwardAttachedMsg();
   void slotForwardDigestMsg();
   void slotRedirectMsg();
+  void slotCustomForwardMsg( int tid );
   void slotNoQuoteReplyToMsg();
   void slotSubjectFilter();
   void slotMailingListFilter();
@@ -404,21 +420,30 @@ private:
 private:
   // Message actions
   KAction *mTrashAction, *mDeleteAction, *mTrashThreadAction,
-    *mDeleteThreadAction, *mSaveAsAction, *mEditAction,
+    *mDeleteThreadAction, *mSaveAsAction, *mEditAction, *mUseAction,
     *mSendAgainAction, *mApplyAllFiltersAction, *mFindInMessageAction,
     *mSaveAttachmentsAction, *mOpenAction, *mViewSourceAction;
   // Composition actions
   KAction *mPrintAction, *mReplyAction, *mReplyAllAction, *mReplyAuthorAction,
     *mReplyListAction,
     *mForwardInlineAction, *mForwardAttachedAction, *mForwardDigestAction,
-    *mRedirectAction,
-    *mNoQuoteReplyAction;
+    *mRedirectAction, *mNoQuoteReplyAction;
   KActionMenu *mReplyActionMenu;
   KActionMenu *mForwardActionMenu;
   // Filter actions
   KActionMenu *mFilterMenu;
   KAction *mSubjectFilterAction, *mFromFilterAction, *mToFilterAction,
       *mListFilterAction;
+  KActionMenu *mTemplateMenu;
+
+  // Custom template actions menu
+  KActionMenu *mCustomReplyActionMenu,
+              *mCustomReplyAllActionMenu,
+              *mCustomForwardActionMenu;
+  // Signal mappers for custom template actions
+  QSignalMapper *mCustomReplyMapper,
+                *mCustomReplyAllMapper,
+                *mCustomForwardMapper;
 
   KActionMenu *mStatusMenu, *mThreadStatusMenu,
     *mMoveActionMenu, *mCopyActionMenu, *mApplyFilterActionsMenu;
@@ -428,7 +453,6 @@ private:
   KToggleAction *mToggleThreadTodoAction;
   KToggleAction *mToggleThreadFlagAction;
   KToggleAction *mToggleTodoAction;
-  KToggleAction *mToggleSentAction;
   KToggleAction *mToggleFlagAction;
 
   KToggleAction *mWatchThreadAction, *mIgnoreThreadAction;
@@ -448,6 +472,7 @@ private:
   KToolBar     *mSearchToolBar;
   KMail::HeaderListQuickSearch *mQuickSearchLine;
   KMFolder     *mFolder;
+  KMFolder     *mTemplateFolder;
   QPopupMenu   *mViewMenu, *mBodyPartsMenu;
   KAction       *mlistFilterAction;
   bool		mIntegrated;
@@ -498,6 +523,9 @@ private:
   QDict<FolderShortcutCommand> mFolderShortcutCommands;
   QGuardedPtr <KMail::FolderJob> mJob;
 
+  QValueVector<QString> mCustomTemplates;
+  QPtrList<KAction> mCustomTemplateActions;
+
   KMSystemTray  *mSystemTray;
   KConfig *mConfig;
   KXMLGUIClient *mGUIClient;
