@@ -162,7 +162,8 @@ public:
       is not stored in any folder. Marks this message as replied. */
   KMMessage* createReply( KMail::ReplyStrategy replyStrategy = KMail::ReplySmart,
                           QString selection=QString::null, bool noQuote=FALSE,
-                          bool allowDecryption=TRUE, bool selectionIsBody=FALSE);
+                          bool allowDecryption=TRUE, bool selectionIsBody=FALSE,
+                          const QString &tmpl = QString::null );
 
   /** Create a new message that is a redirect to this message, filling all
     required header fields with the proper values. The returned message
@@ -179,7 +180,7 @@ public:
   /** Create a new message that is a forward of this message, filling all
     required header fields with the proper values. The returned message
     is not stored in any folder. Marks this message as forwarded. */
-  KMMessage* createForward();
+  KMMessage* createForward( const QString &tmpl = QString::null );
 
   /** Create a new message that is a delivery receipt of this message,
       filling required header fileds with the proper values. The
@@ -308,25 +309,29 @@ public:
 
   /** Get or set the 'ReplyTo' header field */
   QString replyTo() const;
-  void setReplyTo(const QString& aStr);
+  void setReplyTo( const QString &aStr );
   void setReplyTo(KMMessage*);
 
   /** Get or set the 'Cc' header field */
   QString cc() const;
-  void setCc(const QString& aStr);
+  void setCc( const QString &aStr );
   QString ccStrip() const;
 
   /** Get or set the 'Bcc' header field */
   QString bcc() const;
-  void setBcc(const QString& aStr);
+  void setBcc( const QString &aStr );
 
   /** Get or set the 'Fcc' header field */
   QString fcc() const;
-  void setFcc(const QString& aStr);
+  void setFcc( const QString &aStr );
 
   /** Get or set the 'Drafts' folder */
   QString drafts() const { return mDrafts; }
-  void setDrafts(const QString& aStr);
+  void setDrafts( const QString &aStr );
+
+  /** Get or set the 'Templates' folder */
+  QString templates() const { return mTemplates; }
+  void setTemplates( const QString &aStr );
 
   /** Get or set the 'From' header field */
   QString from() const;
@@ -842,6 +847,12 @@ public:
   /** Return the textual content of the message as plain text,
       converting HTML to plain text if necessary. */
   QString asPlainText( bool stripSignature, bool allowDecryption ) const;
+
+  /** Get stored cursor position */
+  int getCursorPos() { return mCursorPos; };
+  /** Set cursor position as offset from message start */
+  void setCursorPos(int pos) { mCursorPos = pos; };
+
 private:
 
   /** Initialization shared by the ctors. */
@@ -850,6 +861,7 @@ private:
   void assign( const KMMessage& other );
 
   QString mDrafts;
+  QString mTemplates;
   mutable DwMessage* mMsg;
   mutable bool       mNeedsAssembly :1;
   bool mDecodeHTML :1;
@@ -868,6 +880,7 @@ private:
   KMMsgMDNSentState mMDNSentState;
   KMMessage* mUnencryptedMsg;
   DwBodyPart* mLastUpdated;
+  int mCursorPos;
 };
 
 
