@@ -489,12 +489,12 @@ void PopAccount::slotJobFinished() {
     mUidlFinished = TRUE;
 
     if ( mLeaveOnServer && mUidForIdMap.isEmpty() &&
-         mUidsOfNextSeenMsgsDict.isEmpty() && !idsOfMsgs.isEmpty() ) {
-      KMessageBox::sorry(0, i18n("Your POP3 server does not support the UIDL "
-      "command: this command is required to determine, in a reliable way, "
+        mUidsOfNextSeenMsgsDict.isEmpty() && !idsOfMsgs.isEmpty() ) {
+      KMessageBox::sorry(0, i18n("Your POP3 server (Account: %1) does not support "
+      "the UIDL command: this command is required to determine, in a reliable way, "
       "which of the mails on the server KMail has already seen before;\n"
       "the feature to leave the mails on the server will therefore not "
-      "work properly."));
+      "work properly.").arg(NetworkAccount::name()) );
       // An attempt to work around buggy pop servers, these seem to be popular.
       mUidsOfNextSeenMsgsDict = mUidsOfSeenMsgsDict;
     }
@@ -811,7 +811,9 @@ void PopAccount::processRemainingQueuedMessages()
   processMsgsTimer.stop();
 
   stage = Quit;
-  kmkernel->folderMgr()->syncAllFolders();
+  if ( kmkernel && kmkernel->folderMgr() ) {
+    kmkernel->folderMgr()->syncAllFolders();
+  }
 }
 
 
