@@ -321,6 +321,7 @@ RecipientsView::RecipientsView( QWidget *parent )
   : QScrollView( parent ), mCurDelLine( 0 ), mModified( false ),
     mFirstColumnWidth( 0 ), mLineHeight( 0 )
 {
+  mCompletionMode = KGlobalSettings::completionMode();
   setHScrollBarMode( AlwaysOff );
   setLineWidth( 0 );
 
@@ -348,6 +349,7 @@ RecipientLine *RecipientsView::addLine()
 {
   RecipientLine *line = new RecipientLine( viewport() );
   addChild( line, 0, mLines.count() * mLineHeight );
+  line->mEdit->setCompletionMode( mCompletionMode );
   line->show();
   connect( line, SIGNAL( returnPressed( RecipientLine * ) ),
     SLOT( slotReturnPressed( RecipientLine * ) ) );
@@ -361,6 +363,8 @@ RecipientLine *RecipientsView::addLine()
   connect( line, SIGNAL( countChanged() ), SLOT( calculateTotal() ) );
   connect( line, SIGNAL( typeModified( RecipientLine * ) ),
     SLOT( slotTypeModified( RecipientLine * ) ) );
+  connect( line->mEdit, SIGNAL( completionModeChanged( KGlobalSettings::Completion ) ),
+    SLOT( setCompletionMode( KGlobalSettings::Completion ) ) );
 
   if ( mLines.last() ) {
     if ( mLines.count() == 1 ) {
@@ -574,6 +578,23 @@ Recipient::List RecipientsView::recipients() const
   return recipients;
 }
 
+void RecipientsView::setCompletionMode ( KGlobalSettings::Completion mode )
+{
+  if ( mCompletionMode == mode )
+    return;
+  mCompletionMode = mode;
+
+  QPtrListIterator<RecipientLine> it( mLines );
+  RecipientLine *line;
+  while( ( line = it.current() ) ) {
+    line->mEdit->blockSignals( true );
+    line->mEdit->setCompletionMode( mode );
+    line->mEdit->blockSignals( false );
+    ++it;
+  }
+  emit completionModeChanged( mode ); //report change to RecipientsEditor
+}
+
 void RecipientsView::removeRecipient( const QString & recipient,
                                       Recipient::Type type )
 {
@@ -804,6 +825,8 @@ RecipientsEditor::RecipientsEditor( QWidget *parent )
   topLayout->addWidget( mRecipientsView );
   connect( mRecipientsView, SIGNAL( focusUp() ), SIGNAL( focusUp() ) );
   connect( mRecipientsView, SIGNAL( focusDown() ), SIGNAL( focusDown() ) );
+  connect( mRecipientsView, SIGNAL( completionModeChanged( KGlobalSettings::Completion ) ),
+    SIGNAL( completionModeChanged( KGlobalSettings::Completion ) ) );
 
   mSideWidget = new SideWidget( mRecipientsView, this );
   topLayout->addWidget( mSideWidget );
@@ -944,4 +967,8 @@ void RecipientsEditor::selectRecipients()
   mSideWidget->pickRecipient();
 }
 
+void RecipientsEditor::setCompletionMode( KGlobalSettings::Completion mode )
+{
+  mRecipientsView->setCompletionMode( mode );
+}
 #include "recipientseditor.moc"
