@@ -269,16 +269,27 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
                                         "mail_forward", ac,
                                         "search_message_forward" );
   connect( mForwardActionMenu, SIGNAL(activated()), this,
-           SLOT(slotForwardMsg()) );
-  mForwardAction = new KAction( i18n("&Inline..."), "mail_forward",
-                                0, this, SLOT(slotForwardMsg()),
-                                ac, "search_message_forward_inline" );
-  mForwardActionMenu->insert( mForwardAction );
+           SLOT(slotForwardInlineMsg()) );
   mForwardAttachedAction = new KAction( i18n("Message->Forward->","As &Attachment..."),
-                                       "mail_forward", 0, this,
+                                        "mail_forward", 0, this,
                                         SLOT(slotForwardAttachedMsg()), ac,
                                         "search_message_forward_as_attachment" );
   mForwardActionMenu->insert( mForwardAttachedAction );
+  mForwardInlineAction = new KAction( i18n("&Inline..."),
+                                      "mail_forward", 0, this,
+                                      SLOT(slotForwardInlineMsg()), ac,
+                                      "search_message_forward_inline" );
+  mForwardActionMenu->insert( mForwardInlineAction );
+  mForwardDigestAction = new KAction( i18n("Message->Forward->","As Di&gest..."),
+                                      "mail_forward", 0, this,
+                                      SLOT(slotForwardDigestMsg()), ac,
+                                      "search_message_forward_as_digest" );
+  mForwardActionMenu->insert( mForwardDigestAction );
+  mRedirectAction = new KAction( i18n("Message->Forward->","&Redirect..."),
+                                      "mail_forward", 0, this,
+                                      SLOT(slotRedirectMsg()), ac,
+                                      "search_message_forward_redirect" );
+  mForwardActionMenu->insert( mRedirectAction );
   mSaveAsAction = KStdAction::saveAs( this, SLOT(slotSaveMsg()), ac, "search_file_save_as" );
   mSaveAtchAction = new KAction( i18n("Save Attachments..."), "attach", 0,
                                  this, SLOT(slotSaveAttachments()), ac, "search_save_attachments" );
@@ -291,7 +302,7 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
           this, SLOT(folderInvalidated(KMFolder*)));
 
   connect(mCbxFolders, SIGNAL(folderChanged(KMFolder*)),
-          this, SLOT(slotFolderActivated(KMFolder*)));
+          this, SLOT(slotFolderActivated()));
 
 }
 
@@ -328,33 +339,33 @@ void SearchWindow::setEnabledSearchButton(bool)
 //-----------------------------------------------------------------------------
 void SearchWindow::updStatus(void)
 {
-    QString genMsg, detailMsg;
-    int numMatches = 0, count = 0;
+    QString genMsg, detailMsg, procMsg;
+    int numMatches = 0, numProcessed = 0;
     KMSearch const *search = (mFolder) ? (mFolder->search()) : 0;
     QString folderName;
     if (search) {
         numMatches = search->foundCount();
+        numProcessed = search->searchCount();
         folderName = search->currentFolder();
     }
 
     if (mFolder && mFolder->search() && !mFolder->search()->running()) {
+        procMsg = i18n("%n message searched", "%n messages searched",
+                       numProcessed);
         if(!mStopped) {
-            genMsg = i18n("Done");
-            detailMsg = i18n("%n match (%1)", "%n matches (%1)", numMatches)
-                        .arg(i18n("%n message processed",
-                                  "%n messages processed", count));
+            genMsg = i18n("Done.");
+            detailMsg = i18n("%n match in %1", "%n matches in %1",
+                             numMatches).arg(procMsg);
         } else {
-            genMsg = i18n("Search canceled");
-            detailMsg = i18n("%n match so far (%1)",
-                             "%n matches so far (%1)", numMatches)
-                        .arg(i18n("%n message processed",
-                                  "%n messages processed", count));
+            genMsg = i18n("Search canceled.");
+            detailMsg = i18n("%n match so far in %1", "%n matches so far in %1",
+                             numMatches).arg(procMsg);
         }
     } else {
+        procMsg = i18n("%n message", "%n messages", numProcessed);
         genMsg = i18n("%n match", "%n matches", numMatches);
-        detailMsg = i18n("Searching in %1 (message %2)")
-                    .arg(folderName)
-                    .arg(count);
+        detailMsg = i18n("Searching in %1. %2 searched so far")
+                    .arg(folderName).arg(procMsg);
     }
 
     mStatusBar->changeItem(genMsg, 0);
@@ -377,10 +388,9 @@ void SearchWindow::keyPressEvent(QKeyEvent *evt)
 
 
 //-----------------------------------------------------------------------------
-void SearchWindow::slotFolderActivated( KMFolder* folder )
+void SearchWindow::slotFolderActivated()
 {
     mChkbxSpecificFolders->setChecked(true);
-    mBtnSearch->setEnabled(folder);
 }
 
 //-----------------------------------------------------------------------------
@@ -705,6 +715,8 @@ void SearchWindow::updateContextMenuActions()
     mReplyAllAction->setEnabled( single_actions );
     mReplyListAction->setEnabled( single_actions );
     mPrintAction->setEnabled( single_actions );
+    mForwardDigestAction->setEnabled( !single_actions );
+    mRedirectAction->setEnabled( single_actions );
 }
 
 //-----------------------------------------------------------------------------
@@ -773,9 +785,9 @@ void SearchWindow::slotReplyListToMsg()
 }
 
 //-----------------------------------------------------------------------------
-void SearchWindow::slotForwardMsg()
+void SearchWindow::slotForwardInlineMsg()
 {
-    KMCommand *command = new KMForwardCommand(this, selectedMessages());
+    KMCommand *command = new KMForwardInlineCommand(this, selectedMessages());
     command->start();
 }
 
@@ -786,6 +798,20 @@ void SearchWindow::slotForwardAttachedMsg()
     command->start();
 }
 
+//-----------------------------------------------------------------------------
+void SearchWindow::slotForwardDigestMsg()
+{
+    KMCommand *command = new KMForwardDigestCommand(this, selectedMessages());
+    command->start();
+}
+
+//-----------------------------------------------------------------------------
+void SearchWindow::slotRedirectMsg()
+{
+    KMCommand *command = new KMRedirectCommand(this, message());
+    command->start();
+}
+
 //-----------------------------------------------------------------------------
 void SearchWindow::slotSaveMsg()
 {
