@@ -86,13 +86,13 @@ public:
    * @param curFolder The folder to use as the new base for searches.
    */
   void activateFolder( KMFolder* curFolder );
-  
+
   /**
    * Provides access to the list of currently selected message in the listview.
    * @return The list of currenty selected search result messages.
    */
   KMMessageList selectedMessages();
-  
+
   /**
    * Provides access to the currently selected message.
    * @return the currently selected message.
@@ -115,13 +115,15 @@ protected slots:
   virtual void slotContextMenuRequested( QListViewItem*, const QPoint &, int );
   virtual void copySelectedToFolder( int menuId );
   virtual void moveSelectedToFolder( int menuId );
-  virtual void slotFolderActivated( KMFolder* );
+  virtual void slotFolderActivated();
   void slotClearSelection();
   void slotReplyToMsg();
   void slotReplyAllToMsg();
   void slotReplyListToMsg();
-  void slotForwardMsg();
+  void slotForwardInlineMsg();
   void slotForwardAttachedMsg();
+  void slotForwardDigestMsg();
+  void slotRedirectMsg();
   void slotSaveMsg();
   void slotSaveAttachments();
   void slotPrintMsg();
@@ -167,8 +169,8 @@ protected:
   QWidget* mLastFocus; // to remember the position of the focus
   QMap<int,KMFolder*> mMenuToFolder;
   KAction *mReplyAction, *mReplyAllAction, *mReplyListAction, *mSaveAsAction,
-    *mForwardAction, *mForwardAttachedAction, *mPrintAction, *mClearAction,
-    *mSaveAtchAction;
+    *mForwardInlineAction, *mForwardAttachedAction, *mForwardDigestAction,
+    *mRedirectAction, *mPrintAction, *mClearAction, *mSaveAtchAction;
   KActionMenu *mForwardActionMenu;
   QValueList<QGuardedPtr<KMFolder> > mFolders;
 
