@@ -9,7 +9,7 @@
     version 2.0, as published by the Free Software Foundation.
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software Foundation,
-    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, US
+    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
 #ifdef HAVE_CONFIG_H
@@ -23,9 +23,9 @@
 #include "sievejob.h"
 using KMail::SieveJob;
 #include "kmkernel.h"
-#include "kmacctmgr.h"
+#include "accountmanager.h"
+using KMail::AccountManager;
 #include "kmacctimap.h"
-#include "kmmessage.h"
 #include <libkpimidentities/identitymanager.h>
 #include <libkpimidentities/identity.h>
 
@@ -170,7 +170,7 @@ namespace KMail {
     if ( mUrl.isEmpty() ) // nothing to do...
       return;
     mSieveJob = SieveJob::get( mUrl );
-    connect( mSieveJob, SIGNAL(result(KMail::SieveJob*,bool,const QString&,bool)),
+    connect( mSieveJob, SIGNAL(gotScript(KMail::SieveJob*,bool,const QString&,bool)),
 	     SLOT(slotGetResult(KMail::SieveJob*,bool,const QString&,bool)) );
   }
 
@@ -238,7 +238,7 @@ namespace KMail {
   }
 
   KURL Vacation::findURL() const {
-    KMAcctMgr * am = kmkernel->acctMgr();
+    AccountManager * am = kmkernel->acctMgr();
     assert( am );
     for ( KMAccount * a = am->first() ; a ; a = am->next() )
       if ( KMail::ImapAccountBase * iab = dynamic_cast<KMail::ImapAccountBase*>( a ) ) {
@@ -371,7 +371,7 @@ namespace KMail {
 
     // and commit the dialog's settings to the server:
     mSieveJob = SieveJob::put( mUrl, script, active, mWasActive );
-    connect( mSieveJob, SIGNAL(result(KMail::SieveJob*,bool,const QString&,bool)),
+    connect( mSieveJob, SIGNAL(gotScript(KMail::SieveJob*,bool,const QString&,bool)),
 	     active
 	     ? SLOT(slotPutActiveResult(KMail::SieveJob*,bool))
 	     : SLOT(slotPutInactiveResult(KMail::SieveJob*,bool)) );
