@@ -12,8 +12,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 
 */
 
@@ -246,7 +246,7 @@ void KMobileProtocol::listRoot(const KURL& url)
   if (url.protocol() == "organizer" ||		// organizer:/
       url.protocol() == "pda")			// pda:/
 	classMask = KMobileDevice::Organizer;
-  if (url.protocol() == "camera")		// camera:/
+  if (url.protocol() == "phonecamera")		// camera:/
 	classMask = KMobileDevice::Camera;
 
   for (unsigned int i=0; i<dirs; i++) {
