@@ -1,8 +1,6 @@
 /*
-    kncollectionview.cpp
-
     KNode, the KDE newsreader
-    Copyright (c) 2004 Volker Krause <volker.krause@rwth-aachen.de>
+    Copyright (c) 2004-2005 Volker Krause <volker.krause@rwth-aachen.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -10,7 +8,7 @@
     (at your option) any later version.
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software Foundation,
-    Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, US
+    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
 #include <qcursor.h>
@@ -146,18 +144,16 @@ void KNCollectionView::writeConfig()
 void KNCollectionView::addAccount(KNNntpAccount *a)
 {
   // add account item
-  KNCollectionViewItem* it = new KNCollectionViewItem(this, KFolderTreeItem::News);
-  a->setListItem(it);
-  it->setOpen(a->wasOpen());
+  KNCollectionViewItem* item = new KNCollectionViewItem( this, KFolderTreeItem::News );
+  a->setListItem( item );
+  item->setOpen( a->wasOpen() );
 
   // add groups for this account
-  QPtrList<KNGroup> groups;
-  groups.setAutoDelete(false);
-  knGlobals.groupManager()->getGroupsOfAccount(a, &groups);
-  for(KNGroup *g = groups.first(); g; g = groups.next()) {
-    KNCollectionViewItem *gitem = new KNCollectionViewItem(it, KFolderTreeItem::News);
-    g->setListItem(gitem);
-    g->updateListItem();
+  QValueList<KNGroup*> groups = knGlobals.groupManager()->groupsOfAccount( a );
+  for ( QValueList<KNGroup*>::Iterator it = groups.begin(); it != groups.end(); ++it ) {
+    KNCollectionViewItem *gitem = new KNCollectionViewItem( item, KFolderTreeItem::News );
+    (*it)->setListItem( gitem );
+    (*it)->updateListItem();
   }
 }
 
@@ -183,9 +179,10 @@ void KNCollectionView::updateAccount(KNNntpAccount *a)
 void KNCollectionView::reloadAccounts()
 {
   KNAccountManager* am = knGlobals.accountManager();
-  for(KNNntpAccount *a = am->first(); a; a = am->next()) {
-    removeAccount(a);
-    addAccount(a);
+  QValueList<KNNntpAccount*>::Iterator it;
+  for ( it = am->begin(); it != am->end(); ++it ) {
+    removeAccount( *it );
+    addAccount( *it );
   }
 }
 
@@ -272,14 +269,14 @@ void KNCollectionView::reloadFolders()
 
 void KNCollectionView::addPendingFolders()
 {
-  QPtrList<KNFolder> folders = knGlobals.folderManager()->folders();
-  for(KNFolder *f = folders.first(); f; f = folders.next())
-    if(!f->listItem())
-      addFolder(f);
+  QValueList<KNFolder*> folders = knGlobals.folderManager()->folders();
+  for ( QValueList<KNFolder*>::Iterator it = folders.begin(); it != folders.end(); ++it )
+    if ( !(*it)->listItem() )
+      addFolder( (*it) );
   // now open the folders if they were open in the last session
-  for(KNFolder *f = folders.first(); f; f = folders.next())
-    if (f->listItem())
-      f->listItem()->setOpen(f->wasOpen());
+  for ( QValueList<KNFolder*>::Iterator it = folders.begin(); it != folders.end(); ++it )
+    if ( (*it)->listItem())
+      (*it)->listItem()->setOpen( (*it)->wasOpen() );
 }
 
 
