@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -52,10 +52,10 @@ TodoPlugin::TodoPlugin( Kontact::Core *core, const char *, const QStringList& )
     mIface( 0 )
 {
   setInstance( TodoPluginFactory::instance() );
-  instance()->iconLoader()->addAppDir("korganizer");
+  instance()->iconLoader()->addAppDir("kdepim");
 
   insertNewAction( new KAction( i18n( "New To-do..." ), "newtodo",
-                   0, this, SLOT( slotNewTodo() ), actionCollection(),
+                   CTRL+SHIFT+Key_T, this, SLOT( slotNewTodo() ), actionCollection(),
                    "new_todo" ) );
 
   mUniqueAppWatcher = new Kontact::UniqueAppWatcher(
