@@ -39,24 +39,33 @@
 
 #include "alarmclient.h"
 #include "mainwindow.h"
+#include <uniqueapphandler.h> // in ../interfaces
 
 using namespace std;
 
 static const char description[] =
     I18N_NOOP( "KDE personal information manager" );
 
-static const char version[] = "1.2.3";
+static const char version[] = "1.2.4";
 
 class KontactApp : public KUniqueApplication {
   public:
-    KontactApp() : mMainWindow( 0 ) {}
+    KontactApp() : mMainWindow( 0 ), mSessionRestored( false ) {}
     ~KontactApp() {}
 
     int newInstance();
+    void setMainWindow( Kontact::MainWindow *window ) {
+        mMainWindow = window;
+        setMainWidget( window );
+    }
+    void setSessionRestored( bool restored ) {
+        mSessionRestored = restored;
+    }
 
   private:
     void startKOrgac();
     Kontact::MainWindow *mMainWindow;
+    bool mSessionRestored;
 };
 
 static void listPlugins()
@@ -75,14 +84,6 @@ static void listPlugins()
   }
 }
 
-static KCmdLineOptions options[] =
-{
-    { "module <module>",   I18N_NOOP( "Start with a specific Kontact module" ), 0 },
-    { "iconify",   I18N_NOOP( "Start in iconified (minimized) mode" ), 0 },
-    { "list", I18N_NOOP( "List all possible modules and exit" ), 0 },
-    KCmdLineLastOption
-};
-
 int KontactApp::newInstance()
 {
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
@@ -94,15 +95,7 @@ int KontactApp::newInstance()
     moduleName = QString::fromLocal8Bit( args->getOption( "module" ) );
   }
 
-  if ( isRestored() ) {
-    // There can only be one main window
-    if ( KMainWindow::canBeRestored( 1 ) ) {
-      mMainWindow = new Kontact::MainWindow();
-      setMainWidget( mMainWindow );
-      mMainWindow->show();
-      mMainWindow->restore( 1 );
-    }
-  } else {
+  if ( !mSessionRestored ) {
     if ( !mMainWindow ) {
       mMainWindow = new Kontact::MainWindow();
       if ( !moduleName.isEmpty() )
@@ -142,9 +135,7 @@ int main( int argc, char **argv )
   about.addAuthor( "Matthias Hoelzer-Kluepfel", I18N_NOOP("Original Author"), "mhk@kde.org" );
 
   KCmdLineArgs::init( argc, argv, &about );
-  KCmdLineArgs::addCmdLineOptions( options );
-  KUniqueApplication::addCmdLineOptions();
-  KApplication::addCmdLineOptions();
+  Kontact::UniqueAppHandler::loadKontactCommandLineOptions();
 
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
   if ( args->isSet( "list" ) ) {
@@ -158,6 +149,17 @@ int main( int argc, char **argv )
   }
 
   KontactApp app;
+  if ( app.restoringSession() ) {
+     // There can only be one main window
+    if ( KMainWindow::canBeRestored( 1 ) ) {
+      Kontact::MainWindow *mainWindow = new Kontact::MainWindow();
+      app.setMainWindow( mainWindow );
+      app.setSessionRestored( true );
+      mainWindow->show();
+      mainWindow->restore( 1 );
+    }
+  }
+
   bool ret = app.exec();
   while ( KMainWindow::memberList->first() )
     delete KMainWindow::memberList->first();
