@@ -76,7 +76,6 @@
 #include <libkcal/freebusy.h>
 #include <libkcal/filestorage.h>
 #include <libkcal/calendarresources.h>
-#include <libkcal/qtopiaformat.h>
 #include <libkcal/calendarnull.h>
 #include <libkcal/htmlexportsettings.h>
 
@@ -125,8 +124,6 @@ CalendarView::CalendarView( QWidget *parent, const char *name )
   mReadOnly = false;
   mSelectedIncidence = 0;
 
-  mCalPrinter = 0;
-
   mFilters.setAutoDelete( true );
 
   mExtensions.setAutoDelete( true );
@@ -370,17 +367,6 @@ QDate CalendarView::endDate()
 }
 
 
-void CalendarView::createPrinter()
-{
-#ifndef KORG_NOPRINTER
-  if (!mCalPrinter) {
-    mCalPrinter = new CalPrinter( this, mCalendar, new KOCoreHelper() );
-    connect(this, SIGNAL(configChanged()), mCalPrinter, SLOT(updateConfig()));
-  }
-#endif
-}
-
-
 bool CalendarView::openCalendar(const QString& filename, bool merge)
 {
   kdDebug(5850) << "CalendarView::openCalendar(): " << filename << endl;
@@ -694,32 +680,34 @@ void CalendarView::incidenceChanged( Incidence *oldIncidence,
   }
   setModified( true );
   history()->recordEdit( oldIncidence, newIncidence );
-  
+
   // Record completed todos in journals, if enabled. we should to this here in
   // favour of the todolist. users can mark a task as completed in an editor
   // as well.
   if ( newIncidence->type() == "Todo"
     && KOPrefs::instance()->recordTodosInJournals()
-    && what == KOGlobals::COMPLETION_MODIFIED ) {
+    &&  ( what == KOGlobals::COMPLETION_MODIFIED
+    || what == KOGlobals::COMPLETION_MODIFIED_WITH_RECURRENCE ) ) {
 
       Todo *todo = static_cast<Todo *>(newIncidence);
-      if ( todo->isCompleted() ) {
+      if ( todo->isCompleted()
+      || what == KOGlobals::COMPLETION_MODIFIED_WITH_RECURRENCE ) {
         QString timeStr = KGlobal::locale()->formatTime( QTime::currentTime() );
         QString description = i18n( "To-do completed: %1 (%2)" ).arg(
           newIncidence->summary() ).arg( timeStr );
 
         Journal::List journals = calendar()->journals( QDate::currentDate() );
         Journal *journal;
-        
+
         if ( journals.isEmpty() ) {
           journal = new Journal();
           journal->setDtStart( QDateTime::currentDateTime() );
-          
+
           QString dateStr = KGlobal::locale()->formatDate( QDate::currentDate() );
           journal->setSummary( i18n("Journal of %1").arg( dateStr ) );
           journal->setDescription( description );
 
-          if ( !mChanger->addIncidence( journal ) ) {
+          if ( !mChanger->addIncidence( journal, this ) ) {
             KODialogManager::errorSaveIncidence( this, journal );
             delete journal;
             return;
@@ -738,7 +726,7 @@ void CalendarView::incidenceChanged( Incidence *oldIncidence,
         }
       }
   }
-  
+
   changeIncidenceDisplay( newIncidence, KOGlobals::INCIDENCEEDITED );
   updateUnmanagedViews();
   checkForFilteredChange( newIncidence );
@@ -903,14 +891,14 @@ void CalendarView::edit_paste()
         pastedEvent->setDtEnd(endDT);
       }
     }
-    mChanger->addIncidence( pastedEvent );
+    mChanger->addIncidence( pastedEvent, this );
 
   } else if ( pastedIncidence->type() == "Todo" ) {
     Todo* pastedTodo = static_cast<Todo*>(pastedIncidence);
     Todo* _selectedTodo = selectedTodo();
     if ( _selectedTodo )
       pastedTodo->setRelatedTo( _selectedTodo );
-    mChanger->addIncidence( pastedTodo );
+    mChanger->addIncidence( pastedTodo, this );
   }
 }
 
@@ -919,106 +907,93 @@ void CalendarView::edit_options()
   mDialogManager->showOptionsDialog();
 }
 
+void CalendarView::dateTimesForNewEvent( QDateTime &startDt, QDateTime &endDt, bool &allDay )
+{
+  if ( !startDt.isValid() ) {
+    // Default start is the first selected date with the preferred time as set
+    // in the config dlg.
+    if ( !startDt.date().isValid() ) {
+      startDt.setDate( mNavigator->selectedDates().first() );
+    }
+    if ( !startDt.time().isValid() ) {
+      startDt.setTime( KOPrefs::instance()->mStartTime.time() );
+    }
+  }
+  if ( !endDt.isValid() ) {
+    int addSecs = ( KOPrefs::instance()->mDefaultDuration.time().hour()*3600 ) +
+                  ( KOPrefs::instance()->mDefaultDuration.time().minute()*60 );
+    endDt = startDt.addSecs( addSecs );
+  }
+  mViewManager->currentView()->eventDurationHint( startDt, endDt, allDay );
+}
+
+KOEventEditor *CalendarView::newEventEditor( const QDateTime &startDtParam,
+     const QDateTime &endDtParam, bool allDayParam)
+{
+  // let the current view change the default start/end datetime
+  bool allDay = allDayParam;
+  QDateTime startDt( startDtParam ), endDt( endDtParam );
+  // Adjust the start/end date times (i.e. replace invalid values by defaults,
+  // and let the view adjust the type.
+  dateTimesForNewEvent( startDt, endDt, allDay );
+
+  KOEventEditor *eventEditor = mDialogManager->getEventEditor();
+  eventEditor->newEvent();
+  connectIncidenceEditor( eventEditor );
+  eventEditor->setDates( startDt, endDt, allDay );
+  mDialogManager->connectTypeAhead( eventEditor, viewManager()->agendaView() );
+  return eventEditor;
+}
+
+
+
 
 void CalendarView::newEvent()
 {
   kdDebug(5850) << "CalendarView::newEvent()" << endl;
-  QDate date = mNavigator->selectedDates().first();
-  QTime startTime = KOPrefs::instance()->mStartTime.time();
-  QDateTime startDt( date, startTime );
-  int addSecs = ( KOPrefs::instance()->mDefaultDuration.time().hour()*3600 ) +
-                ( KOPrefs::instance()->mDefaultDuration.time().minute()*60 );
-  QDateTime endDt = ( startDt.addSecs( addSecs ) );
-  bool allDay = false;
-
-  // let the current view change the default start/end datetime
-  mViewManager->currentView()->eventDurationHint( startDt, endDt, allDay );
-
-  if ( allDay ) {
-    newEvent( startDt, endDt, true );
-  } else {
-    newEvent( startDt, endDt );
-  }
-}
-
-void CalendarView::newEvent( const QDateTime &fh )
-{
-  int addSecs = ( KOPrefs::instance()->mDefaultDuration.time().hour()*3600 ) +
-                ( KOPrefs::instance()->mDefaultDuration.time().minute()*60 );
-  QDateTime endTime ( fh.addSecs( addSecs ) );
-  newEvent( fh, endTime );
+  newEvent( QDateTime(), QDateTime() );
 }
 
 void CalendarView::newEvent( const QDate &dt )
 {
-  QTime startTime = KOPrefs::instance()->mStartTime.time();
-  int addSecs = ( KOPrefs::instance()->mDefaultDuration.time().hour()*3600 ) +
-                ( KOPrefs::instance()->mDefaultDuration.time().minute()*60 );
-  QTime endTime ( startTime.addSecs( addSecs ) );
-  newEvent(QDateTime(dt, startTime),
-           QDateTime(dt, endTime), true);
+  QDateTime startDt( dt, KOPrefs::instance()->mStartTime.time() );
+  return newEvent( QDateTime( dt ), QDateTime() );
 }
 
-void CalendarView::newEvent( const QString &text )
+void CalendarView::newEvent( const QDateTime &startDt )
 {
-  KOEventEditor *eventEditor = mDialogManager->getEventEditor();
-  connectIncidenceEditor( eventEditor );
-  eventEditor->newEvent( text );
-  mDialogManager->connectTypeAhead( eventEditor, viewManager()->agendaView() );
+  return newEvent( startDt, QDateTime() );
+}
+
+void CalendarView::newEvent( const QDateTime &startDt, const QDateTime &endDt,
+                             bool allDay )
+{
+  KOEventEditor *eventEditor = newEventEditor( startDt, endDt, allDay );
   eventEditor->show();
 }
 
 void CalendarView::newEvent( const QString &summary, const QString &description,
-                             const QString &attachment )
+                             const QStringList &attachments, const QStringList &attendees )
 {
-  KOEventEditor *eventEditor = mDialogManager->getEventEditor();
-  connectIncidenceEditor( eventEditor );
-  eventEditor->newEvent( summary, description, attachment );
+  KOEventEditor *eventEditor = newEventEditor();
+  eventEditor->setTexts( summary, description );
+  // if attach or attendee list is empty, these methods don't do anything, so
+  // it's save to call them in every case
+  eventEditor->addAttachments( attachments );
+  eventEditor->addAttendees( attendees );
   eventEditor->show();
 }
 
-void CalendarView::newEvent( const QString &summary, const QString &description,
-                             const QString &attachment, const QStringList &attendees )
-{
-  KOEventEditor *eventEditor = mDialogManager->getEventEditor();
-  connectIncidenceEditor( eventEditor );
-  eventEditor->newEvent( summary, description, attachment, attendees );
-  eventEditor->show();
-}
-
-void CalendarView::newEvent( const QDateTime &fromHint, const QDateTime &toHint,
-                             bool allDay)
-{
-  KOEventEditor *eventEditor = mDialogManager->getEventEditor();
-  connectIncidenceEditor( eventEditor );
-  eventEditor->newEvent(fromHint,toHint,allDay);
-  mDialogManager->connectTypeAhead( eventEditor, viewManager()->agendaView() );
-  eventEditor->show();
-}
-
-void CalendarView::newTodo( const QString &text )
-{
-  KOTodoEditor *todoEditor = mDialogManager->getTodoEditor();
-  connectIncidenceEditor( todoEditor );
-  todoEditor->newTodo( text );
-  todoEditor->show();
-}
-
 void CalendarView::newTodo( const QString &summary, const QString &description,
-                             const QString &attachment )
+                            const QStringList &attachments, const QStringList &attendees )
 {
   KOTodoEditor *todoEditor = mDialogManager->getTodoEditor();
   connectIncidenceEditor( todoEditor );
-  todoEditor->newTodo( summary, description, attachment );
-  todoEditor->show();
-}
-
-void CalendarView::newTodo( const QString &summary, const QString &description,
-                            const QString &attachment, const QStringList &attendees )
-{
-  KOTodoEditor *todoEditor = mDialogManager->getTodoEditor();
-  connectIncidenceEditor( todoEditor );
-  todoEditor->newTodo( summary, description, attachment, attendees );
+  todoEditor->newTodo();
+  todoEditor->setTexts( summary, description );
+  todoEditor->addAttachments( attachments );
+  todoEditor->addAttendees( attendees );
+  todoEditor->setDates( QDateTime(), false );
   todoEditor->show();
 }
 
@@ -1029,15 +1004,14 @@ void CalendarView::newTodo()
   bool allday = true;
   KOTodoEditor *todoEditor = mDialogManager->getTodoEditor();
   connectIncidenceEditor( todoEditor );
+  todoEditor->newTodo();
   if ( mViewManager->currentView()->isEventView() ) {
     dtDue.setDate( mNavigator->selectedDates().first() );
     QDateTime dtDummy = QDateTime::currentDateTime();
     mViewManager->currentView()->
-      eventDurationHint( dtDue , dtDummy , allday );
+      eventDurationHint( dtDue, dtDummy, allday );
+    todoEditor->setDates( dtDue, allday );
   }
-  else
-    dtDue = QDateTime::currentDateTime().addDays( 7 );
-  todoEditor->newTodo(dtDue,0,allday);
   todoEditor->show();
 }
 
@@ -1045,52 +1019,36 @@ void CalendarView::newTodo( const QDate &date )
 {
   KOTodoEditor *todoEditor = mDialogManager->getTodoEditor();
   connectIncidenceEditor( todoEditor );
-  todoEditor->newTodo( QDateTime( date, QTime::currentTime() ), 0, true );
+  todoEditor->newTodo();
+  todoEditor->setDates( QDateTime( date, QTime::currentTime() ), true );
   todoEditor->show();
 }
 
 void CalendarView::newJournal()
 {
   kdDebug(5850) << "CalendarView::newJournal()" << endl;
-  QDate date = mNavigator->selectedDates().first();
-  newJournal( date );
+  newJournal( QString::null, QDate() );
 }
 
-void CalendarView::newJournal( const QDate &date )
+void CalendarView::newJournal( const QDate &date)
 {
-  KOJournalEditor *journalEditor = mDialogManager->getJournalEditor();
-  connectIncidenceEditor( journalEditor );
-  journalEditor->newJournal( date );
-  journalEditor->show();
+  newJournal( QString::null, date );
 }
 
 void CalendarView::newJournal( const QString &text, const QDate &date )
 {
   KOJournalEditor *journalEditor = mDialogManager->getJournalEditor();
   connectIncidenceEditor( journalEditor );
-  journalEditor->newJournal( text, date );
+  journalEditor->newJournal();
+  journalEditor->setTexts( text );
+  if ( !date.isValid() ) {
+    journalEditor->setDate( mNavigator->selectedDates().first() );
+  } else {
+    journalEditor->setDate( date );
+  }
   journalEditor->show();
 }
 
-void CalendarView::newJournal( const QString &text )
-{
-  KOJournalEditor *journalEditor = mDialogManager->getJournalEditor();
-  connectIncidenceEditor( journalEditor );
-  journalEditor->newJournal( text );
-  journalEditor->show();
-}
-
-//TODO:
-// void CalendarView::newJournal( const QString &summary,
-//                                const QString &description,
-//                                const QString &attachment )
-// {
-//   KOJournalEditor *journalEditor = mDialogManager->getJournalEditor();
-//   connectIncidenceEditor( journalEditor );
-//   journalEditor->newJournal( summary, description, attachment );
-//   journalEditor->show();
-// }
-
 void CalendarView::newSubTodo()
 {
   Todo *todo = selectedTodo();
@@ -1101,7 +1059,8 @@ void CalendarView::newSubTodo(Todo *parentEvent)
 {
   KOTodoEditor *todoEditor = mDialogManager->getTodoEditor();
   connectIncidenceEditor( todoEditor );
-  todoEditor->newTodo(QDateTime::currentDateTime().addDays(7),parentEvent,true);
+  todoEditor->newTodo();
+  todoEditor->setDates( QDateTime(), false, parentEvent );
   todoEditor->show();
 }
 
@@ -1121,7 +1080,7 @@ bool CalendarView::addIncidence( const QString &ical )
   format.setTimeZone( mCalendar->timeZoneId(), true );
   Incidence *incidence = format.fromString( ical );
   if ( !incidence ) return false;
-  if ( !mChanger->addIncidence( incidence ) ) {
+  if ( !mChanger->addIncidence( incidence, this ) ) {
     delete incidence;
     return false;
   }
@@ -1274,8 +1233,9 @@ void CalendarView::dissociateOccurrence( Incidence *incidence, const QDate &date
   Incidence* newInc = mCalendar->dissociateOccurrence( incidence, date, true );
 
   if ( newInc ) {
+    // TODO: Use the same resource instead of asking again!
     mChanger->changeIncidence( oldincidence, incidence );
-    mChanger->addIncidence( newInc );
+    mChanger->addIncidence( newInc, this );
   } else {
     KMessageBox::sorry( this, i18n("Dissociating the occurrence failed."),
       i18n("Dissociating Failed") );
@@ -1300,8 +1260,9 @@ void CalendarView::dissociateFutureOccurrence( Incidence *incidence, const QDate
 
   Incidence* newInc = mCalendar->dissociateOccurrence( incidence, date, true );
   if ( newInc ) {
+    // TODO: Use the same resource instead of asking again!
     mChanger->changeIncidence( oldincidence, incidence );
-    mChanger->addIncidence( newInc );
+    mChanger->addIncidence( newInc, this );
   } else {
     KMessageBox::sorry( this, i18n("Dissociating the future occurrences failed."),
       i18n("Dissociating Failed") );
@@ -1493,16 +1454,21 @@ bool CalendarView::isModified()
 void CalendarView::print()
 {
 #ifndef KORG_NOPRINTER
-  createPrinter();
+  KOCoreHelper helper;
+  CalPrinter printer( this, mCalendar, &helper );
+  connect( this, SIGNAL(configChanged()), &printer, SLOT(updateConfig()) );
 
   KOrg::BaseView *currentView = mViewManager->currentView();
 
-  CalPrinter::PrintType printType = CalPrinter::Month;
-
+  CalPrinterBase::PrintType printType = CalPrinterBase::Month;
   if ( currentView ) printType = currentView->printType();
 
   DateList tmpDateList = mNavigator->selectedDates();
-  mCalPrinter->print( printType, tmpDateList.first(), tmpDateList.last() );
+  Incidence::List selectedIncidences;
+  if ( mViewManager->currentView() ) {
+    selectedIncidences = mViewManager->currentView()->selectedIncidences();
+  }
+  printer.print( printType, tmpDateList.first(), tmpDateList.last(), selectedIncidences );
 #endif
 }
 
@@ -2141,17 +2107,6 @@ void CalendarView::slotCalendarChanged()
   updateView();
 }
 
-void CalendarView::importQtopia( const QString &categories,
-                                 const QString &datebook,
-                                 const QString &todolist )
-{
-  QtopiaFormat qtopiaFormat;
-  if ( !categories.isEmpty() ) qtopiaFormat.load( mCalendar, categories );
-  if ( !datebook.isEmpty() ) qtopiaFormat.load( mCalendar, datebook );
-  if ( !todolist.isEmpty() ) qtopiaFormat.load( mCalendar, todolist );
-  updateView();
-}
-
 void CalendarView::warningChangeFailed( Incidence * )
 {
   KMessageBox::sorry( this, i18n("Unable to edit item: "
@@ -2220,7 +2175,7 @@ void CalendarView::addIncidenceOn( Incidence *incadd, const QDate &dt )
     todo->setHasDueDate( true );
   }
 
-  if ( !mChanger->addIncidence( incidence ) ) {
+  if ( !mChanger->addIncidence( incidence, this ) ) {
     KODialogManager::errorSaveIncidence( this, incidence );
     delete incidence;
   }
