@@ -2,6 +2,7 @@
   This file is part of KOrganizer.
 
   Copyright (c) 2001,2004 Cornelius Schumacher <schumacher@kde.org>
+  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
   As a special exception, permission is given to link this program
   with any edition of Qt, and distribute the resulting executable,
@@ -29,8 +30,6 @@
 
 namespace KCal{class CalFilter; }
 class CalendarView;
-class OutgoingDialog;
-class IncomingDialog;
 class KCMultiDialog;
 class KConfigureDialog;
 namespace KPIM { class CategoryEditDialog; }
@@ -40,7 +39,6 @@ class KOTodoEditor;
 class KOJournalEditor;
 class SearchDialog;
 class ArchiveDialog;
-class PluginDialog;
 class FilterEditDialog;
 class KOAgendaView;
 
@@ -57,6 +55,8 @@ class KODialogManager : public QObject
     KODialogManager( CalendarView * );
     virtual ~KODialogManager();
 
+    /** Get the appropriate editor for the given incidence */
+    KOIncidenceEditor *getEditor( Incidence * );
     /** Get an editor dialog for an Event. */
     KOEventEditor *getEventEditor();
     /** Get an editor dialog for a Todo. */
@@ -65,44 +65,31 @@ class KODialogManager : public QObject
     KOJournalEditor *getJournalEditor();
     void connectEditor( KOIncidenceEditor*editor );
 
-    OutgoingDialog *outgoingDialog();
-
-    IncomingDialog *incomingDialog();
-
     void updateSearchDialog();
-    void setDocumentId( const QString &id );
 
     void connectTypeAhead( KOEventEditor *editor, KOAgendaView *agenda );
 
-    static void errorSaveEvent( QWidget *parent );
-    static void errorSaveTodo( QWidget *parent );
-    static void errorSaveJournal( QWidget *parent );
+    static void errorSaveIncidence( QWidget *parent, Incidence *incidence );
 
   public slots:
     void showOptionsDialog();
-    void showIncomingDialog();
-    void showOutgoingDialog();
     void showCategoryEditDialog();
     void showSearchDialog();
     void showArchiveDialog();
     void showFilterEditDialog(QPtrList<CalFilter> *filters);
-    void showPluginDialog();
 
   private:
-    void createOutgoingDialog();
-    void createIncomingDialog();
-
+    class DialogManagerVisitor;
+    class EditorDialogVisitor;
+    
     CalendarView *mMainView;
 
-    OutgoingDialog *mOutgoingDialog;
-    IncomingDialog *mIncomingDialog;
     KCMultiDialog *mOptionsDialog;
 //    KConfigureDialog *mOptionsDialog;
     KPIM::CategoryEditDialog *mCategoryEditDialog;
     SearchDialog *mSearchDialog;
     ArchiveDialog *mArchiveDialog;
     FilterEditDialog *mFilterEditDialog;
-    PluginDialog *mPluginDialog;
 };
 
 #endif
