@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -28,6 +28,7 @@
 #include <qbuttongroup.h>
 #include <qvgroupbox.h>
 #include <qwidgetstack.h>
+#include <qspinbox.h>
 #include <qdatetime.h>
 #include <qlabel.h>
 #include <qcheckbox.h>
@@ -42,7 +43,6 @@
 #include <kmessagebox.h>
 #include <kfiledialog.h>
 #include <kstandarddirs.h>
-#include <krestrictedline.h>
 #include <ktextedit.h>
 
 #include <libkcal/event.h>
@@ -80,9 +80,11 @@ void KOEditorGeneralEvent::finishSetup()
   QWidget::setTabOrder( mTimeAssociateButton, mAlarmButton );
   QWidget::setTabOrder( mAlarmButton, mAlarmTimeEdit );
   QWidget::setTabOrder( mAlarmTimeEdit, mAlarmIncrCombo );
-  QWidget::setTabOrder( mAlarmIncrCombo, mAlarmSoundButton );
-  QWidget::setTabOrder( mAlarmSoundButton, mAlarmProgramButton );
-  QWidget::setTabOrder( mAlarmProgramButton, mFreeTimeCombo );
+//   QWidget::setTabOrder( mAlarmIncrCombo, mAlarmSoundButton );
+  QWidget::setTabOrder( mAlarmIncrCombo, mAlarmEditButton );
+//   QWidget::setTabOrder( mAlarmSoundButton, mAlarmProgramButton );
+//   QWidget::setTabOrder( mAlarmProgramButton, mFreeTimeCombo );
+  QWidget::setTabOrder( mAlarmEditButton, mFreeTimeCombo );
   QWidget::setTabOrder( mFreeTimeCombo, mDescriptionEdit );
   QWidget::setTabOrder( mDescriptionEdit, mCategoriesButton );
   QWidget::setTabOrder( mCategoriesButton, mSecrecyCombo );
@@ -163,7 +165,7 @@ void KOEditorGeneralEvent::initClass(QWidget *parent,QBoxLayout *topLayout)
 
   QLabel *freeTimeLabel = new QLabel(i18n("S&how time as:"),parent);
   QString whatsThis = i18n("Sets how this time will appear on your Free/Busy "
-		  	   "information.");
+                           "information.");
   QWhatsThis::add( freeTimeLabel, whatsThis );
   classLayout->addWidget(freeTimeLabel);
 
@@ -238,6 +240,9 @@ void KOEditorGeneralEvent::endTimeChanged( QTime newtime )
 
 void KOEditorGeneralEvent::startDateChanged( const QDate &newdate )
 {
+  if ( !newdate.isValid() )
+    return;
+
   int daysep = mCurrStartDateTime.daysTo(mCurrEndDateTime);
 
   mCurrStartDateTime.setDate(newdate);
@@ -251,20 +256,16 @@ void KOEditorGeneralEvent::startDateChanged( const QDate &newdate )
 
 void KOEditorGeneralEvent::endDateChanged( const QDate &newdate )
 {
-  QDateTime newdt(newdate, mCurrEndDateTime.time());
+  if ( !newdate.isValid() )
+    return;
 
-  if(newdt < mCurrStartDateTime) {
-    // oops, we can't let that happen.
-    newdt = mCurrStartDateTime;
-    mEndDateEdit->setDate(newdt.date());
-    mEndTimeEdit->setTime(newdt.time());
-  }
+  QDateTime newdt(newdate, mCurrEndDateTime.time());
   mCurrEndDateTime = newdt;
 
   emit dateTimesChanged(mCurrStartDateTime,mCurrEndDateTime);
 }
 
-void KOEditorGeneralEvent::setDefaults( const QDateTime &from, 
+void KOEditorGeneralEvent::setDefaults( const QDateTime &from,
                                         const QDateTime &to, bool allDay)
 {
   KOEditorGeneral::setDefaults(allDay);
@@ -392,8 +393,8 @@ void KOEditorGeneralEvent::setDuration()
   }
   mDurationLabel->setText(tmpStr);
   QWhatsThis::add( mDurationLabel,
-		   i18n("Shows the duration of the event or to-do with the "
-			"current start and end dates and times.") );
+       i18n("Shows the duration of the event or to-do with the "
+      "current start and end dates and times.") );
 }
 
 void KOEditorGeneralEvent::emitDateTimeStr()
