@@ -1,7 +1,7 @@
 /*
     This file is part of KOrganizer.
 
-    Copyright (c) 1997, 1998 Preston Brown
+    Copyright (c) 1997, 1998 Preston Brown <pbrown@kde.org>
     Copyright (c) 2000-2003 Cornelius Schumacher <schumacher@kde.org>
     Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
@@ -17,7 +17,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -30,12 +30,10 @@
 #include <qlayout.h>
 #include <qdatetime.h>
 
-#include <kabc/addressee.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
-#include <libkdepim/categoryselectdialog.h>
 #include <libkcal/calendarlocal.h>
 #include <libkcal/calendarresources.h>
 #include <libkcal/resourcecalendar.h>
@@ -89,10 +87,6 @@ void KOTodoEditor::setupGeneral()
 {
   mGeneral = new KOEditorGeneralTodo(this);
 
-  connect(mGeneral,SIGNAL(openCategoryDialog()),mCategoryDialog,SLOT(show()));
-  connect(mCategoryDialog, SIGNAL(categoriesSelected(const QString &)),
-          mGeneral,SLOT(setCategories(const QString &)));
-
   if (KOPrefs::instance()->mCompactDialogs) {
     QFrame *topFrame = addPage(i18n("General"));
 
@@ -132,6 +126,7 @@ void KOTodoEditor::setupGeneral()
     mGeneral->initStatus(topFrame,topLayout);
     QBoxLayout *alarmLineLayout = new QHBoxLayout(topLayout);
     mGeneral->initAlarm(topFrame,alarmLineLayout);
+    alarmLineLayout->addStretch( 1 );
     mGeneral->initDescription(topFrame,topLayout);
     QBoxLayout *detailsLayout = new QHBoxLayout(topLayout);
     mGeneral->initCategories( topFrame, detailsLayout );
@@ -169,75 +164,30 @@ void KOTodoEditor::editIncidence(Incidence *incidence)
   setCaption( i18n("Edit To-do") );
 }
 
-void KOTodoEditor::newTodo( const QDateTime &due, Todo *relatedTodo, bool allDay)
+void KOTodoEditor::newTodo()
 {
   init();
-
   mTodo = 0;
-  setDefaults(due,relatedTodo,allDay);
-
   setCaption( i18n("New To-do") );
 }
 
-void KOTodoEditor::newTodo( const QString &text )
+void KOTodoEditor::setTexts( const QString &summary, const QString &description )
 {
-  init();
-
-  mTodo = 0;
-
-  loadDefaults();
-
-  mGeneral->setDescription( text );
-
-  int pos = text.find( "\n" );
-  if ( pos > 0 ) {
-    mGeneral->setSummary( text.left( pos ) );
-    mGeneral->setDescription( text );
+  if ( description.isEmpty() && summary.contains("\n") ) {
+    mGeneral->setDescription( summary );
+    int pos = summary.find( "\n" );
+    mGeneral->setSummary( summary.left( pos ) );
   } else {
-    mGeneral->setSummary( text );
-  }
-
-  setCaption( i18n("New To-do") );
-}
-
-void KOTodoEditor::newTodo( const QString &summary,
-                            const QString &description,
-                            const QString &attachment )
-{
-  init();
-
-  mTodo = 0;
-
-  loadDefaults();
-
-  mGeneral->setSummary( summary );
-  mGeneral->setDescription( description );
-
-  if ( !attachment.isEmpty() ) {
-    mAttachments->addAttachment( attachment );
-  }
-
-  setCaption( i18n("New To-do") );
-}
-
-void KOTodoEditor::newTodo( const QString &summary,
-                            const QString &description,
-                            const QString &attachment,
-                            const QStringList &attendees )
-{
-  newTodo( summary, description, attachment );
-
-  QStringList::ConstIterator it;
-  for ( it = attendees.begin(); it != attendees.end(); ++it ) {
-    QString name, email;
-    KABC::Addressee::parseEmailAddress( *it, name, email );
-    mDetails->insertAttendee( new Attendee( name, email ) );
+    mGeneral->setSummary( summary );
+    mGeneral->setDescription( description );
   }
 }
 
+
+
 void KOTodoEditor::loadDefaults()
 {
-  setDefaults(QDateTime::currentDateTime().addDays(7),0,false);
+  setDates( QDateTime::currentDateTime().addDays(7), true, 0 );
 }
 
 bool KOTodoEditor::processInput()
@@ -273,7 +223,7 @@ bool KOTodoEditor::processInput()
 
     writeTodo( mTodo );
 
-    if ( !mChanger->addIncidence( mTodo ) ) {
+    if ( !mChanger->addIncidence( mTodo, this ) ) {
       delete mTodo;
       mTodo = 0;
       return false;
@@ -292,21 +242,19 @@ void KOTodoEditor::deleteTodo()
   reject();
 }
 
-void KOTodoEditor::setDefaults( const QDateTime &due, Todo *relatedEvent, bool allDay )
+void KOTodoEditor::setDates( const QDateTime &due, bool allDay, Todo *relatedEvent )
 {
   mRelatedTodo = relatedEvent;
 
   // inherit some properties from parent todo
   if ( mRelatedTodo ) {
-    mGeneral->setCategories( mRelatedTodo->categoriesStr() );
-    mCategoryDialog->setSelected( mRelatedTodo->categories() );
-    if ( mRelatedTodo->hasDueDate() )
-      mGeneral->setDefaults( mRelatedTodo->dtDue(), allDay );
-    else
-      mGeneral->setDefaults( due, allDay );
+    mGeneral->setCategories( mRelatedTodo->categories() );
   }
-  else
+  if ( !due.isValid() && mRelatedTodo && mRelatedTodo->hasDueDate() ) {
+    mGeneral->setDefaults( mRelatedTodo->dtDue(), allDay );
+  } else {
     mGeneral->setDefaults( due, allDay );
+  }
 
   mDetails->setDefaults();
   if ( mTodo )
@@ -318,6 +266,8 @@ void KOTodoEditor::setDefaults( const QDateTime &due, Todo *relatedEvent, bool a
 
 void KOTodoEditor::readTodo( Todo *todo )
 {
+  if ( !todo ) return;
+//   mRelatedTodo = todo->relatedTo();
   kdDebug(5850)<<"read todo"<<endl;
   mGeneral->readTodo( todo );
   mDetails->readEvent( todo );
@@ -325,8 +275,6 @@ void KOTodoEditor::readTodo( Todo *todo )
   mRecurrence->readIncidence( todo );
   mAttachments->readIncidence( todo );
 
-  // categories
-  mCategoryDialog->setSelected( todo->categories() );
   createEmbeddedURLPages( todo );
   readDesignerFields( todo );
 }
@@ -347,7 +295,7 @@ void KOTodoEditor::writeTodo( Todo *todo )
   }
   writeDesignerFields( todo );
 
-  // set related event, i.e. parent to-do in this case.
+  // set related incidence, i.e. parent to-do in this case.
   if ( mRelatedTodo ) {
     todo->setRelatedTo( mRelatedTodo );
   }
@@ -367,7 +315,7 @@ int KOTodoEditor::msgItemDelete()
 {
   return KMessageBox::warningContinueCancel(this,
       i18n("This item will be permanently deleted."),
-      i18n("KOrganizer Confirmation"),KGuiItem(i18n("Delete"),"editdelete"));
+      i18n("KOrganizer Confirmation"), KStdGuiItem::del() );
 }
 
 void KOTodoEditor::modified (int /*modification*/)
@@ -377,32 +325,27 @@ void KOTodoEditor::modified (int /*modification*/)
   reload();
 }
 
-void KOTodoEditor::slotLoadTemplate()
+void KOTodoEditor::loadTemplate( /*const*/ CalendarLocal& cal )
 {
-  CalendarLocal cal( KOPrefs::instance()->mTimeZoneId );
-  Todo *todo = new Todo;
-  QString templateName = loadTemplate( &cal, todo->type(),
-                                       KOPrefs::instance()->mTodoTemplates );
-  delete todo;
-  if ( templateName.isEmpty() ) {
-    return;
-  }
-
   Todo::List todos = cal.todos();
   if ( todos.count() == 0 ) {
     KMessageBox::error( this,
-        i18n("Template '%1' does not contain a valid to-do.")
-        .arg( templateName ) );
+        i18n("Template does not contain a valid to-do.") );
   } else {
     readTodo( todos.first() );
   }
 }
 
-void KOTodoEditor::saveTemplate( const QString &templateName )
+void KOTodoEditor::slotSaveTemplate( const QString &templateName )
 {
   Todo *todo = new Todo;
   writeTodo( todo );
   saveAsTemplate( todo, templateName );
 }
 
+QStringList& KOTodoEditor::templates() const
+{
+  return KOPrefs::instance()->mTodoTemplates;
+}
+
 #include "kotodoeditor.moc"
