@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -32,7 +32,6 @@
 
 #include <libkcal/todo.h>
 #include <korganizer/baseview.h>
-#include "calprinter.h"
 
 class QDragEnterEvent;
 class QDragMoveEvent;
@@ -127,7 +126,7 @@ class KOTodoView : public KOrg::BaseView
     /** Return number of shown dates. TodoView does not show dates, */
     int currentDateCount() { return 0; }
 
-    CalPrinter::PrintType printType();
+    CalPrinterBase::PrintType printType();
 
     void setDocumentId( const QString & );
 
@@ -157,6 +156,7 @@ class KOTodoView : public KOrg::BaseView
     void newSubTodo();
     void showTodo();
     void editTodo();
+    void printTodo();
     void deleteTodo();
 
     void setNewPercentage( KOTodoViewItem *item, int percentage );
@@ -172,12 +172,12 @@ class KOTodoView : public KOrg::BaseView
     void itemStateChanged( QListViewItem * );
 
     void setNewPercentageDelayed( KOTodoViewItem *item, int percentage );
-    void progressDelayedNewPercentage();
+    void processDelayedNewPercentage();
 
   signals:
     void unSubTodoSignal();
     void unAllSubTodoSignal();
-    
+
     void todoCompleted( Todo * );
 
     void purgeCompletedSignal();
@@ -235,7 +235,7 @@ class KOTodoView : public KOrg::BaseView
       eDueDateColumn = 4,
       eCategoriesColumn = 5,
       eDescriptionColumn = 6
-    }; 
+    };
     enum {
       ePopupEdit = 1300,
       ePopupDelete = 1301,
@@ -244,7 +244,7 @@ class KOTodoView : public KOrg::BaseView
       ePopupUnSubTodo = 1304,
       ePopupUnAllSubTodo = 1305
     };
-  
+
 };
 
 #endif
