@@ -20,8 +20,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -40,6 +40,7 @@
 #include <kabc/stdaddressbook.h>
 #include <kabc/resourcefile.h>
 #include <kio/netaccess.h>
+#include <ksavefile.h>
 
 #include <pilotSerialDatabase.h>
 #include <pilotLocalDatabase.h>
@@ -56,8 +57,7 @@
 //
 extern "C"
 {
-long version_conduit_address = KPILOT_PLUGIN_API;
-const char *id_conduit_address="$Id: abbrowser-conduit.cc 414025 2005-05-15 06:07:38Z vanrijn $";
+unsigned long version_conduit_address = Pilot::PLUGIN_API;
 }
 
 
@@ -69,13 +69,11 @@ const QString AbbrowserConduit::idString=CSL1("RecordID");
 
 AddressBook*AbbrowserConduit::aBook=0L;
 
-/// This macro just sets the phone number of type "type" to "phone"
-/// Use a macro, because that saves two lines for each call, but does not
-/// have the overhead of a function call
+/// This function just sets the phone number of type "type" to "phone"
 static inline void _setPhoneNumber(Addressee &abEntry, int type, const QString &nr)
 {
 	PhoneNumber phone = abEntry.phoneNumber(type);
-	phone.setNumber(nr); \
+	phone.setNumber(nr);
 	abEntry.insertPhoneNumber(phone);
 }
 
@@ -88,17 +86,15 @@ static inline void _setPhoneNumber(Addressee &abEntry, int type, const QString &
 
 
 
-AbbrowserConduit::AbbrowserConduit(KPilotDeviceLink * o, const char *n, const QStringList & a):
+AbbrowserConduit::AbbrowserConduit(KPilotLink * o, const char *n, const QStringList & a):
 		ConduitAction(o, n, a),
+		fAddressAppInfo(0L),
 		addresseeMap(),
 		syncedIds(),
 		abiter(),
 		ticket(0L)
 {
 	FUNCTIONSETUP;
-#ifdef DEBUG
-	DEBUGCONDUIT<<id_conduit_address<<endl;
-#endif
 	fConduitName=i18n("Addressbook");
 }
 
@@ -168,6 +164,7 @@ bool AbbrowserConduit::_prepare()
 
 	readConfig();
 	syncedIds.clear();
+	pilotindex = 0;
 
 	return true;
 }
@@ -183,20 +180,26 @@ void AbbrowserConduit::readConfig()
 	SyncAction::ConflictResolution res = (SyncAction::ConflictResolution)AbbrowserSettings::conflictResolution();
 	setConflictResolution(res);
 
-#ifdef DEBUG
 	DEBUGCONDUIT << fname
-		<< ": Settings "
+		<< ": Reading addressbook "
+		<< ( AbbrowserSettings::addressbookType() == AbbrowserSettings::eAbookFile ?
+			AbbrowserSettings::fileName() : CSL1("Standard") )
+		<< endl;
+	DEBUGCONDUIT << fname
+		<< ": "
 		<< " fConflictResolution=" << getConflictResolution()
+		<< " fArchive=" << AbbrowserSettings::archiveDeleted()
+		<< " fFirstTime=" << isFirstSync()
+		<< endl;
+	DEBUGCONDUIT << fname
+		<< ": "
 		<< " fPilotStreetHome=" << AbbrowserSettings::pilotStreet()
 		<< " fPilotFaxHome=" << AbbrowserSettings::pilotFax()
-		<< " fArchive=" << AbbrowserSettings::archiveDeleted()
 		<< " eCustom[0]=" << AbbrowserSettings::custom0()
 		<< " eCustom[1]=" << AbbrowserSettings::custom1()
 		<< " eCustom[2]=" << AbbrowserSettings::custom2()
 		<< " eCustom[3]=" << AbbrowserSettings::custom3()
-		<< " fFirstTime=" << isFirstSync()
 		<< endl;
-#endif
 }
 
 
@@ -375,37 +378,16 @@ bool AbbrowserConduit::_saveAddressBook()
 void AbbrowserConduit::_getAppInfo()
 {
 	FUNCTIONSETUP;
-	// get the address application header information
-	unsigned char *buffer = new unsigned char[PilotRecord::APP_BUFFER_SIZE];
-	int appLen=fDatabase->readAppBlock(buffer, PilotRecord::APP_BUFFER_SIZE);
 
-	unpack_AddressAppInfo(&fAddressAppInfo, buffer, appLen);
-	delete[]buffer;
-	buffer = NULL;
-
-#ifdef DEBUG
-	DEBUGCONDUIT << fname << " lastUniqueId" << fAddressAppInfo.category.lastUniqueID << endl;
-	for(int i = 0; i < 16; i++)
-	{
-		DEBUGCONDUIT << fname << " cat " << i << " =" << fAddressAppInfo.category.name[i] << endl;
-	}
-
-	for(int x = 0; x < 8; x++)
-	{
-		DEBUGCONDUIT << fname << " phone[" << x << "] = " << fAddressAppInfo.phoneLabels[x] << endl;
-	}
-#endif
+	delete fAddressAppInfo;
+	fAddressAppInfo = new PilotAddressInfo(fDatabase);
+	fAddressAppInfo->dump();
 }
 void AbbrowserConduit::_setAppInfo()
 {
 	FUNCTIONSETUP;
-	// get the address application header information
-	int appLen = pack_AddressAppInfo(&fAddressAppInfo, 0, 0);
-	unsigned char *buffer = new unsigned char[appLen];
-	pack_AddressAppInfo(&fAddressAppInfo, buffer, appLen);
-	if (fDatabase) fDatabase->writeAppBlock(buffer, appLen);
-	if (fLocalDatabase) fLocalDatabase->writeAppBlock(buffer, appLen);
-	delete[] buffer;
+	if (fDatabase) fAddressAppInfo->writeTo(fDatabase);
+	if (fLocalDatabase) fAddressAppInfo->writeTo(fLocalDatabase);
 }
 
 int AbbrowserConduit::getCustom(const int index)
@@ -623,27 +605,15 @@ KABC::Address AbbrowserConduit::getAddress(const Addressee & abEntry)
 QString AbbrowserConduit::_getCatForHH(const QStringList cats, const QString curr) const
 {
 	FUNCTIONSETUP;
-	int j;
 	if (cats.size()<1) return QString::null;
 	if (cats.contains(curr)) return curr;
 	for(QStringList::ConstIterator it = cats.begin(); it != cats.end(); ++it)
 	{
-		for(j = 0; j <= 15; j++)
+		if ( fAddressAppInfo->findCategory( *it, false /* Unknown returns -1 */) >= 0)
 		{
-			QString catName = PilotAppCategory::codec()->
-				toUnicode(fAddressAppInfo.category.name[j]);
-			if(!(*it).isEmpty() && !_compare(*it, catName))
-			{
-				return catName;
-			}
+			return *it;
 		}
 	}
-	// If we have a free label, return the first possible cat
-	for(j = 0; j <= 15; j++)
-	{
-		QString cat = QString::fromLatin1(fAddressAppInfo.category.name[j]);
-		if (cat.isEmpty()) return cats.first();
-	}
 
 	// didn't find anything. return null
 	return QString::null;
@@ -663,10 +633,10 @@ void AbbrowserConduit::_setCategory(Addressee & abEntry, QString cat)
 
 
 
-#ifdef DEBUG
 void AbbrowserConduit::showAddressee(const Addressee & abAddress)
 {
 	FUNCTIONSETUP;
+#ifdef DEBUG
 	DEBUGCONDUIT << "\tAbbrowser Contact Entry" << endl;
 	if (abAddress.isEmpty()) {
 		DEBUGCONDUIT<< "\t\tEMPTY"<<endl;
@@ -684,6 +654,9 @@ void AbbrowserConduit::showAddressee(const Addressee & abAddress)
 	DEBUGCONDUIT << "\t\tFax = " << getFax(abAddress).number() << endl;
 	DEBUGCONDUIT << "\t\tPager = " << abAddress.phoneNumber(PhoneNumber::Pager).number() << endl;
 	DEBUGCONDUIT << "\t\tCategory = " << abAddress.categories().first() << endl;
+#else
+	Q_UNUSED( abAddress );
+#endif
 }
 
 
@@ -691,6 +664,7 @@ void AbbrowserConduit::showAddressee(const Addressee & abAddress)
 void AbbrowserConduit::showPilotAddress(PilotAddress *pilotAddress)
 {
 	FUNCTIONSETUPL(3);
+#ifdef DEBUG
 	if (debug_level >= 3)
 	{
 	if (!pilotAddress) {
@@ -700,8 +674,10 @@ void AbbrowserConduit::showPilotAddress(PilotAddress *pilotAddress)
 	DEBUGCONDUIT << fname << "\n"
 			<< pilotAddress->getTextRepresentation(false) << endl;
 	}
-}
+#else
+	Q_UNUSED( pilotAddress );
 #endif
+}
 
 
 void AbbrowserConduit::showAdresses(Addressee &pcAddr, PilotAddress *backupAddr,
@@ -737,9 +713,6 @@ void AbbrowserConduit::showAdresses(Addressee &pcAddr, PilotAddress *backupAddr,
 /* virtual */ bool AbbrowserConduit::exec()
 {
 	FUNCTIONSETUP;
-#ifdef DEBUG
-	DEBUGCONDUIT << fname << id_conduit_address << endl;
-#endif
 
 	_prepare();
 
@@ -751,11 +724,20 @@ void AbbrowserConduit::showAdresses(Addressee &pcAddr, PilotAddress *backupAddr,
 	}
 	setFirstSync( retrieved );
 
-#ifdef DEBUG
-	DEBUGCONDUIT << fname << ": First sync now " << isFirstSync() << endl;
-#endif
-
 	_getAppInfo();
+
+	// Local block
+	{
+		QString dbpath = fLocalDatabase->dbPathName();
+		DEBUGCONDUIT << fname << ": Local database path " << dbpath << endl;
+	}
+
+	if ( syncMode().isTest() )
+	{
+		QTimer::singleShot(0, this, SLOT(slotTestRecord()));
+		return true;
+	}
+
 	if(!_loadAddressBook())
 	{
 		emit logError(i18n("Unable to open the addressbook."));
@@ -772,7 +754,6 @@ void AbbrowserConduit::showAdresses(Addressee &pcAddr, PilotAddress *backupAddr,
 
 	// perform syncing from palm to abbrowser
 	// iterate through all records in palm pilot
-	pilotindex = 0;
 
 #ifdef DEBUG
 	DEBUGCONDUIT << fname << ": fullsync=" << isFullSync() << ", firstSync=" <<    isFirstSync() << endl;
@@ -954,6 +935,9 @@ void AbbrowserConduit::slotPCRecToPalm()
 	}
 	KPILOT_DELETE(backupAddr);
 	KPILOT_DELETE(backupRec);
+#ifdef DEBUG
+		DEBUGCONDUIT << fname << ": adding id:["<< rid << "] to syncedIds." << endl;
+#endif
 	syncedIds.append(rid);
 	// done with the sync process, go on with the next one:
 	QTimer::singleShot(0, this, SLOT(slotPCRecToPalm()));
@@ -973,28 +957,44 @@ void AbbrowserConduit::slotDeletedRecord()
 		return;
 	}
 
-	// already synced, so skip this record:
-	if(syncedIds.contains(backupRec->id()))
-	{
-		KPILOT_DELETE(backupRec);
-		QTimer::singleShot(0, this, SLOT(slotDeletedRecord()));
-		return;
-	}
+	recordid_t id = backupRec->id();
 
-	QString uid = addresseeMap[backupRec->id()];
+	QString uid = addresseeMap[id];
 	Addressee e = aBook->findByUid(uid);
-	PilotRecord*palmRec=fDatabase->readRecordById(backupRec->id());
+
+#ifdef DEBUG
+		DEBUGCONDUIT << fname << ": now looking at palm id: ["
+					<< id << "], kabc uid: [" << uid << "]." << endl;
+#endif
+
 	PilotAddress*backupAddr=0L;
 	if (backupRec) backupAddr=new PilotAddress(fAddressAppInfo, backupRec);
-	PilotAddress*palmAddr=0L;
-	if (palmRec) palmAddr=new PilotAddress(fAddressAppInfo, palmRec);
+	PilotRecord*palmRec=fDatabase->readRecordById(id);
 
-	syncedIds.append(backupRec->id());
-	syncAddressee(e, backupAddr, palmAddr);
+	if ( e.isEmpty() ) {
+#ifdef DEBUG
+		DEBUGCONDUIT << fname << ": no Addressee found for this id." << endl;
+		DEBUGCONDUIT << fname << "\n"
+				<< backupAddr->getTextRepresentation(false) << endl;
+#endif
+
+		if (palmRec) {
+#ifdef DEBUG
+		DEBUGCONDUIT << fname << ": deleting from database on palm." << endl;
+#endif
+			fDatabase->deleteRecord(id);
+		}
+#ifdef DEBUG
+		DEBUGCONDUIT << fname << ": deleting from backup database." << endl;
+#endif
+		fLocalDatabase->deleteRecord(id);
+
+		// because we just deleted a record, we need to go back one
+		pilotindex--;
+	}
 
-	KPILOT_DELETE(palmAddr);
-	KPILOT_DELETE(backupAddr);
 	KPILOT_DELETE(palmRec);
+	KPILOT_DELETE(backupAddr);
 	KPILOT_DELETE(backupRec);
 	QTimer::singleShot(0, this, SLOT(slotDeletedRecord()));
 }
@@ -1074,10 +1074,27 @@ void AbbrowserConduit::slotCleanup()
 		fLocalDatabase->resetSyncFlags();
 		fLocalDatabase->cleanup();
 	}
+
+	// Write out the sync maps
+	QString syncFile = fLocalDatabase->dbPathName() + CSL1(".sync");
+	DEBUGCONDUIT << fname << ": Writing sync map to " << syncFile << endl;
+	KSaveFile map( syncFile );
+	if ( map.status() == 0 )
+	{
+		DEBUGCONDUIT << fname << ": Writing sync map ..." << endl;
+		(*map.dataStream()) << addresseeMap ;
+		map.close();
+	}
+	// This also picks up errors from map.close()
+	if ( map.status() != 0 )
+	{
+		kdWarning() << k_funcinfo << ": Could not make backup of sync map." << endl;
+	}
+
 	KPILOT_DELETE(fDatabase);
 	KPILOT_DELETE(fLocalDatabase);
 	_saveAddressBook();
-	emit syncDone(this);
+	delayDone();
 }
 
 
@@ -1249,7 +1266,7 @@ bool AbbrowserConduit::syncAddressee(Addressee &pcAddr, PilotAddress*backupAddr,
 		{
 #ifdef DEBUG
 			DEBUGCONDUIT<<"2d"<<endl;
-			DEBUGCONDUIT<<"Flags: "<<palmAddr->getAttrib()<<", isDeleted="<<
+			DEBUGCONDUIT<<"Flags: "<<palmAddr->attributes()<<", isDeleted="<<
 				isDeleted(palmAddr)<<", isArchived="<<isArchived(palmAddr)<<endl;
 #endif
 			if (isDeleted(palmAddr))
@@ -1319,9 +1336,9 @@ bool AbbrowserConduit::_copyToPC(Addressee &pcAddr, PilotAddress*backupAddr,
 	{
 		return false;
 	}
-#ifdef DEBUG
+
 	showPilotAddress(palmAddr);
-#endif
+
 	_copy(pcAddr, palmAddr);
 	_savePCAddr(pcAddr, backupAddr, palmAddr);
 	_writeBackup(palmAddr);
@@ -1335,10 +1352,8 @@ bool AbbrowserConduit::_writeBackup(PilotAddress *backup)
 	FUNCTIONSETUP;
 	if (!backup) return false;
 
-
-#ifdef DEBUG
 	showPilotAddress(backup);
-#endif
+
 	PilotRecord *pilotRec = backup->pack();
 	fLocalDatabase->writeRecord(pilotRec);
 	KPILOT_DELETE(pilotRec);
@@ -1354,26 +1369,24 @@ bool AbbrowserConduit::_deleteAddressee(Addressee &pcAddr, PilotAddress*backupAd
 
 	if (palmAddr)
 	{
-		if (!syncedIds.contains(palmAddr->id())) syncedIds.append(palmAddr->id());
-		palmAddr->makeDeleted();
-		PilotRecord *pilotRec = palmAddr->pack();
-		pilotRec->setDeleted();
-		pilotindex--;
-		fDatabase->writeRecord(pilotRec);
-		fLocalDatabase->writeRecord(pilotRec);
-		syncedIds.append(pilotRec->id());
-		KPILOT_DELETE(pilotRec);
+		if (!syncedIds.contains(palmAddr->id())) {
+#ifdef DEBUG
+		DEBUGCONDUIT << fname << ": adding id:["<< palmAddr->id() << "] to syncedIds." << endl;
+#endif
+			syncedIds.append(palmAddr->id());
+		}
+		fDatabase->deleteRecord(palmAddr->id());
+		fLocalDatabase->deleteRecord(palmAddr->id());
 	}
 	else if (backupAddr)
 	{
-		if (!syncedIds.contains(backupAddr->id())) syncedIds.append(backupAddr->id());
-		backupAddr->makeDeleted();
-		PilotRecord *pilotRec = backupAddr->pack();
-		pilotRec->setDeleted();
-		pilotindex--;
-		fLocalDatabase->writeRecord(pilotRec);
-		syncedIds.append(pilotRec->id());
-		KPILOT_DELETE(pilotRec);
+		if (!syncedIds.contains(backupAddr->id())) {
+#ifdef DEBUG
+		DEBUGCONDUIT << fname << ": adding id:["<< backupAddr->id() << "] to syncedIds." << endl;
+#endif
+			syncedIds.append(backupAddr->id());
+		}
+		fLocalDatabase->deleteRecord(backupAddr->id());
 	}
 	if (!pcAddr.isEmpty())
 	{
@@ -1408,7 +1421,7 @@ bool AbbrowserConduit::_savePalmAddr(PilotAddress *palmAddr, Addressee &pcAddr)
 	PilotRecord *pilotRec = palmAddr->pack();
 #ifdef DEBUG
 	DEBUGCONDUIT << fname << ": record with id=" << pilotRec->id()
-		<< " len=" << pilotRec->getLen() << endl;
+		<< " len=" << pilotRec->size() << endl;
 #endif
 	recordid_t pilotId = fDatabase->writeRecord(pilotRec);
 #ifdef DEBUG
@@ -1421,7 +1434,12 @@ bool AbbrowserConduit::_savePalmAddr(PilotAddress *palmAddr, Addressee &pcAddr)
 	if(pilotId != 0)
 	{
 		palmAddr->setID(pilotId);
-		if (!syncedIds.contains(pilotId)) syncedIds.append(pilotId);
+		if (!syncedIds.contains(pilotId)) {
+#ifdef DEBUG
+		DEBUGCONDUIT << fname << ": adding id:["<< pilotId << "] to syncedIds." << endl;
+#endif
+			syncedIds.append(pilotId);
+		}
 	}
 
 	recordid_t abId = 0;
@@ -1445,9 +1463,24 @@ bool AbbrowserConduit::_savePCAddr(Addressee &pcAddr, PilotAddress*,
 #ifdef DEBUG
 	DEBUGCONDUIT<<"Before _savePCAddr, pcAddr.custom="<<pcAddr.custom(appString, idString)<<endl;
 #endif
-	if(!pcAddr.custom(appString, idString).isEmpty())
+	QString pilotId = pcAddr.custom(appString, idString);
+	long pilotIdL = pilotId.toLong();
+	if(!pilotId.isEmpty())
 	{
-		addresseeMap.insert(pcAddr.custom(appString, idString).toLong(), pcAddr.uid());
+		// because we maintain a mapping between pilotId -> kabc uid, whenever we add
+		// a new relationship, we have to remove any old mapping that would tie a different
+		// pilot id -> this kabc uid
+		QMap < recordid_t, QString>::iterator it;
+		for ( it = addresseeMap.begin(); it != addresseeMap.end(); ++it ) {
+			QString kabcUid = it.data();
+			if (kabcUid == pcAddr.uid()) {
+				addresseeMap.remove(it);
+				break;
+			}
+		}
+
+		// now put the new mapping in
+		addresseeMap.insert(pilotIdL,  pcAddr.uid());
 	}
 
 	aBook->insertAddressee(pcAddr);
@@ -1463,44 +1496,83 @@ bool AbbrowserConduit::_savePCAddr(Addressee &pcAddr, PilotAddress*,
  *********************************************************************/
 
 
-int AbbrowserConduit::_compare(const QString & str1, const QString & str2) const
-{
-//	FUNCTIONSETUP;
-	if(str1.isEmpty() && str2.isEmpty()) return 0;
-	else return str1.compare(str2);
-}
-
 
 bool AbbrowserConduit::_equal(const PilotAddress *piAddress, const Addressee &abEntry,
 	enum eqFlagsType flags) const
 {
-	FUNCTIONSETUPL(8);
+	FUNCTIONSETUP;
+
 	// empty records are never equal!
-	if (!piAddress) return false;
-	if (abEntry.isEmpty()) return false;
+	if (!piAddress) {
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": no pilot address passed" << endl;
+#endif
+		return false;
+	}
+	if (abEntry.isEmpty()) {
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ":abEntry.isEmpty()" << endl;
+#endif
+		return false;
+	}
 	//  Archived records match anything so they won't be copied to the HH again
 	if (flags & eqFlagsFlags)
 		if (isArchived(piAddress) && isArchived(abEntry) ) return true;
 
 	if (flags & eqFlagsName)
 	{
-		if(_compare(abEntry.familyName(), piAddress->getField(entryLastname)))
+		if(!_equal(abEntry.familyName(), piAddress->getField(entryLastname)))
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": last name not equal" << endl;
+#endif
 			return false;
-		if(_compare(abEntry.givenName(), piAddress->getField(entryFirstname)))
+		}
+		// goofiness that we do in _copy(), duplicated here for your viewing pleasure... *grrr*
+		QString firstAndMiddle = abEntry.givenName();
+		if(!abEntry.additionalName().isEmpty()) firstAndMiddle += CSL1(" ") + abEntry.additionalName();
+
+		if(!_equal(firstAndMiddle, piAddress->getField(entryFirstname)))
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": first name not equal" << endl;
+#endif
 			return false;
-		if(_compare(abEntry.prefix(), piAddress->getField(entryTitle)))
+		}
+		if(!_equal(abEntry.prefix(), piAddress->getField(entryTitle)))
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": title/prefix not equal" << endl;
+#endif
 			return false;
-		if(_compare(abEntry.organization(), piAddress->getField(entryCompany)))
+		}
+		if(!_equal(abEntry.organization(), piAddress->getField(entryCompany)))
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": company/organization not equal" << endl;
+#endif
 			return false;
+		}
 	}
 	if (flags & eqFlagsNote)
-		if(_compare(abEntry.note(), piAddress->getField(entryNote)))
+		if(!_equal(abEntry.note(), piAddress->getField(entryNote)))
+	{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": note not equal" << endl;
+#endif
 			return false;
+	}
 
 	if (flags & eqFlagsNote)
 	{
 		QString cat = _getCatForHH(abEntry.categories(), piAddress->getCategoryLabel());
-		if(_compare(cat, piAddress->getCategoryLabel())) return false;
+		if(!_equal(cat, piAddress->getCategoryLabel()))
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": category not equal" << endl;
+#endif
+			return false;
+		}
 	}
 
 	if (flags & eqFlagsPhones)
@@ -1509,12 +1581,30 @@ bool AbbrowserConduit::_equal(const PilotAddress *piAddress, const Addressee &ab
 		QStringList abEmails(abEntry.emails());
 		QStringList piEmails(piAddress->getEmails());
 
-		if (abEmails.count() != piEmails.count()) return false;
+		if (abEmails.count() != piEmails.count())
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": email count not equal" << endl;
+#endif
+			return false;
+		}
 		for (QStringList::Iterator it = abEmails.begin(); it != abEmails.end(); it++) {
-			if (!piEmails.contains(*it)) return false;
+			if (!piEmails.contains(*it))
+			{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": pilot e-mail missing" << endl;
+#endif
+			return false;
+			}
 		}
 		for (QStringList::Iterator it = piEmails.begin(); it != piEmails.end(); it++) {
-			if (!abEmails.contains(*it)) return false;
+			if (!abEmails.contains(*it))
+			{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": kabc e-mail missing" << endl;
+#endif
+			return false;
+			}
 		}
 
 		// now look for differences in phone numbers.  Note:  we can't just compare one
@@ -1530,75 +1620,136 @@ bool AbbrowserConduit::_equal(const PilotAddress *piAddress, const Addressee &ab
 			for (PhoneNumber::List::Iterator it = abPhones.begin(); it != abPhones.end(); it++) {
 				PhoneNumber abPhone = *it;
 				// see if we have the same number here...
-				if (_compare(piPhone.number(), abPhone.number()) == 0) {
-					// *sigh*  Okay, now see if the preferred number has changed.
-					// only check this in one direction, since kabc can have more
-					// than one field as preferred and the pilot can only have one
-					if (piPhone.type() & PhoneNumber::Pref &&
-						!(abPhone.type() & PhoneNumber::Pref)) {
-						// if the pilot says this one is preferred and kabc doesn't
-						// agree, the records don't match.
-						return false;
-					} else {
-						found = true;
-						break;
-					}
+				// * Note * We used to check for preferred number matching, but
+				//     this seems to have broke in kdepim 3.5 and I don't have time to
+				//     figure out why, so we won't check to see if preferred number match
+				if ( _equal(piPhone.number(), abPhone.number()) ) {
+					found = true;
+					break;
 				}
 			}
-			if (!found)
+			if (!found) {
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": not equal because kabc phone not found." << endl;
+#endif
 				return false;
+			}
 		}
-		// now the other way (*cringe*  kabc has the capacity to store way more addresses
+		// now the other way.  *cringe*  kabc has the capacity to store way more addresses
 		// than the Pilot, so this might give false positives more than we'd want....
 		for (PhoneNumber::List::Iterator it = abPhones.begin(); it != abPhones.end(); it++) {
 			PhoneNumber abPhone = *it;
 			bool found=false;
 			for (PhoneNumber::List::Iterator it = piPhones.begin(); it != piPhones.end(); it++) {
 				PhoneNumber piPhone = *it;
-				if (_compare(piPhone.number(), abPhone.number()) == 0) {
+				if ( _equal(piPhone.number(), abPhone.number()) ) {
 					found = true;
 					break;
 				}
 			}
-			if (!found)
+			if (!found) {
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": not equal because pilot phone not found." << endl;
+#endif
 				return false;
+			}
 		}
 
-		if(_compare(getOtherField(abEntry),
-			piAddress->getPhoneField(PilotAddress::eOther, false))) return false;
+		if(!_equal(getOtherField(abEntry),
+		   piAddress->getPhoneField(PilotAddress::eOther, false))) {
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": not equal because of other phone field." << endl;
+#endif
+		   	return false;
+		}
 	}
 
 	if (flags & eqFlagsAdress)
 	{
 		KABC::Address address = getAddress(abEntry);
-		if(_compare(address.street(), piAddress->getField(entryAddress)))
+		if(!_equal(address.street(), piAddress->getField(entryAddress)))
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": address not equal" << endl;
+#endif
 			return false;
-		if(_compare(address.locality(), piAddress->getField(entryCity)))
+		}
+		if(!_equal(address.locality(), piAddress->getField(entryCity)))
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": city not equal" << endl;
+#endif
 			return false;
-		if(_compare(address.region(), piAddress->getField(entryState)))
+		}
+		if(!_equal(address.region(), piAddress->getField(entryState)))
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": state not equal" << endl;
+#endif
 			return false;
-		if(_compare(address.postalCode(), piAddress->getField(entryZip)))
+		}
+		if(!_equal(address.postalCode(), piAddress->getField(entryZip)))
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": zip not equal" << endl;
+#endif
 			return false;
-		if(_compare(address.country(), piAddress->getField(entryCountry)))
+		}
+		if(!_equal(address.country(), piAddress->getField(entryCountry)))
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": country not equal" << endl;
+#endif
 			return false;
+		}
 	}
 
 	if (flags & eqFlagsCustom)
 	{
-		if(_compare(getCustomField(abEntry, 0),
-			piAddress->getField(entryCustom1))) return false;
-		if(_compare(getCustomField(abEntry, 1),
-			piAddress->getField(entryCustom2))) return false;
-		if(_compare(getCustomField(abEntry, 2),
-			piAddress->getField(entryCustom3))) return false;
-		if(_compare(getCustomField(abEntry, 3),
-			piAddress->getField(entryCustom4))) return false;
+		if(!_equal(getCustomField(abEntry, 0),
+			piAddress->getField(entryCustom1)))
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": custom1 not equal" << endl;
+#endif
+			return false;
+		}
+		if(!_equal(getCustomField(abEntry, 1),
+			piAddress->getField(entryCustom2)))
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": custom2 not equal" << endl;
+#endif
+			return false;
+		}
+		if(!_equal(getCustomField(abEntry, 2),
+			piAddress->getField(entryCustom3)))
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": custom3 not equal" << endl;
+#endif
+			return false;
+		}
+		if(!_equal(getCustomField(abEntry, 3),
+			piAddress->getField(entryCustom4)))
+		{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": custom4 not equal" << endl;
+#endif
+			return false;
+		}
 	}
 
 	// if any side is marked archived, but the other is not, the two
 	// are not equal.
 	if (flags & eqFlagsFlags)
-		if (isArchived(piAddress) || isArchived(abEntry) ) return false;
+		if (isArchived(piAddress) || isArchived(abEntry) )
+	{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname  << ": archived flags don't match" << endl;
+#endif
+			return false;
+	}
 
 	return true;
 }
@@ -1610,7 +1761,7 @@ void AbbrowserConduit::_copy(PilotAddress *toPilotAddr, Addressee &fromAbEntry)
 	FUNCTIONSETUP;
 	if (!toPilotAddr) return;
 
-	toPilotAddr->setAttrib(toPilotAddr->getAttrib() & ~(dlpRecAttrDeleted));
+	toPilotAddr->setDeleted(false);
 
 	// don't do a reset since this could wipe out non copied info
 	//toPilotAddr->reset();
@@ -1644,9 +1795,13 @@ void AbbrowserConduit::_copy(PilotAddress *toPilotAddr, Addressee &fromAbEntry)
 	toPilotAddr->setCategory(_getCatForHH(fromAbEntry.categories(), toPilotAddr->getCategoryLabel()));
 
 	if (isArchived(fromAbEntry))
-		toPilotAddr->makeArchived();
+	{
+		toPilotAddr->setArchived( true );
+	}
 	else
-		toPilotAddr->setAttrib(toPilotAddr->getAttrib() & ~(dlpRecAttrArchived));
+	{
+		toPilotAddr->setArchived( false );
+	}
 }
 
 
@@ -1748,9 +1903,8 @@ void AbbrowserConduit::_copy(Addressee &toAbEntry, PilotAddress *fromPiAddr)
 	toAbEntry.insertCustom(appString, idString, QString::number(fromPiAddr->id()));
 
 
-	int cat = fromPiAddr->getCat();
-	QString category;
-	if (0 < cat && cat <= 15) category = fAddressAppInfo.category.name[cat];
+	int cat = fromPiAddr->category();
+	QString category = fAddressAppInfo->categoryName(cat);
 	_setCategory(toAbEntry, category);
 #ifdef DEBUG
 	showAddressee(toAbEntry);
@@ -2142,3 +2296,24 @@ Addressee AbbrowserConduit::_findMatch(const PilotAddress & pilotAddress) const
 	return Addressee();
 }
 
+void AbbrowserConduit::slotTestRecord()
+{
+	FUNCTIONSETUP;
+
+	// Get a record and interpret it as an address.
+	PilotRecord *r = fDatabase->readRecordByIndex( pilotindex );
+	if (!r)
+	{
+		delayDone();
+		return;
+	}
+	PilotAddress a(fAddressAppInfo,r);
+	KPILOT_DELETE(r);
+
+	// Process this record.
+	showPilotAddress(&a);
+
+	// Schedule more work.
+	++pilotindex;
+	QTimer::singleShot(0, this, SLOT(slotTestRecord()));
+}
