@@ -18,8 +18,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 **
 **
 ** Specific permission is granted for this code to be linked to libmal
@@ -121,7 +121,7 @@ MALConduitFactory::~MALConduitFactory()
 
 	if (qstrcmp(c,"SyncAction")==0)
 	{ 
-		KPilotDeviceLink *d = dynamic_cast<KPilotDeviceLink *>(p);
+		KPilotLink *d = dynamic_cast<KPilotLink *>(p);
 
 		if (d)
 		{
@@ -130,7 +130,7 @@ MALConduitFactory::~MALConduitFactory()
 		else
 		{
 			kdError() << k_funcinfo
-				<< ": Couldn't cast parent to KPilotDeviceLink"
+				<< ": Couldn't cast parent to KPilotLink"
 				<< endl;
 			return 0L;
 		}
