@@ -18,8 +18,8 @@
 **
 ** You should have received a copy of the GNU Lesser General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -29,13 +29,6 @@
 
 #include "options.h"
 
-// Something to allow us to check what revision
-// the modules are that make up a binary distribution.
-//
-//
-static const char *memofile_conduit_id=
-    "$Id: memofile-conduit.cc 418453 2005-05-26 17:06:20Z vanrijn $";
-
 // Only include what we really need:
 // First UNIX system stuff, then std C++,
 // then Qt, then KDE, then local includes.
@@ -55,7 +48,7 @@ static const char *memofile_conduit_id=
 #include <kconfig.h>
 #include <kdebug.h>
 
-#include "pilotAppCategory.h"
+#include "pilotRecord.h"
 #include "pilotSerialDatabase.h"
 #include "memofile-factory.h"
 #include "memofile-conduit.h"
@@ -65,7 +58,7 @@ static const char *memofile_conduit_id=
 /**
  * Our workhorse.  This is the main driver for the conduit.
  */
-MemofileConduit::MemofileConduit(KPilotDeviceLink *d,
+MemofileConduit::MemofileConduit(KPilotLink *d,
                                  const char *n,
                                  const QStringList &l) :
 		ConduitAction(d,n,l),
@@ -74,9 +67,6 @@ MemofileConduit::MemofileConduit(KPilotDeviceLink *d,
 		_memofiles(0L)
 {
 	FUNCTIONSETUP;
-#ifdef DEBUG
-	DEBUGCONDUIT<<memofile_conduit_id<<endl;
-#endif
 	fConduitName=i18n("Memofile");
 	fMemoList.setAutoDelete(true);
 }
@@ -195,11 +185,11 @@ bool MemofileConduit::setAppInfo()
 
 	fCategories = map;
 
-	for (int i = 0; i < MAX_CATEGORIES; i++)
+	for (unsigned int i = 0; i < Pilot::CATEGORY_COUNT; i++)
 	{
 		if (fCategories.contains(i)) {
 			QString name = fCategories[i].left(16);
-			fMemoAppInfo->setCategory(i,name);
+			fMemoAppInfo->setCategoryName(i,name);
 
 #ifdef DEBUG
 			DEBUGCONDUIT << fname
@@ -272,9 +262,9 @@ bool MemofileConduit::loadPilotCategories()
 	int _category_id=0;
 	int _category_num=0;
 
-	for (int i = 0; i < MAX_CATEGORIES; i++)
+	for (unsigned int i = 0; i < Pilot::CATEGORY_COUNT; i++)
 	{
-		_category_name = fMemoAppInfo->category(i);
+		_category_name = fMemoAppInfo->categoryName(i);
 		if (!_category_name.isEmpty())
 		{
 			_category_name = Memofiles::sanitizeName( _category_name );
@@ -325,9 +315,9 @@ void MemofileConduit::getAllFromPilot()
 			<< ": Added memo: ["
 			<< currentRecord
 			<< "], id: ["
-			<< memo->getID()
+			<< memo->id()
 			<< "], category: ["
-			<< fCategories[memo->getCat()]
+			<< fCategories[memo->category()]
 			<< "], title: ["
 			<< memo->getTitle()
 			<< "]" << endl;
@@ -360,7 +350,7 @@ void MemofileConduit::getAllFromPilot()
 }
 
 /**
- *  Read all memos in from Pilot.
+ *  Read all modified memos in from Pilot.
  */
 void MemofileConduit::getModifiedFromPilot()
 {
@@ -377,7 +367,7 @@ void MemofileConduit::getModifiedFromPilot()
 		// we are syncing to both our filesystem and to the local
 		// database, so take care of the local database here
 		if (memo->isDeleted()) {
-			fLocalDatabase->deleteRecord(memo->getID());
+			fLocalDatabase->deleteRecord(memo->id());
 		} else {
 			fLocalDatabase->writeRecord(pilotRec);
 		}
@@ -388,7 +378,7 @@ void MemofileConduit::getModifiedFromPilot()
 #ifdef DEBUG
 			DEBUGCONDUIT << fname
 			<< ": modified memo id: ["
-			<< memo->getID()
+			<< memo->id()
 			<< "], title: ["
 			<< memo->getTitle()
 			<< "]" << endl;
@@ -398,7 +388,7 @@ void MemofileConduit::getModifiedFromPilot()
 #ifdef DEBUG
 			DEBUGCONDUIT << fname <<
 			": skipped secret modified record id: ["
-			<< memo->getID()
+			<< memo->id()
 			<< "], title: ["
 			<< memo->getTitle()
 			<< "]" << endl;
@@ -438,11 +428,11 @@ void MemofileConduit::listPilotMemos()
 
 	PilotMemo *memo;
 	for ( memo = fMemoList.first(); memo; memo = fMemoList.next() ) {
-		QString _category_name = fCategories[memo->getCat()];
+		QString _category_name = fCategories[memo->category()];
 
 		DEBUGCONDUIT << fConduitName
 		<< ": listing record id: [" << memo->id()
-		<< "] category id: [" << memo->getCat()
+		<< "] category id: [" << memo->category()
 		<< "] category name: [" << _category_name
 		<< "] title: [" << memo->getTitle()
 		<< "]" << endl;
@@ -490,11 +480,11 @@ bool MemofileConduit::copyPCToHH()
 	}
 
 	_memofiles->save();
-	
+
 	// now that we've copied from the PC to our handheld, remove anything extra from the
 	// handheld...
 	deleteUnsyncedHHRecords();
-	
+
 	return true;
 
 }
@@ -504,8 +494,8 @@ void MemofileConduit::deleteUnsyncedHHRecords()
 	FUNCTIONSETUP;
 	if ( syncMode()==SyncMode::eCopyPCToHH )
 	{
-		RecordIDList ids=fDatabase->idList();
-		RecordIDList::iterator it;
+		Pilot::RecordIDList ids=fDatabase->idList();
+		Pilot::RecordIDList::iterator it;
 		for ( it = ids.begin(); it != ids.end(); ++it )
 		{
 			if (!_memofiles->find(*it))
