@@ -29,33 +29,6 @@
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
 
-#include <klibloader.h>
-
-#include "plugin.h"
-
-class MemofileWidget;
-class KInstance;
-class KAboutData;
-
-class MemofileConduitFactory : public KLibFactory
-{
-Q_OBJECT
-
-public:
-	MemofileConduitFactory(QObject * = 0L,const char * = 0L);
-	virtual ~MemofileConduitFactory();
-
-	static KAboutData *about() { return fAbout; } ;
-
-protected:
-	virtual QObject* createObject( QObject* parent = 0,
-		const char* name = 0,
-		const char* classname = "QObject",
-		const QStringList &args = QStringList() );
-private:
-	KInstance *fInstance;
-	static KAboutData *fAbout;
-} ;
 
 extern "C"
 {
