@@ -36,24 +36,14 @@
 #include <qlineedit.h>
 
 #include "uiDialog.h"
+#include "pluginfactory.h"
 
 #include "notepad-conduit.h"     // Conduit action
 #include "notepad-setup.h"
-#include "notepad-factory.moc"
 #include "notepadconduit.h"     // Settings class
 
-extern "C"
-{
-
-void *init_conduit_notepad()
-{
-	return new NotepadConduitFactory;
-}
-
-}
-
 //----------------------------------------------------------------------------
-// Conduit Confuguration
+// Conduit Configuration
 //----------------------------------------------------------------------------
 class NotepadConduitConfig : public ConduitConfigBase
 {
@@ -62,26 +52,47 @@ public:
 	virtual void commit();
 	virtual void load();
 	static ConduitConfigBase *create(QWidget *p, const char *n)
-	{ 
-		return new NotepadConduitConfig(p, n); 
+	{
+		return new NotepadConduitConfig(p, n);
 	};
-	
+
 protected:
 	NotepadWidget *fConfigWidget;
 } ;
 
+static KAboutData *createAbout()
+{
+	FUNCTIONSETUP;
+
+	KAboutData *fAbout = new KAboutData("NotepadConduit",
+		I18N_NOOP("Saves notepads to png files"),
+		KPILOT_VERSION,
+		I18N_NOOP("Configures the Notepad Conduit for KPilot"),
+		KAboutData::License_LGPL,
+		"(C) 2004, Joern Ahrens");
+	fAbout->addAuthor("Joern Ahrens",
+		I18N_NOOP("Primary Author"),
+		"kde@jokele.de",
+		"http://www.jokele.de/");
+	fAbout->addCredit("Adriaan de Groot");
+	fAbout->addCredit("Angus Ainslies",
+		I18N_NOOP("Notepad conduit is based on Angus' read-notepad, part of pilot-link" ));
+	return fAbout;
+}
+
+
 NotepadConduitConfig::NotepadConduitConfig(QWidget *p, const char *n) :
 	ConduitConfigBase(p, n),
 	fConfigWidget(new NotepadWidget(p))
 {
 	FUNCTIONSETUP;
-	
+
 	fConduitName = i18n("Notepad");
-	UIDialog::addAboutPage(fConfigWidget->tabWidget, NotepadConduitFactory::about());
+	UIDialog::addAboutPage(fConfigWidget->tabWidget, createAbout());
 	fWidget=fConfigWidget;
 	QObject::connect(fConfigWidget->fOutputDirectory, SIGNAL(textChanged(const QString&)),
 		this, SLOT(modified()));
-	fConfigWidget->fOutputDirectory->setMode(KFile::Directory | 
+	fConfigWidget->fOutputDirectory->setMode(KFile::Directory |
 											KFile::LocalOnly);
 }
 
@@ -96,85 +107,19 @@ NotepadConduitConfig::NotepadConduitConfig(QWidget *p, const char *n) :
 /* virtual */ void NotepadConduitConfig::load()
 {
 	FUNCTIONSETUP;
-	
+
 	NotepadConduitSettings::self()->readConfig();
 	fConfigWidget->fOutputDirectory->setURL(NotepadConduitSettings::outputDirectory());
 	fModified=false;
 }
 
-//----------------------------------------------------------------------------
-// Conduit Factory
-//----------------------------------------------------------------------------
-KAboutData *NotepadConduitFactory::fAbout = 0L;
-
-NotepadConduitFactory::NotepadConduitFactory(QObject *p, const char *n) :
-	KLibFactory(p,n)
+extern "C"
 {
-	FUNCTIONSETUP;
 
-	fInstance = new KInstance("notepadconduit");
-	fAbout = new KAboutData("NotepadConduit",
-		I18N_NOOP("Saves notepads to png files"),
-		KPILOT_VERSION,
-		I18N_NOOP("Configures the Notepad Conduit for KPilot"),
-		KAboutData::License_LGPL,
-		"(C) 2004, Joern Ahrens");
-	fAbout->addAuthor("Joern Ahrens",
-		I18N_NOOP("Primary Author"),
-		"kde@jokele.de",
-		"http://www.jokele.de/");
-	fAbout->addCredit("Adriaan de Groot");
-	fAbout->addCredit("Angus Ainslies", 
-		I18N_NOOP("Notepad conduit is based on Angus' read-notepad, part of pilot-link" ));
+void *init_conduit_notepad()
+{
+	return new ConduitFactory<NotepadConduitConfig,NotepadConduit>(0,"abbrowserconduit");
 }
 
-NotepadConduitFactory::~NotepadConduitFactory()
-{
-	FUNCTIONSETUP;
-
-	KPILOT_DELETE(fInstance);
-	KPILOT_DELETE(fAbout);
 }
 
-/* virtual */ QObject *NotepadConduitFactory::createObject( QObject *parent,
-	const char *name, const char *className, const QStringList &args)
-{
-	FUNCTIONSETUP;
-
-#ifdef DEBUG
-	DEBUGCONDUIT << fname
-		<< ": Creating object of class "
-		<< className
-		<< endl;
-#endif
-
-	if(qstrcmp(className, "ConduitConfigBase") == 0)
-	{
-		QWidget *w = dynamic_cast<QWidget *>(parent);
-		if (w) {
-			return new NotepadConduitConfig(w);
-		}
-		else {
-			return 0L;
-		}
-	}
-
-	if(qstrcmp(className, "SyncAction") == 0)
-	{
-		KPilotDeviceLink *d = dynamic_cast<KPilotDeviceLink *>(parent);
-
-		if (d) {
-			return new NotepadConduit(d, name, args);
-		}
-		else {
-			kdError() << k_funcinfo
-				<< ": Couldn't cast to KPilotDeviceLink"
-				<< endl;
-			return 0L;
-		}
-	}
-
-	return 0L;
-}
-
-
