@@ -18,8 +18,8 @@
 **
 ** You should have received a copy of the GNU Lesser General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -37,23 +37,14 @@
 #include <kaboutdata.h>
 
 #include "uiDialog.h"
+#include "pluginfactory.h"
 
 #include "setup_base.h"
 #include "null-conduit.h"
-#include "null-factory.moc"
+#include "null-factory.h"
 #include "nullSettings.h"
 
 
-extern "C"
-{
-
-void *init_conduit_null()
-{
-	return new NullConduitFactory;
-}
-
-}
-
 class NullConduitConfig : public ConduitConfigBase
 {
 public:
@@ -62,6 +53,7 @@ public:
 	virtual void load();
 protected:
 	NullWidget *fConfigWidget;
+	KAboutData *fAbout;
 } ;
 
 NullConduitConfig::NullConduitConfig(QWidget *p, const char *n) :
@@ -70,14 +62,21 @@ NullConduitConfig::NullConduitConfig(QWidget *p, const char *n) :
 {
 	FUNCTIONSETUP;
 	fConduitName = i18n("Null");
-	UIDialog::addAboutPage(fConfigWidget->tabWidget,NullConduitFactory::about());
+	fAbout = new KAboutData("nullConduit",
+		I18N_NOOP("Null Conduit for KPilot"),
+		KPILOT_VERSION,
+		I18N_NOOP("Configures the Null Conduit for KPilot"),
+		KAboutData::License_GPL,
+		"(C) 2001, Adriaan de Groot");
+	fAbout->addAuthor("Adriaan de Groot",
+		I18N_NOOP("Primary Author"),
+		"groot@kde.org",
+		"http://www.cs.kun.nl/~adridg/kpilot");
+
+	UIDialog::addAboutPage(fConfigWidget->tabWidget,fAbout);
 	fWidget=fConfigWidget;
 	QObject::connect(fConfigWidget->fLogMessage,SIGNAL(textChanged(const QString&)),
 		this,SLOT(modified()));
-	QObject::connect(fConfigWidget->fDatabases,SIGNAL(textChanged(const QString&)),
-		this,SLOT(modified()));
-	QObject::connect(fConfigWidget->fFailImmediately,SIGNAL(toggled(bool)),
-		this,SLOT(modified()));
 }
 
 /* virtual */ void NullConduitConfig::commit()
@@ -89,15 +88,9 @@ NullConduitConfig::NullConduitConfig(QWidget *p, const char *n) :
 		<< ": Message="
 		<< fConfigWidget->fLogMessage->text()
 		<< endl;
-	DEBUGCONDUIT << fname
-		<< ": Databases="
-		<< fConfigWidget->fDatabases->text()
-		<< endl;
 #endif
 
 	NullConduitSettings::setLogMessage( fConfigWidget->fLogMessage->text() );
-	NullConduitSettings::setDatabases( fConfigWidget->fDatabases->text() );
-	NullConduitSettings::setFailImmediately( fConfigWidget->fFailImmediately->isChecked());
 	NullConduitSettings::self()->writeConfig();
 	unmodified();
 }
@@ -108,94 +101,26 @@ NullConduitConfig::NullConduitConfig(QWidget *p, const char *n) :
 	NullConduitSettings::self()->readConfig();
 
 	fConfigWidget->fLogMessage->setText( NullConduitSettings::logMessage() );
-	fConfigWidget->fDatabases->setText( NullConduitSettings::databases().join(",") );
-	fConfigWidget->fFailImmediately->setChecked( NullConduitSettings::failImmediately() );
-
 #ifdef DEBUG
 	DEBUGCONDUIT << fname
 		<< ": Read Message="
 		<< fConfigWidget->fLogMessage->text()
 		<< endl;
-	DEBUGCONDUIT << fname
-		<< ": Read Database="
-		<< fConfigWidget->fDatabases->text()
-		<< endl;
 #endif
 
 	unmodified();
 }
 
-KAboutData *NullConduitFactory::fAbout = 0L;
-NullConduitFactory::NullConduitFactory(QObject *p, const char *n) :
-	KLibFactory(p,n)
-{
-	FUNCTIONSETUP;
 
-	fInstance = new KInstance("nullconduit");
-	fAbout = new KAboutData("nullConduit",
-		I18N_NOOP("Null Conduit for KPilot"),
-		KPILOT_VERSION,
-		I18N_NOOP("Configures the Null Conduit for KPilot"),
-		KAboutData::License_GPL,
-		"(C) 2001, Adriaan de Groot");
-	fAbout->addAuthor("Adriaan de Groot",
-		I18N_NOOP("Primary Author"),
-		"groot@kde.org",
-		"http://www.cs.kun.nl/~adridg/kpilot");
+
+extern "C"
+{
+
+unsigned long version_conduit_null = Pilot::PLUGIN_API;
+void *init_conduit_null()
+{
+	return new ConduitFactory<NullConduitConfig,NullConduit>(0,"nullconduit");
 }
 
-NullConduitFactory::~NullConduitFactory()
-{
-	FUNCTIONSETUP;
-
-	KPILOT_DELETE(fInstance);
-	KPILOT_DELETE(fAbout);
 }
 
-/* virtual */ QObject *NullConduitFactory::createObject( QObject *p,
-	const char *n,
-	const char *c,
-	const QStringList &a)
-{
-	FUNCTIONSETUP;
-
-#ifdef DEBUG
-	DEBUGCONDUIT << fname
-		<< ": Creating object of class "
-		<< c
-		<< endl;
-#endif
-
-	if (qstrcmp(c,"ConduitConfigBase")==0)
-	{
-		QWidget *w = dynamic_cast<QWidget *>(p);
-		if (w)
-		{
-			return new NullConduitConfig(w);
-		}
-		else
-		{
-			return 0L;
-		}
-	}
-	else if (qstrcmp(c,"SyncAction")==0)
-	{
-		KPilotDeviceLink *d = dynamic_cast<KPilotDeviceLink *>(p);
-
-		if (d)
-		{
-			return new NullConduit(d,n,a);
-		}
-		else
-		{
-			kdError() << k_funcinfo
-				<< ": Couldn't cast to KPilotDeviceLink"
-				<< endl;
-			return 0L;
-		}
-	}
-
-	return 0L;
-}
-
-
