@@ -30,9 +30,10 @@
 #include "options.h"
 
 #include <qbuttongroup.h>
+#include <kaboutdata.h>
 
 #include "korganizerConduit.h"
-#include "todo-factory.h"
+#include "todo-conduit.h"
 #include "todo-setup.h"
 
 #include "uiDialog.h"
@@ -43,7 +44,28 @@ ToDoWidgetSetup::ToDoWidgetSetup(QWidget *w, const char *n) :
 {
 	FUNCTIONSETUP;
 	fConduitName = i18n("To-do");
-	UIDialog::addAboutPage(fConfigWidget->tabWidget,VCalConduitFactoryBase::about());
+	KAboutData *fAbout = new KAboutData("todoConduit",
+		I18N_NOOP("To-do Conduit for KPilot"),
+		KPILOT_VERSION,
+		I18N_NOOP("Configures the To-do Conduit for KPilot"),
+		KAboutData::License_GPL,
+		"(C) 2001, Adriaan de Groot\n(C) 2002-2003, Reinhold Kainhofer");
+	fAbout->addAuthor("Dan Pilone",
+		I18N_NOOP("Original Author"));
+	fAbout->addAuthor("Preston Brown",
+		I18N_NOOP("Original Author"));
+	fAbout->addAuthor("Herwin-Jan Steehouwer",
+		I18N_NOOP("Original Author"));
+	fAbout->addAuthor("Adriaan de Groot",
+		I18N_NOOP("Maintainer"),
+		"groot@kde.org",
+		"http://www.cs.kun.nl/~adridg/kpilot");
+	fAbout->addAuthor("Reinhold Kainhofer",
+		I18N_NOOP("Maintainer"),
+		"reinhold@kainhofer.com",
+		"http://reinhold.kainhofer.com/Linux/");
+
+	UIDialog::addAboutPage(fConfigWidget->tabWidget,fAbout);
 
 	fConfigWidget->fSyncDestination->setTitle(i18n("To-do Destination"));
 }
@@ -58,8 +80,8 @@ ToDoWidgetSetup::~ToDoWidgetSetup()
 	return new ToDoWidgetSetup(w,n);
 }
 
-VCalConduitSettings*ToDoWidgetSetup::config() 
+VCalConduitSettings*ToDoWidgetSetup::config()
 {
-  return ToDoConduitFactory::config(); 
+  return TodoConduit::theConfig();
 }
 
