@@ -19,8 +19,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -45,8 +45,6 @@
 #include "kpilotSettings.h"
 #include "kpilotConfig.h"
 
-static const char kpilotconfig_id[] =
-	"$Id: kpilotConfig.cc 378136 2005-01-13 15:52:42Z adridg $";
 
 // This is a number indicating what configuration version
 // we're dealing with. Whenever new configuration options are
