@@ -28,9 +28,6 @@
 */
 
 
-static const char *pilotlocaldatabase_id =
-	"$Id: pilotLocalDatabase.cc 452989 2005-08-24 21:20:38Z adridg $";
-
 #include "options.h"
 
 #include <stdio.h>
@@ -43,14 +40,14 @@ static const char *pilotlocaldatabase_id =
 #include <qfile.h>
 #include <qregexp.h>
 #include <qdatetime.h>
-#include <qtextcodec.h>
 #include <qvaluevector.h>
 
 #include <kdebug.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
+#include <ksavefile.h>
 
-#include "pilotAppCategory.h"
+#include "pilotRecord.h"
 #include "pilotLocalDatabase.h"
 
 typedef QValueVector<PilotRecord *> Records;
@@ -72,7 +69,11 @@ public:
 		resetIndex();
 	}
 
-	void resetIndex() { current = 0; pending = -1; }
+	void resetIndex()
+	{
+		current = 0;
+		pending = -1;
+	}
 
 	unsigned int current;
 	int pending;
@@ -91,7 +92,7 @@ PilotLocalDatabase::PilotLocalDatabase(const QString & path,
 	fixupDBName();
 	openDatabase();
 
-	if (!isDBOpen() && useDefaultPath)
+	if (!isOpen() && useDefaultPath)
 	{
 		if (fPathBase && !fPathBase->isEmpty())
 		{
@@ -104,38 +105,12 @@ PilotLocalDatabase::PilotLocalDatabase(const QString & path,
 		}
 		fixupDBName();
 		openDatabase();
-		if (!isDBOpen())
+		if (!isOpen())
+		{
 			fPathName=path;
+		}
 	}
 
-	/* NOTREACHED */
-	(void) pilotlocaldatabase_id;
-}
-
-PilotLocalDatabase::PilotLocalDatabase(const QString & dbName,
-	bool useConduitDBs) :
-	PilotDatabase(dbName),
-	fPathName(QString::null),
-	fDBName(dbName),
-	fAppInfo(0L),
-	fAppLen(0),
-	d(0L)
-{
-	FUNCTIONSETUP;
-	if (fPathBase && !fPathBase->isEmpty() )
-	{
-		fPathName = *fPathBase;
-		if (useConduitDBs)
-			fPathName.replace(CSL1("DBBackup/"), CSL1("conduits/"));
-	}
-	else
-	{
-		fPathName = KGlobal::dirs()->saveLocation("data",
-			CSL1("kpilot/")+(useConduitDBs?CSL1("conduits/"):CSL1("DBBackup/")));
-	}
-
-	fixupDBName();
-	openDatabase();
 }
 
 PilotLocalDatabase::PilotLocalDatabase(const QString &dbName) :
@@ -183,20 +158,20 @@ bool PilotLocalDatabase::createDatabase(long creator, long type, int, int flags,
 {
 	FUNCTIONSETUP;
 
-	// if the database is already open, we cannot create it again. How about completely resetting it? (i.e. deleting it and the createing it again)
-	if (isDBOpen()) {
-#ifdef DEBUG
-		DEBUGCONDUIT<<"Database "<<fDBName<<" already open. Cannot recreate it."<<endl;
-#endif
+	// if the database is already open, we cannot create it again.
+	// How about completely resetting it? (i.e. deleting it and then
+	// creating it again)
+	if (isOpen()) 
+	{
+		DEBUGLIBRARY << fname << ": Database " << fDBName
+			<< " already open. Cannot recreate it." << endl;
 		return true;
 	}
 
-#ifdef DEBUG
-	DEBUGCONDUIT<<"Creating database "<<fDBName<<endl;
-#endif
+	DEBUGLIBRARY << fname << ": Creating database " << fDBName << endl;
 
 	// Database names seem to be latin1.
-	memcpy(&fDBInfo.name[0], PilotAppCategory::codec()->fromUnicode(fDBName), 34*sizeof(char));
+	Pilot::toPilot(fDBName, fDBInfo.name, sizeof(fDBInfo.name));
 	fDBInfo.creator=creator;
 	fDBInfo.type=type;
 	fDBInfo.more=0;
@@ -223,14 +198,21 @@ bool PilotLocalDatabase::createDatabase(long creator, long type, int, int flags,
 int PilotLocalDatabase::deleteDatabase()
 {
 	FUNCTIONSETUP;
-	if (isDBOpen()) closeDatabase();
+	if (isOpen())
+	{
+		closeDatabase();
+	}
 
 	QString dbpath=dbPathName();
 	QFile fl(dbpath);
 	if (QFile::remove(dbPathName()))
+	{
 		return 0;
+	}
 	else
+	{
 		return -1;
+	}
 }
 
 
@@ -242,7 +224,7 @@ int PilotLocalDatabase::readAppBlock(unsigned char *buffer, int size)
 
 	size_t m = kMin((size_t)size,(size_t)fAppLen);
 
-	if (!isDBOpen())
+	if (!isOpen())
 	{
 		kdError() << k_funcinfo << ": DB not open!" << endl;
 		memset(buffer,0,m);
@@ -257,7 +239,7 @@ int PilotLocalDatabase::writeAppBlock(unsigned char *buffer, int len)
 {
 	FUNCTIONSETUP;
 
-	if (isDBOpen() == false)
+	if (!isOpen())
 	{
 		kdError() << k_funcinfo << ": DB not open!" << endl;
 		return -1;
@@ -271,10 +253,17 @@ int PilotLocalDatabase::writeAppBlock(unsigned char *buffer, int len)
 }
 
 
-	// returns the number of records in the database
-int PilotLocalDatabase::recordCount()
+// returns the number of records in the database
+unsigned int PilotLocalDatabase::recordCount() const
 {
-	return d->size();
+	if (d && isOpen())
+	{
+		return d->size();
+	}
+	else
+	{
+		return 0;
+	}
 }
 
 
@@ -283,7 +272,10 @@ QValueList<recordid_t> PilotLocalDatabase::idList()
 {
 	int idlen=recordCount();
 	QValueList<recordid_t> idlist;
-	if (idlen<=0) return idlist;
+	if (idlen<=0)
+	{
+		return idlist;
+	}
 
 	// now create the QValue list from the idarr:
 	for (int i=0; i<idlen; i++)
@@ -299,13 +291,13 @@ PilotRecord *PilotLocalDatabase::readRecordById(recordid_t id)
 {
 	FUNCTIONSETUP;
 
-	d->pending = -1;
-	if (isDBOpen() == false)
+	if (!isOpen())
 	{
 		kdWarning() << k_funcinfo << fDBName << ": DB not open!" << endl;
 		return 0L;
 	}
 
+	d->pending = -1;
 
 	for (unsigned int i = 0; i < d->size(); i++)
 	{
@@ -323,17 +315,26 @@ PilotRecord *PilotLocalDatabase::readRecordById(recordid_t id)
 PilotRecord *PilotLocalDatabase::readRecordByIndex(int index)
 {
 	FUNCTIONSETUP;
+
+	if (index < 0)
+	{
+		DEBUGLIBRARY << fname << ": Index " << index << " is bogus." << endl;
+		return 0L;
+	}
+
 	d->pending = -1;
-	if (isDBOpen() == false)
+	if (!isOpen())
 	{
 		kdWarning() << k_funcinfo << ": DB not open!" << endl;
 		return 0L;
 	}
-#ifdef DEBUG
-	DEBUGKPILOT << "Index=" << index << " Count=" << recordCount() << endl;
-#endif
-	if (index >= recordCount())
+
+	DEBUGLIBRARY << fname << ": Index=" << index << " Count=" << recordCount() << endl;
+
+	if ( (unsigned int)index >= recordCount() )
+	{
 		return 0L;
+	}
 	PilotRecord *newRecord = new PilotRecord((*d)[index]);
 	d->current = index;
 
@@ -345,7 +346,7 @@ PilotRecord *PilotLocalDatabase::readNextRecInCategory(int category)
 {
 	FUNCTIONSETUP;
 	d->pending  = -1;
-	if (isDBOpen() == false)
+	if (!isOpen())
 	{
 		kdWarning() << k_funcinfo << ": DB not open!" << endl;
 		return 0L;
@@ -369,14 +370,12 @@ const PilotRecord *PilotLocalDatabase::findNextNewRecord()
 {
 	FUNCTIONSETUP;
 
-	if (isDBOpen() == false)
+	if (!isOpen())
 	{
 		kdWarning() << k_funcinfo << ": DB not open!" << endl;
 		return 0L;
 	}
-#ifdef DEBUG
-	DEBUGKPILOT << fname << ": looking for new record from " << d->current << endl;
-#endif
+	DEBUGLIBRARY << fname << ": looking for new record from " << d->current << endl;
 	// Should this also check for deleted?
 	while ((d->current < d->size())
 		&& ((*d)[d->current]->id() != 0 ))
@@ -396,7 +395,7 @@ PilotRecord *PilotLocalDatabase::readNextModifiedRec(int *ind)
 {
 	FUNCTIONSETUP;
 
-	if (isDBOpen() == false)
+	if (!isOpen())
 	{
 		kdWarning() << k_funcinfo << ": DB not open!" << endl;
 		return 0L;
@@ -411,9 +410,14 @@ PilotRecord *PilotLocalDatabase::readNextModifiedRec(int *ind)
 	}
 
 	if (d->current >= d->size())
+	{
 		return 0L;
+	}
 	PilotRecord *newRecord = new PilotRecord((*d)[d->current]);
-	if (ind) *ind=d->current;
+	if (ind)
+	{
+		*ind=d->current;
+	}
 
 	d->pending = d->current;	// Record which one needs the new id
 	d->current++;	// so we skip it next time
@@ -425,7 +429,7 @@ recordid_t PilotLocalDatabase::updateID(recordid_t id)
 {
 	FUNCTIONSETUP;
 
-	if (isDBOpen() == false)
+	if (!isOpen())
 	{
 		kdError() << k_funcinfo << ": DB not open!" << endl;
 		return 0;
@@ -446,7 +450,7 @@ recordid_t PilotLocalDatabase::writeRecord(PilotRecord * newRecord)
 {
 	FUNCTIONSETUP;
 
-	if (isDBOpen() == false)
+	if (!isOpen())
 	{
 		kdError() << k_funcinfo << ": DB not open!" << endl;
 		return 0;
@@ -486,7 +490,7 @@ recordid_t PilotLocalDatabase::writeRecord(PilotRecord * newRecord)
 int PilotLocalDatabase::deleteRecord(recordid_t id, bool all)
 {
 	FUNCTIONSETUP;
-	if (isDBOpen() == false)
+	if (!isOpen())
 	{
 		kdError() << k_funcinfo <<": DB not open"<<endl;
 		return -1;
@@ -524,7 +528,7 @@ int PilotLocalDatabase::resetSyncFlags()
 {
 	FUNCTIONSETUP;
 
-	if (isDBOpen() == false)
+	if (!isOpen())
 	{
 		kdError() << k_funcinfo << ": DB not open!" << endl;
 		return -1;
@@ -541,7 +545,7 @@ int PilotLocalDatabase::resetSyncFlags()
 int PilotLocalDatabase::resetDBIndex()
 {
 	FUNCTIONSETUP;
-	if (isDBOpen() == false)
+	if (!isOpen())
 	{
 		kdWarning() << k_funcinfo << ": DB not open!" << endl;
 		return -1;
@@ -554,7 +558,7 @@ int PilotLocalDatabase::resetDBIndex()
 int PilotLocalDatabase::cleanup()
 {
 	FUNCTIONSETUP;
-	if (isDBOpen() == false)
+	if (!isOpen())
 	{
 		kdWarning() << k_funcinfo << ": DB not open!" << endl;
 		return -1;
@@ -602,16 +606,12 @@ void PilotLocalDatabase::openDatabase()
 	pi_file *dbFile;
 
 	setDBOpen(false);
-	char buffer[PATH_MAX];
-	memset(buffer,0,PATH_MAX);
-	strlcpy(buffer,QFile::encodeName(dbPathName()),PATH_MAX);
 
-	dbFile = pi_file_open(buffer);
+	dbFile = pi_file_open( QFile::encodeName(dbPathName()) );
 	if (dbFile == 0L)
 	{
-#ifdef DEBUG
-		DEBUGCONDUIT << fname << ": Failed to open " << dbPathName() << endl;
-#endif
+		QString path = dbPathName();
+		DEBUGLIBRARY << fname << ": Failed to open " << path << endl;
 		return;
 	}
 
@@ -638,10 +638,16 @@ void PilotLocalDatabase::openDatabase()
 	while (pi_file_read_record(dbFile, i,
 			&tmpBuffer, &size, &attr, &cat, &id) == 0)
 	{
-		(*d)[i] = new PilotRecord(tmpBuffer, size, attr, cat, id);
+		pi_buffer_t *b = pi_buffer_new(size);
+		memcpy(b->data,tmpBuffer,size);
+		b->used = size;
+		(*d)[i] = new PilotRecord(b, attr, cat, id);
 		i++;
 	}
 	pi_file_close(dbFile);	// We done with it once we've read it in.
+
+	KSaveFile::backupFile( dbPathName() );
+
 	setDBOpen(true);
 }
 
@@ -650,29 +656,31 @@ void PilotLocalDatabase::closeDatabase()
 	FUNCTIONSETUP;
 	pi_file *dbFile;
 
-	if (isDBOpen() == false)
+	if (!isOpen())
 	{
-#ifdef DEBUG
-		DEBUGCONDUIT << fname << ": Database "<<fDBName<<" is not open. Cannot close and write it"<<endl;
-#endif
+		DEBUGLIBRARY << fname << ": Database " << fDBName
+			<< " is not open. Cannot close and write it"
+			<< endl;
 		return;
 	}
 
 	QString newName = dbPathName() + CSL1(".new");
-	char buf[PATH_MAX];
-	memset(buf,0,PATH_MAX);
-	strlcpy(buf,QFile::encodeName(newName),PATH_MAX);
+	QString path = dbPathName();
+	DEBUGLIBRARY << fname
+		<< ": Creating temp file " << newName
+		<< " for the database file " << path << endl;
 
-#ifdef DEBUG
-	DEBUGCONDUIT << fname
-		<< ": Creating temp file " << buf
-		<< " for the database file " << dbPathName() << endl;
-#endif
-
-	dbFile = pi_file_create(buf,&fDBInfo);
+	dbFile = pi_file_create(QFile::encodeName(newName),&fDBInfo);
 	pi_file_set_app_info(dbFile, fAppInfo, fAppLen);
+
 	for (unsigned int i = 0; i < d->size(); i++)
 	{
+		// How did a NULL pointer sneak in here?
+		if (!(*d)[i])
+		{
+			continue;
+		}
+
 		if (((*d)[i]->id() == 0) && ((*d)[i]->isDeleted()))
 		{
 			// Just ignore it
@@ -701,12 +709,10 @@ void PilotLocalDatabase::setDBPath(const QString &s)
 {
 	FUNCTIONSETUP;
 
-#ifdef DEBUG
-	DEBUGDAEMON << fname
+	DEBUGLIBRARY << fname
 		<< ": Setting default DB path to "
 		<< s
 		<< endl;
-#endif
 
 	if (!fPathBase)
 	{
@@ -723,3 +729,34 @@ void PilotLocalDatabase::setDBPath(const QString &s)
 	return eLocalDB;
 }
 
+
+/* static */ bool PilotLocalDatabase::infoFromFile( const QString &path, DBInfo *d )
+{
+	FUNCTIONSETUP;
+
+	pi_file *f = 0L;
+
+	if (!d)
+	{
+		return false;
+	}
+	if (!QFile::exists(path))
+	{
+		return false;
+	}
+
+	const char * fileName = QFile::encodeName( path );
+	f = pi_file_open( fileName );
+	if (!f)
+	{
+		kdWarning() << k_funcinfo
+			<< ": Can't open " << path << endl;
+		return false;
+	}
+
+	pi_file_get_info(f,d);
+	pi_file_close(f);
+
+	return true;
+}
+
