@@ -25,70 +25,29 @@
 /*
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
-static const char *pilotMemo_id =
-	"$Id: pilotMemo.cc 437980 2005-07-23 19:53:57Z kainhofe $";
 
 #include "options.h"
 
-#include <qtextcodec.h>
 
 #include "pilotMemo.h"
 #include "pilotDatabase.h"
 
 
 
-PilotMemo::PilotMemo(const PilotRecord * rec) : PilotAppCategory(rec)
+PilotMemo::PilotMemo(const PilotRecord * rec) : PilotRecordBase(rec)
 {
 	FUNCTIONSETUP;
-	fText = codec()->toUnicode((const char *)(rec->data()),rec->size());
-	(void) pilotMemo_id;
-}
-
-void PilotMemo::unpack(const void *text, int /* firstTime */)
-{
-	FUNCTIONSETUP;
-	kdWarning() << k_funcinfo << ": deprecated and broken function." << endl;
-	fText = codec()->toUnicode((const char *)text);
+	fText = Pilot::fromPilot((const char *)(rec->data()),rec->size());
 }
 
 PilotRecord *PilotMemo::pack()
 {
-	char *buf = new char[fText.length() + 8];
-	int len = fText.length() + 8;
-	pack_(buf,&len);
-	PilotRecord *r = new PilotRecord(buf, len, attributes(), category(), id());
-	delete[] buf;
+	pi_buffer_t *b = pi_buffer_new(fText.length()+8);
+	b->used = Pilot::toPilot(fText, b->data, b->allocated);
+	PilotRecord *r = new PilotRecord(b, this);
 	return r;
 }
 
-void *PilotMemo::pack_(void *buf, int *len)
-{
-	FUNCTIONSETUP;
-	if (!*len) return NULL;
-	if (*len < 0) return NULL; // buffer size being silly
-	if (fText.length() > (unsigned) *len) return NULL; // won't fit either
-
-	QCString s = codec()->fromUnicode(fText);
-
-	int use_length = *len;
-	if (MAX_MEMO_LEN < use_length) use_length = MAX_MEMO_LEN;
-
-	// Zero out the buffer, up to the max memo size.
-	memset(buf,0,use_length);
-
-	// Copy the encoded string and make extra sure it's NUL terminated.
-	// Yay, _every_ parameter needs a cast.
-	// *NOTE* This will truncate the memo text if it was passed in as being
-	//        too long, but this is better than allowing garbage in
-	strlcpy(( char *)buf,(const char *)s,use_length);
-
-	// Finally, we set the length of the memo to the used length
-	// of the data buffer, which might be the length of the string.
-	if ((int)s.length() < use_length) use_length = s.length()+1;
-	*len = use_length;
-	return buf;
-}
-
 
 QString PilotMemo::getTextRepresentation(bool richText)
 {
