@@ -35,19 +35,23 @@
 #include "pilotDatabase.h"
 #include "pilotRecord.h"
 
+class KPilotDeviceLink;
 
 class KDE_EXPORT PilotSerialDatabase : public PilotDatabase
 {
+friend class KPilotDeviceLink;
+protected:
+	PilotSerialDatabase( KPilotDeviceLink *l, const QString &dbName);
+
 public:
-	PilotSerialDatabase(int linksocket, const QString &dbName);
 	virtual ~PilotSerialDatabase();
 
 	/** Reads the application block info, returns size */
 	virtual int readAppBlock(unsigned char* buffer, int maxLen);
 	/** Writes the application block info. */
 	virtual int writeAppBlock(unsigned char* buffer, int len);
-	/**  returns the number of records in the database */
-	virtual int recordCount();
+	/**  returns the number of records in the database, 0 if not open */
+	virtual unsigned int recordCount() const;
 	/** Returns a QValueList of all record ids in the database. */
 	 virtual QValueList<recordid_t> idList();
 	/** Reads a record from database by id, returns record length */
@@ -105,7 +109,13 @@ public:
 protected:
 	virtual void openDatabase();
 	virtual void closeDatabase();
-	int getDBHandle() { return fDBHandle; }
+	/** Returns the file handle used to communicate with the handheld.
+	*   This is an internal value to be passed to DLP functions.
+	*/
+	int getDBHandle() const
+	{
+		return fDBHandle;
+	}
 
 
 private:
@@ -114,14 +124,12 @@ private:
 	QString     fDBName;
 	int         fDBHandle;
 	int         fDBSocket;
-#if PILOT_LINK_NUMBER >= PILOT_LINK_0_12_0
 	// Pilot-link 0.12 allocates buffers as needed and resizes them.
 	// Start with a buffer that is _probably_ big enough for most 
 	// PIM records, but much smaller than the 64k that we use otherwise.
 	// Might want to add algorithm for trying to optimize the initial 
 	// allocation for a given database.
 	static const int InitialBufferSize = 2048;
-#endif
 };
 
 #endif
