@@ -28,9 +28,9 @@
 */
 #include "options.h"
 
+
 #include <stdlib.h>
 
-#include <qtextcodec.h>
 #include <qdatetime.h>
 
 #include <kglobal.h>
@@ -39,10 +39,11 @@
 
 #include "pilotTodoEntry.h"
 
-static const char *pilotTodoEntry_id = "$Id: pilotTodoEntry.cc 450724 2005-08-18 22:12:19Z adridg $";
 
-
-PilotTodoEntry::PilotTodoEntry(struct ToDoAppInfo &appInfo):PilotAppCategory(), fAppInfo(appInfo)
+PilotTodoEntry::PilotTodoEntry(struct ToDoAppInfo &appInfo) :
+	fAppInfo(appInfo),
+	fDescriptionSize(0),
+	fNoteSize(0)
 {
 	FUNCTIONSETUP;
 	::memset(&fTodoInfo, 0, sizeof(struct ToDo));
@@ -50,27 +51,40 @@ PilotTodoEntry::PilotTodoEntry(struct ToDoAppInfo &appInfo):PilotAppCategory(),
 
 /* initialize the entry from another one. If rec==NULL, this constructor does the same as PilotTodoEntry()
 */
-PilotTodoEntry::PilotTodoEntry(struct ToDoAppInfo &appInfo, PilotRecord * rec):PilotAppCategory(rec), fAppInfo(appInfo)
+PilotTodoEntry::PilotTodoEntry(struct ToDoAppInfo &appInfo, PilotRecord * rec) :
+	PilotRecordBase(rec),
+	fAppInfo(appInfo),
+	fDescriptionSize(0),
+	fNoteSize(0)
 {
 	::memset(&fTodoInfo, 0, sizeof(struct ToDo));
 	if (rec)
 	{
-#if PILOT_LINK_NUMBER >= PILOT_LINK_0_12_0
 		pi_buffer_t b;
-		b.data = (unsigned char *) rec->getData();
+		b.data = (unsigned char *) rec->data();
 		b.allocated = b.used = rec->size();
 		unpack_ToDo(&fTodoInfo, &b, todo_v1);
-#else
-		unpack_ToDo(&fTodoInfo, (unsigned char *) rec->data(),
-			rec->size());
-#endif
+		if (fTodoInfo.description)
+		{
+			// Assume size of buffer allocated is just large enough;
+			// count trailing NUL as well.
+			fDescriptionSize = strlen(fTodoInfo.description)+1;
+		}
+		if (fTodoInfo.note)
+		{
+			// Same
+			fNoteSize = strlen(fTodoInfo.note)+1;
+		}
 	}
 
-	(void) pilotTodoEntry_id;
 }
 
 
-PilotTodoEntry::PilotTodoEntry(const PilotTodoEntry & e):PilotAppCategory(e), fAppInfo(e.fAppInfo)
+PilotTodoEntry::PilotTodoEntry(const PilotTodoEntry & e) :
+	PilotRecordBase( &e ),
+	fAppInfo(e.fAppInfo),
+	fDescriptionSize(0),
+	fNoteSize(0)
 {
 	FUNCTIONSETUP;
 	::memcpy(&fTodoInfo, &e.fTodoInfo, sizeof(fTodoInfo));
@@ -80,8 +94,7 @@ PilotTodoEntry::PilotTodoEntry(const PilotTodoEntry & e):PilotAppCategory(e), fA
 
 	setDescriptionP(e.getDescriptionP());
 	setNoteP(e.getNoteP());
-
-}				// end of copy constructor
+}
 
 
 PilotTodoEntry & PilotTodoEntry::operator = (const PilotTodoEntry & e)
@@ -95,6 +108,8 @@ PilotTodoEntry & PilotTodoEntry::operator = (const PilotTodoEntry & e)
 		// See PilotDateEntry::operator = for details
 		fTodoInfo.description = 0L;
 		fTodoInfo.note = 0L;
+		fDescriptionSize = 0;
+		fNoteSize = 0;
 
 		setDescriptionP(e.getDescriptionP());
 		setNoteP(e.getNoteP());
@@ -102,7 +117,7 @@ PilotTodoEntry & PilotTodoEntry::operator = (const PilotTodoEntry & e)
 	}
 
 	return *this;
-}				// end of assignment operator
+}
 
 QString PilotTodoEntry::getTextRepresentation(bool richText)
 {
@@ -154,28 +169,33 @@ QString PilotTodoEntry::getTextRepresentation(bool richText)
 
 QString PilotTodoEntry::getCategoryLabel() const
 {
-	return codec()->toUnicode(fAppInfo.category.name[category()]);
+	return Pilot::fromPilot(fAppInfo.category.name[category()]);
 }
 
-void *PilotTodoEntry::pack_(void *buf, int *len)
+PilotRecord *PilotTodoEntry::pack() const
 {
 	int i;
 
-#if PILOT_LINK_NUMBER >= PILOT_LINK_0_12_0
-	pi_buffer_t b = { 0,0,0 } ;
-	i = pack_ToDo(&fTodoInfo, &b, todo_v1);
-	memcpy(buf,b.data,kMin(i,*len));
-	*len = kMin(i,*len);
-#else
-	i = pack_ToDo(&fTodoInfo, (unsigned char *) buf, *len);
-	*len = i;
-#endif
-	return buf;
+	pi_buffer_t *b = pi_buffer_new( sizeof(fTodoInfo) );
+	i = pack_ToDo(const_cast<ToDo_t *>(&fTodoInfo), b, todo_v1);
+	if (i<0)
+	{
+		return 0;
+	}
+	// pack_ToDo sets b->used
+	return new PilotRecord( b, this );
 }
 
 void PilotTodoEntry::setDescription(const QString &desc)
 {
-	setDescriptionP(codec()->fromUnicode(desc),desc.length());
+	if (desc.length() < fDescriptionSize)
+	{
+		Pilot::toPilot(desc, fTodoInfo.description, fDescriptionSize);
+	}
+	else
+	{
+		setDescriptionP(Pilot::toPilot(desc),desc.length());
+	}
 }
 
 void PilotTodoEntry::setDescriptionP(const char *desc, int len)
@@ -183,12 +203,17 @@ void PilotTodoEntry::setDescriptionP(const char *desc, int len)
 	KPILOT_FREE(fTodoInfo.description);
 	if (desc && *desc)
 	{
-		if (-1 == len) len=::strlen(desc);
+		if (-1 == len)
+		{
+			len=::strlen(desc);
+		}
 
+		fDescriptionSize = len+1;
 		fTodoInfo.description = (char *)::malloc(len + 1);
 		if (fTodoInfo.description)
 		{
-			strlcpy(fTodoInfo.description, desc, len+1);
+			strncpy(fTodoInfo.description, desc, len);
+			fTodoInfo.description[len] = 0;
 		}
 		else
 		{
@@ -205,24 +230,37 @@ void PilotTodoEntry::setDescriptionP(const char *desc, int len)
 
 QString PilotTodoEntry::getDescription() const
 {
-	return codec()->toUnicode(getDescriptionP());
+	return Pilot::fromPilot(getDescriptionP());
 }
 
 void PilotTodoEntry::setNote(const QString &note)
 {
-	setNoteP(codec()->fromUnicode(note),note.length());
+	if (note.length() < fNoteSize)
+	{
+		Pilot::toPilot(note, fTodoInfo.note, fNoteSize);
+	}
+	else
+	{
+		setNoteP(Pilot::toPilot(note),note.length());
+	}
 }
 
 void PilotTodoEntry::setNoteP(const char *note, int len)
 {
 	KPILOT_FREE(fTodoInfo.note);
 	if (note && *note)
-	  {
-	    if (-1 == len) len=::strlen(note);
+	{
+		if (-1 == len)
+		{
+			len=::strlen(note);
+		}
+
+		fNoteSize = len+1;
 		fTodoInfo.note = (char *)::malloc(len + 1);
 		if (fTodoInfo.note)
 		{
-		    strlcpy(fTodoInfo.note, note, len+1);
+			strncpy(fTodoInfo.note, note, len);
+			fTodoInfo.note[len] = 0;
 		}
 		else
 		{
@@ -238,6 +276,6 @@ void PilotTodoEntry::setNoteP(const char *note, int len)
 
 QString PilotTodoEntry::getNote() const
 {
-	return codec()->toUnicode(getNoteP());
+	return Pilot::fromPilot(getNoteP());
 }
 
