@@ -1,11 +1,11 @@
-/* uiDialog.cc                          KPilot
+/* KPilot
 **
 ** Copyright (C) 2001 by Dan Pilone
+** Copyright (C) 2004 by Adriaan de Groot
 **
-** This defines a subclass of KDialogBase that handles the setup for
-** KPilot -- and conduits -- configuration dialogs. It also provides
-** some support for the default about-page in setup dialogs, for applications
-** (like conduits) with no main window or menu.
+** This class defines a way to add an "about widget" to a tab widget.
+**
+** None of Dan's original code is left.
 */
 
 /*
@@ -21,8 +21,8 @@
 **
 ** You should have received a copy of the GNU Lesser General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -44,35 +44,7 @@
 #include <kiconloader.h>
 #include <kactivelabel.h>
 
-#include "uiDialog.moc"
-
-UIDialog::UIDialog(QWidget * parent, const char *name,
-	bool modal) :
-	KDialogBase(parent, name, modal, QString::null,
-		KDialogBase::Ok | KDialogBase::Cancel,
-		KDialogBase::Ok, false),
-	fP(0L)
-{
-	FUNCTIONSETUP;
-
-	fMainWidget = makeHBoxMainWidget();
-}
-
-UIDialog::UIDialog(QWidget *parent, const char *name,
-	int buttonmask, bool modal) :
-	KDialogBase(parent,name,modal,QString::null,
-		buttonmask | KDialogBase::Ok,
-		KDialogBase::Ok, false),
-	fP(0L)
-{
-	FUNCTIONSETUP;
-	fMainWidget = makeHBoxMainWidget();
-}
-
-UIDialog::~UIDialog()
-{
-	FUNCTIONSETUP;
-}
+#include "uiDialog.h"
 
 /* static */ QWidget *UIDialog::aboutPage(QWidget *parent, KAboutData *ad)
 {
@@ -91,13 +63,6 @@ UIDialog::~UIDialog()
 	grid->addColSpacing(4, SPACING);
 
 
-#ifdef DEBUG
-	DEBUGKPILOT << fname
-		<< ": Looking for icon for "
-		<< p->appName()
-		<< endl;
-#endif
-
 	QPixmap applicationIcon =
 		l->loadIcon(QString::fromLatin1(p->appName()),
 		KIcon::Desktop,
@@ -106,12 +71,6 @@ UIDialog::~UIDialog()
 
 	if (applicationIcon.isNull())
 	{
-#ifdef DEBUG
-		DEBUGKPILOT << fname
-			<< ": Looking for icon for "
-			<< "kpilot"
-			<< endl;
-#endif
 		applicationIcon = l->loadIcon(QString::fromLatin1("kpilot"),
 			KIcon::Desktop);
 	}
@@ -122,14 +81,7 @@ UIDialog::~UIDialog()
 	//
 	text->setText(i18n("Send questions and comments to kdepim-users@kde.org"));
 	text->adjustSize();
-#ifdef DEBUG
-	DEBUGKPILOT << fname
-		<< ": Text size "
-		<< text->size().width()
-		<< ","
-		<< text->size().height()
-		<< endl;
-#endif
+
 	int linewidth = text->size().width();
 	int lineheight = text->size().height();
 
@@ -141,16 +93,16 @@ UIDialog::~UIDialog()
 
 
 	KActiveLabel *linktext = new KActiveLabel(w);
-	grid->addRowSpacing(1,QMAX(100,6*lineheight));
-	grid->addRowSpacing(2,QMAX(100,6*lineheight));
+	grid->addRowSpacing(1,kMax(100,6*lineheight));
+	grid->addRowSpacing(2,kMax(100,6*lineheight));
 	grid->addColSpacing(2,SPACING+linewidth/2);
 	grid->addColSpacing(3,SPACING+linewidth/2);
 	grid->setRowStretch(1,50);
 	grid->setRowStretch(2,50);
 	grid->setColStretch(2,50);
 	grid->setColStretch(3,50);
-	linktext->setMinimumSize(linewidth,QMAX(260,60+12*lineheight));
-	linktext->setFixedHeight(QMAX(260,60+12*lineheight));
+	linktext->setMinimumSize(linewidth,kMax(260,60+12*lineheight));
+	linktext->setFixedHeight(kMax(260,60+12*lineheight));
 	linktext->setVScrollBarMode(QScrollView::Auto/*AlwaysOn*/);
 	text = new QLabel(w);
 	grid->addMultiCellWidget(text,0,0,2,3);
@@ -231,24 +183,7 @@ UIDialog::~UIDialog()
 	linktext->append(s);
 	linktext->ensureVisible(0,0);
 
-#ifdef DEBUG
-	DEBUGKPILOT << fname
-		<< ": Size "
-		<< w->size().width()
-		<< ","
-		<< w->size().height()
-		<< endl;
-#endif
-
 	w->adjustSize();
-#ifdef DEBUG
-	DEBUGKPILOT << fname
-		<< ": Adjusted size "
-		<< w->size().width()
-		<< ","
-		<< w->size().height()
-		<< endl;
-#endif
 
 	return w;
 }
@@ -273,53 +208,8 @@ UIDialog::~UIDialog()
 		sz.setHeight(tw->size().height());
 	}
 
-#ifdef DEBUG
-	DEBUGKPILOT << fname
-		<< ": Final size "
-		<< sz.width()
-		<< ","
-		<< sz.height()
-		<< endl;
-#endif
-
 	tw->resize(sz);
 	tw->addTab(w, i18n("About"));
 	tw->adjustSize();
 }
 
-void UIDialog::addAboutPage(bool aboutbutton,KAboutData *ad)
-{
-	FUNCTIONSETUP;
-	addAboutPage(tabWidget(),ad,aboutbutton);
-}
-
-void UIDialog::setTabWidget(QTabWidget * w)
-{
-	FUNCTIONSETUP;
-
-	widget()->resize(w->size());
-	fP = w;
-}
-
-/* slot */ void UIDialog::showAbout()
-{
-	FUNCTIONSETUP;
-	KAboutApplication *kap = new KAboutApplication(this);
-
-	kap->exec();
-	// Experience crashes when deleting kap
-	//
-	//
-	// delete kap;
-}
-
-/* virtual slot */ void UIDialog::slotOk()
-{
-	FUNCTIONSETUP;
-
-	if (validate())
-	{
-		commitChanges();
-		KDialogBase::slotOk();
-	}
-}
