@@ -35,12 +35,12 @@
 
 #include "gwjobs.h"
 
-#define READ_ADDRESS_FOLDER_CHUNK_SIZE 250
+#define READ_ADDRESS_FOLDER_CHUNK_SIZE 50
 #define READ_CALENDAR_FOLDER_CHUNK_SIZE 50
 
 GWJob::GWJob( GroupwiseServer *server, struct soap *soap, const QString &url,
   const std::string &session )
-  : mServer( server ), mSoap( soap ), mUrl( url ), mSession( session )
+  : mServer( server ), mSoap( soap ), mUrl( url ), mSession( session ), mError( GroupWise::NoError )
 {
 }
 
@@ -61,6 +61,8 @@ void ReadAddressBooksJob::run()
 {
   kdDebug() << "ReadAddressBooksJob::run()" << endl;
 
+// alternate read logic added on 20061209, uses the list of address books provided by the job starter instead of asking the server for the address book list again.  Risk might be that the list of address books is stale.
+#if 0
   mSoap->header->ngwt__session = mSession;
   _ngwm__getAddressBookListRequest addressBookListRequest;
   _ngwm__getAddressBookListResponse addressBookListResponse;
@@ -89,6 +91,17 @@ void ReadAddressBooksJob::run()
       }
     }
   }
+#else
+  GWConverter conv( mSoap );
+  QStringList::Iterator it = mAddressBookIds.begin();
+  const QStringList::Iterator end = mAddressBookIds.end();
+  for ( ; it != end; ++it )
+  {
+    std::string* id = conv.qStringToString( *it );
+    readAddressBook( *id );
+    mProgress += 100;
+  }
+#endif
 }
 
 void ReadAddressBooksJob::readAddressBook( std::string &id )
@@ -171,35 +184,50 @@ void ReadAddressBooksJob::readAddressBook( std::string &id )
 #else
   unsigned int readItems = 0;
   unsigned int readChunkSize = READ_ADDRESS_FOLDER_CHUNK_SIZE;
-  
-  int cursor;
+
+  int cursor = 0;
 
   _ngwm__createCursorRequest cursorRequest;
   _ngwm__createCursorResponse cursorResponse;
 
   cursorRequest.container = id;
   cursorRequest.view = 0;
-  // filter for Contacts until we support Groups
-  cursorRequest.filter = soap_new_ngwt__Filter( mSoap, -1 );
-  ngwt__FilterEntry * fe = soap_new_ngwt__FilterEntry( mSoap, -1 );
-  fe->op = isOf;
-  fe->field = soap_new_std__string( mSoap, -1 );
-  fe->field->append( "@type" );
-  fe->value = soap_new_std__string( mSoap, -1 );
-  fe->value->append( "Contact" );
-  fe->custom = 0;
-  fe->date = 0;
-
-  cursorRequest.filter->element = fe;
-
+  if ( id.find( "GroupWiseSystemAddressBook" ) == 0 )
+  {
+    kdDebug() << "  Book: " << id.c_str() << " is a SAB " << endl;
+    // filter for Contacts until we support Groups
+    cursorRequest.filter = soap_new_ngwt__Filter( mSoap, -1 );
+    ngwt__FilterEntry * fe = soap_new_ngwt__FilterEntry( mSoap, -1 );
+    fe->op = isOf;
+    fe->field = soap_new_std__string( mSoap, -1 );
+    fe->field->append( "@type" );
+    fe->value = soap_new_std__string( mSoap, -1 );
+    fe->value->append( "Contact" );
+    fe->custom = 0;
+    fe->date = 0;
+    cursorRequest.filter->element = fe;
+  }
+  else
+  {
+    kdDebug() << "  Book: " << id.c_str() << " is a personal address book " << endl;
+    cursorRequest.filter = 0;
+  }
+  
   mSoap->header->ngwt__session = mSession;
   soap_call___ngw__createCursorRequest( mSoap, mUrl.latin1(), 0,
                                         &cursorRequest,
                                         &cursorResponse );
   if ( cursorResponse.cursor )
     cursor = *(cursorResponse.cursor);
-  else /* signal error? */
-    return;
+  else
+  {
+    if ( cursorResponse.status && cursorResponse.status->code != 0 )
+    {
+      kdDebug() << "  Couldn't read " << GWConverter::stringToQString(id ) << " : " << GWConverter::stringToQString(cursorResponse.status->description) << endl;
+      //mError = GroupWise::RefreshNeeded;
+    }
+  return;
+  }
 
   _ngwm__readCursorRequest readCursorRequest;
 
@@ -237,7 +265,7 @@ void ReadAddressBooksJob::readAddressBook( std::string &id )
       for( it = readCursorResponse.items->item.begin(); it != readCursorResponse.items->item.end(); ++it ) {
         ngwt__Item *item = *it;
 
-#if 1
+#if 0
         if ( item )
           if ( item->name )
             kdDebug() << "ITEM: " << item->name->c_str() << endl;
@@ -617,71 +645,86 @@ void UpdateAddressBooksJob::setAddressBookIds( const QStringList &ids )
   kdDebug() << "ADDR IDS: " << ids.join( "," ) << endl;
 }
 
-void UpdateAddressBooksJob::setStartSequenceNumber( const int startSeqNo )
+void UpdateAddressBooksJob::setStartSequenceNumber( const unsigned long startSeqNo )
 {
   mStartSequenceNumber = startSeqNo;
 }
 
+void UpdateAddressBooksJob::setLastPORebuildTime( const unsigned long lastPORebuildTime)
+{
+  mLastPORebuildTime = lastPORebuildTime;
+}
+
 void UpdateAddressBooksJob::run()
 {
   kdDebug() << "UpdateAddressBooksJob::run()" << endl;
 
-  mSoap->header->ngwt__session = mSession;
-  _ngwm__getDeltasRequest request;
-  _ngwm__getDeltasResponse response;
+  while ( true )
+  {
+    mSoap->header->ngwt__session = mSession;
+    _ngwm__getDeltasRequest request;
+    _ngwm__getDeltasResponse response;
 
-  GWConverter conv( mSoap );
-  request.container.append( mAddressBookIds.first().latin1() );
-  request.deltaInfo = soap_new_ngwt__DeltaInfo( mSoap, -1 );
-  request.deltaInfo->count = (int*)soap_malloc( mSoap, sizeof(int) );
-  *( request.deltaInfo->count ) = -1;
- /* request.deltaInfo->count = 0;*/
-  request.deltaInfo->lastTimePORebuild = 0;
-  request.deltaInfo->firstSequence = (unsigned long*)soap_malloc( mSoap, sizeof(unsigned long) );
-  *(request.deltaInfo->firstSequence) = mStartSequenceNumber;
-  request.deltaInfo->lastSequence = 0; /*(unsigned long*)soap_malloc( mSoap, sizeof(unsigned long) );*/
-  /* *(request.deltaInfo->lastSequence) = mLastSequenceNumber; */
-  //request.view = soap_new_std__string( mSoap, -1 );
-  //request.view->append("id name version modified ItemChanges");
-  request.view = 0;
-  soap_call___ngw__getDeltasRequest( mSoap, mUrl.latin1(),
-                                              NULL, &request, &response);
-  soap_print_fault( mSoap, stderr );
-  response.items->item;
-  
-  
-  if ( response.items ) {
-    std::vector<class ngwt__Item * > items = response.items->item;
+    GWConverter conv( mSoap );
+    request.container.append( mAddressBookIds.first().latin1() );
+    request.deltaInfo = soap_new_ngwt__DeltaInfo( mSoap, -1 );
+    request.deltaInfo->count = (int*)soap_malloc( mSoap, sizeof(int) );
+    *( request.deltaInfo->count ) = READ_ADDRESS_FOLDER_CHUNK_SIZE;
+    request.deltaInfo->lastTimePORebuild = mLastPORebuildTime;
+    request.deltaInfo->firstSequence = (unsigned long*)soap_malloc( mSoap, sizeof(unsigned long) );
+    *(request.deltaInfo->firstSequence) = mStartSequenceNumber;
+    request.deltaInfo->lastSequence = 0; /*(unsigned long*)soap_malloc( mSoap, sizeof(unsigned long) );*/
+    //request.view = soap_new_std__string( mSoap, -1 );
+    //request.view->append("id name version modified ItemChanges");
+    request.view = 0;
+    soap_call___ngw__getDeltasRequest( mSoap, mUrl.latin1(),
+                                                NULL, &request, &response);
+    soap_print_fault( mSoap, stderr );
+
+    if ( response.items ) {
+      std::vector<class ngwt__Item * > items = response.items->item;
 #if 1
-    kdDebug() << "ReadAddressBooksJob::UpdateAddressBooksJob() - got " << items.size() << "contacts" << endl;
+      kdDebug() << "  - got " << items.size() << "contacts" << endl;
 #endif
-    KABC::Addressee::List contacts;
-    ContactConverter converter( mSoap );
+      KABC::Addressee::List contacts;
+      ContactConverter converter( mSoap );
 
-    std::vector<class ngwt__Item * >::const_iterator it;
-    for ( it = items.begin(); it != items.end(); ++it ) {
-      ngwt__Item *item = *it;
+      std::vector<class ngwt__Item * >::const_iterator it;
+      for ( it = items.begin(); it != items.end(); ++it ) {
+        ngwt__Item *item = *it;
 
-#if 1
-    if ( item )
-      if ( item->name )
-        kdDebug() << "ITEM: " << item->name->c_str() << endl;
-      if ( item->id )
-        kdDebug() << "ITEM: ID (" << item->id->c_str()
-        << ")" << endl;
-    else 
-      kdDebug() << "ITEM is null" << endl;
+#if 0
+      if ( item )
+        if ( item->name )
+          kdDebug() << "ITEM: " << item->name->c_str() << endl;
+        if ( item->id )
+          kdDebug() << "ITEM: ID (" << item->id->c_str()
+          << ")" << endl;
+      else 
+        kdDebug() << "ITEM is null" << endl;
 #endif
 
-      ngwt__Contact *contact = dynamic_cast<ngwt__Contact *>( item );
+        ngwt__Contact *contact = dynamic_cast<ngwt__Contact *>( item );
 
-      KABC::Addressee addr = converter.convertFromContact( contact );
-      if ( !addr.isEmpty() )
-        contacts.append( addr );
+        KABC::Addressee addr = converter.convertFromContact( contact );
+        if ( !addr.isEmpty() )
+          contacts.append( addr );
+      }
+      mServer->emitGotAddressees( contacts );
+
+      // now stop if we got less items than we asked for.
+      if ( items.size() < READ_ADDRESS_FOLDER_CHUNK_SIZE )
+        break;
+      else
+        mStartSequenceNumber += READ_ADDRESS_FOLDER_CHUNK_SIZE;
     }
-    mServer->emitGotAddressees( contacts );
+    else if ( response.status && response.status->code == 0xD716 )
+    {
+      kdDebug() << "The cached address book is too old, we have to refresh the whole thing." << endl;
+      mError = GroupWise::RefreshNeeded;
+      return;
+    }
+    else
+      return;
   }
-
-//   if ( addressBookListResponse.books ) { 
-//     std::vector<class ngwt__AddressBook * > *addressBooks = &addressBookListResponse.books->book;
 }
