@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 
     In addition, as a special exception, the copyright holders give
     permission to link the code of this program with any edition of
@@ -235,7 +235,7 @@ bool Task::saveAttributes( QDomElement& element ) const
   if ( !parent().isNull() )
     writeString( element, "parent", parent() );
 
-  if ( hasCompletedDate() )
+  if ( hasCompletedDate() && percentCompleted() == 100)
     writeString( element, "x-completed-date", dateTimeToString( completedDate() ) );
 
   return true;
@@ -302,10 +302,12 @@ void Task::setFields( const KCal::Todo* task )
     mHasDueDate = false;
   if ( task->relatedTo() )
     setParent( task->relatedTo()->uid() );
+  else if ( !task->relatedToUid().isEmpty() )
+    setParent( task->relatedToUid() );
   else
     setParent( QString::null );
 
-  if ( task->hasCompletedDate() )
+  if ( task->hasCompletedDate() && task->percentComplete() == 100 )
     setCompletedDate( localToUTC( task->completed() ) );
   else
     mHasCompletedDate = false;
@@ -326,6 +328,6 @@ void Task::saveTo( KCal::Todo* task )
   if ( !parent().isNull() )
     task->setRelatedToUid( parent() );
 
-  if ( hasCompletedDate() )
+  if ( hasCompletedDate() && task->percentComplete() == 100 )
     task->setCompleted( utcToLocal( mCompletedDate ) );
 }
