@@ -31,7 +31,6 @@
 
 extern "C" {
   #include <ical.h>
-  #include <icalss.h>
   #include <icalparser.h>
   #include <icalrestriction.h>
 }
@@ -192,17 +191,16 @@ icalcomponent *ICalFormatImpl::writeEvent(Event *event)
     icaltimetype end;
     if (event->doesFloat()) {
 //      kdDebug(5800) << " Event " << event->summary() << " floats." << endl;
-//      if (event->dtEnd().date() != event->dtStart().date()) {
-        // +1 day because end date is non-inclusive.
-        end = writeICalDate( event->dtEnd().date().addDays( 1 ) );
-//      }
+      // +1 day because end date is non-inclusive.
+      end = writeICalDate( event->dtEnd().date().addDays( 1 ) );
+      icalcomponent_add_property(vevent,icalproperty_new_dtend(end));
     } else {
 //      kdDebug(5800) << " Event " << event->summary() << " has time." << endl;
       if (event->dtEnd() != event->dtStart()) {
         end = writeICalDateTime(event->dtEnd());
+        icalcomponent_add_property(vevent,icalproperty_new_dtend(end));
       }
     }
-    icalcomponent_add_property(vevent,icalproperty_new_dtend(end));
   }
 
 // TODO: resources
@@ -406,8 +404,8 @@ void ICalFormatImpl::writeIncidence(icalcomponent *parent,Incidence *incidence)
         incidence->relatedToUid().utf8()));
   }
 
-  kdDebug(5800) << "Write recurrence for '" << incidence->summary() << "' (" << incidence->uid()
-            << ")" << endl;
+//   kdDebug(5800) << "Write recurrence for '" << incidence->summary() << "' (" << incidence->uid()
+//             << ")" << endl;
 
   RecurrenceRule::List rrules( incidence->recurrence()->rRules() );
   RecurrenceRule::List::ConstIterator rit;
@@ -766,7 +764,7 @@ icalrecurrencetype ICalFormatImpl::writeRecurrenceRule( RecurrenceRule *recur )
 
 icalcomponent *ICalFormatImpl::writeAlarm(Alarm *alarm)
 {
-kdDebug(5800) << " ICalFormatImpl::writeAlarm" << endl;
+// kdDebug(5800) << " ICalFormatImpl::writeAlarm" << endl;
   icalcomponent *a = icalcomponent_new(ICAL_VALARM_COMPONENT);
 
   icalproperty_action action;
@@ -783,7 +781,7 @@ kdDebug(5800) << " ICalFormatImpl::writeAlarm" << endl;
       break;
     case Alarm::Audio:
       action = ICAL_ACTION_AUDIO;
-kdDebug(5800) << " It's an audio action, file: " << alarm->audioFile() << endl;
+// kdDebug(5800) << " It's an audio action, file: " << alarm->audioFile() << endl;
       if (!alarm->audioFile().isEmpty()) {
         attach = icalattach_new_from_url(QFile::encodeName( alarm->audioFile() ).data());
         icalcomponent_add_property(a,icalproperty_new_attach(attach));
@@ -950,6 +948,8 @@ Event *ICalFormatImpl::readEvent( icalcomponent *vevent, icalcomponent *vtimezon
   QStringList categories;
   icalproperty_transp transparency;
 
+  bool dtEndProcessed = false;
+
   while (p) {
     icalproperty_kind kind = icalproperty_isa(p);
     switch (kind) {
@@ -968,6 +968,7 @@ Event *ICalFormatImpl::readEvent( icalcomponent *vevent, icalcomponent *vtimezon
           event->setDtEnd(readICalDateTime(icaltime, tz));
           event->setFloats( false );
         }
+        dtEndProcessed = true;
         break;
 
       case ICAL_RELATEDTO_PROPERTY:  // related event (parent)
@@ -993,6 +994,12 @@ Event *ICalFormatImpl::readEvent( icalcomponent *vevent, icalcomponent *vtimezon
     p = icalcomponent_get_next_property(vevent,ICAL_ANY_PROPERTY);
   }
 
+  // according to rfc2445 the dtend shouldn't be written when it equals
+  // start date. so assign one equal to start date.
+  if ( !dtEndProcessed && !event->hasDuration() ) {
+    event->setDtEnd( event->dtStart() );
+  }
+
   QString msade = event->nonKDECustomProperty("X-MICROSOFT-CDO-ALLDAYEVENT");
   if (!msade.isNull()) {
     bool floats = (msade == QString::fromLatin1("TRUE"));
@@ -1173,19 +1180,26 @@ Person ICalFormatImpl::readOrganizer( icalproperty *organizer )
 
 Attachment *ICalFormatImpl::readAttachment(icalproperty *attach)
 {
-  icalattach *a = icalproperty_get_attach(attach);
-
   Attachment *attachment = 0;
 
-  int isurl = icalattach_get_is_url (a);
-  if (isurl == 0)
-    attachment = new Attachment((const char*)icalattach_get_data(a));
-  else {
-    attachment = new Attachment(QString(icalattach_get_url(a)));
+  icalvalue_kind value_kind = icalvalue_isa(icalproperty_get_value(attach));
+
+  if ( value_kind == ICAL_ATTACH_VALUE ) {
+    icalattach *a = icalproperty_get_attach(attach);
+
+    int isurl = icalattach_get_is_url (a);
+    if (isurl == 0)
+      attachment = new Attachment((const char*)icalattach_get_data(a));
+    else {
+      attachment = new Attachment(QString(icalattach_get_url(a)));
+    }
+  }
+  else if ( value_kind == ICAL_URI_VALUE ) {
+    attachment = new Attachment(QString(icalvalue_get_uri(icalproperty_get_value(attach))));
   }
 
   icalparameter *p = icalproperty_get_first_parameter(attach, ICAL_FMTTYPE_PARAMETER);
-  if (p)
+  if (p && attachment)
     attachment->setMimeType(QString(icalparameter_get_fmttype(p)));
 
   return attachment;
@@ -1429,7 +1443,7 @@ void ICalFormatImpl::readCustomProperties(icalcomponent *parent,CustomProperties
     QString value = QString::fromUtf8(icalproperty_get_x(p));
     const char *name = icalproperty_get_x_name(p);
     customProperties[name] = value;
-    kdDebug(5800) << "Set custom property [" << name << '=' << value << ']' << endl;
+    // kdDebug(5800) << "Set custom property [" << name << '=' << value << ']' << endl;
     p = icalcomponent_get_next_property(parent,ICAL_X_PROPERTY);
   }
 
@@ -1445,7 +1459,7 @@ void ICalFormatImpl::readRecurrenceRule(icalproperty *rrule,Incidence *incidence
   Recurrence *recur = incidence->recurrence();
 
   struct icalrecurrencetype r = icalproperty_get_rrule(rrule);
-  dumpIcalRecurrence(r);
+//   dumpIcalRecurrence(r);
 
   RecurrenceRule *recurrule = new RecurrenceRule( /*incidence*/ );
   recurrule->setStartDt( incidence->dtStart() );
@@ -1458,7 +1472,7 @@ void ICalFormatImpl::readExceptionRule( icalproperty *rrule, Incidence *incidenc
 //  kdDebug(5800) << "Read recurrence for " << incidence->summary() << endl;
 
   struct icalrecurrencetype r = icalproperty_get_exrule(rrule);
-  dumpIcalRecurrence(r);
+//   dumpIcalRecurrence(r);
 
   RecurrenceRule *recurrule = new RecurrenceRule( /*incidence*/ );
   recurrule->setStartDt( incidence->dtStart() );
@@ -1552,7 +1566,7 @@ void ICalFormatImpl::readRecurrence( const struct icalrecurrencetype &r, Recurre
 
 void ICalFormatImpl::readAlarm(icalcomponent *alarm,Incidence *incidence)
 {
-  kdDebug(5800) << "Read alarm for " << incidence->summary() << endl;
+//   kdDebug(5800) << "Read alarm for " << incidence->summary() << endl;
 
   Alarm* ialarm = incidence->newAlarm();
   ialarm->setRepeatCount(0);
@@ -1579,7 +1593,7 @@ void ICalFormatImpl::readAlarm(icalcomponent *alarm,Incidence *incidence)
     }
   }
   ialarm->setType(type);
-kdDebug(5800) << " alarm type =" << type << endl;
+// kdDebug(5800) << " alarm type =" << type << endl;
 
   p = icalcomponent_get_first_property(alarm,ICAL_ANY_PROPERTY);
   while (p) {
