@@ -3,7 +3,7 @@
   FILE: icaltypes.c
   CREATOR: eric 16 May 1999
   
-  $Id: icaltypes.c 405592 2005-04-14 19:28:51Z dfaure $
+  $Id: icaltypes.c 537923 2006-05-06 09:14:35Z onurf $
   $Locker:  $
     
 
@@ -77,7 +77,7 @@ struct icaltriggertype icaltriggertype_from_string(const char* str)
 
     
     struct icaltriggertype tr, null_tr;
-    icalerrorstate es;
+    icalerrorstate es = ICAL_ERROR_UNKNOWN;
     icalerrorenum e;
 
     tr.time= icaltime_null_time();
