@@ -1,7 +1,7 @@
 /*
     This file is part of libkcal.
 
-    Copyright (c) 1998 Preston Brown
+    Copyright (c) 1998 Preston Brown <pbrown@kde.org>
     Copyright (c) 2001,2003 Cornelius Schumacher <schumacher@kde.org>
 
     This library is free software; you can redistribute it and/or
@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <typeinfo>
@@ -78,7 +78,7 @@ ResourceLocal::ResourceLocal( const KConfig* config )
   init();
 }
 
-ResourceLocal::ResourceLocal( const QString& fileName ) 
+ResourceLocal::ResourceLocal( const QString& fileName )
   : ResourceCached( 0 )
 {
   mURL = KURL( fileName );
@@ -94,7 +94,7 @@ void ResourceLocal::writeConfig( KConfig* config )
   ResourceCalendar::writeConfig( config );
   config->writePathEntry( "CalendarURL", mURL.prettyURL() );
   QString typeID = typeid( *mFormat ).name();
-  
+
   if ( typeid( *mFormat ) == typeid( ICalFormat ) )
     config->writeEntry( "Format", "ical" );
   else if ( typeid( *mFormat ) == typeid( VCalFormat ) ) // if ( typeID == "ICalFormat" )
@@ -109,8 +109,6 @@ void ResourceLocal::init()
 
   setType( "file" );
 
-  mOpen = false;
-
   connect( &mDirWatch, SIGNAL( dirty( const QString & ) ),
            SLOT( reload() ) );
   connect( &mDirWatch, SIGNAL( created( const QString & ) ),
@@ -136,16 +134,6 @@ ResourceLocal::~ResourceLocal()
   delete d;
 }
 
-bool ResourceLocal::doOpen()
-{
-  kdDebug(5800) << "Opening resource " << resourceName() << " with URL "
-                << mURL.prettyURL() << endl;
-
-  mOpen = true;
-
-  return true;
-}
-
 QDateTime ResourceLocal::readLastModified()
 {
   QFileInfo fi( mURL.path() );
@@ -154,13 +142,12 @@ QDateTime ResourceLocal::readLastModified()
 
 bool ResourceLocal::doLoad()
 {
-  if ( !mOpen ) return true;
-
   bool success;
 
   if ( !KStandardDirs::exists( mURL.path() ) ) {
     kdDebug(5800) << "ResourceLocal::load(): File doesn't exist yet." << endl;
-    success = true;
+    // Save the empty calendar, so the calendar file will be created.
+    success = doSave();
   } else {
     success = mCalendar.load( mURL.path() );
     if ( success ) d->mLastModified = readLastModified();
@@ -171,10 +158,7 @@ bool ResourceLocal::doLoad()
 
 bool ResourceLocal::doSave()
 {
-  if ( !mOpen ) return true;
-
   bool success = mCalendar.save( mURL.path() );
-
   d->mLastModified = readLastModified();
 
   return success;
@@ -185,33 +169,29 @@ KABC::Lock *ResourceLocal::lock()
   return mLock;
 }
 
-void ResourceLocal::reload()
+bool ResourceLocal::doReload()
 {
-  kdDebug(5800) << "ResourceLocal::reload()" << endl;
+  kdDebug(5800) << "ResourceLocal::doReload()" << endl;
 
-  if ( !mOpen ) return;
+  if ( !isOpen() ) return false;
 
   if ( d->mLastModified == readLastModified() ) {
     kdDebug(5800) << "ResourceLocal::reload(): file not modified since last read."
               << endl;
-    return;
+    return false;
   }
 
   mCalendar.close();
   mCalendar.load( mURL.path() );
-
-  emit resourceChanged( this );
+  return true;
 }
 
-void ResourceLocal::doClose()
+void ResourceLocal::reload()
 {
-  if ( !mOpen ) return;
-
-  mCalendar.close();
-  mOpen = false;
+  if ( doReload() )
+    emit resourceChanged( this );
 }
 
-
 void ResourceLocal::dump() const
 {
   ResourceCalendar::dump();
@@ -223,4 +203,27 @@ QString ResourceLocal::fileName() const
   return mURL.path();
 }
 
+bool ResourceLocal::setFileName( const QString &fileName )
+{
+  bool open = isOpen();
+  if ( open ) close();
+  delete mLock;
+  mDirWatch.stopScan();
+  mDirWatch.removeFile( mURL.path() );
+  mURL = KURL( fileName );
+  mLock = new KABC::Lock( mURL.path() );
+  mDirWatch.addFile( mURL.path() );
+  mDirWatch.startScan();
+  return true;
+}
+
+bool ResourceLocal::setValue( const QString &key, const QString &value ) 
+{
+  if ( key == "File" ) {
+    return setFileName( value );
+  } else return false;
+}
+
+
+
 #include "resourcelocal.moc"
