@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "calendarlocal.h"
@@ -64,9 +64,13 @@ int main( int argc, char **argv )
   kdDebug(5800) << "Output file: " << output << endl;
 
 
-  CalendarLocal cal;
+  CalendarLocal cal( QString::fromLatin1("UTC") );
 
   if ( !cal.load( input ) ) return 1;
+	QString tz = cal.nonKDECustomProperty( "X-LibKCal-Testsuite-OutTZ" );
+	if ( !tz.isEmpty() ) {
+	  cal.setTimeZoneIdViewOnly( tz );
+	}
   if ( !cal.save( output ) ) return 1;
 
   return 0;
